% MASTER_p3d_MB_sensitivity.m
%
% AUTHOR:           Michael Swyer
% DATE CREATED:     7/8/2015
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:
%   Script to run poly3d, version from 1999, in c++ is slaved to matlab
%   for:
%   - Modeling the faults at Mount Baker
%
% OBSERVATION GRIDS:
%      Areal grid: 2D
%           -Extent of WADGER thermal model for MB with 1000 ft obs point
%           spacing converted to meters in UTM.
%          
% PURPOSE OF MODIFICATION:
%
% INPUT: Fault nodes and connectivity in global coordinates NAD_1983_UTM_ZONE_10N
%       , Stress tensors for 200m and 3000m depths and focal mechanism observation
%       points in Microsoft Excel format named:
%           -
% 
% OUTPUT: Poly 3D Input and Output files named:
%           -MountBaker200_ul.in
%           -MountBaker200_ul.out
%           -MountBaker200_ll.in
%           -MountBaker200_ll.out
%           -MountBaker3km_ul.in
%           -MountBaker3km_ul.out
%           -MountBaker3km_ll.in
%           -MountBaker3km_ll.out
%
% NOTE: 
% - Based on original files drafted by J. Ole Kaven
% 
% - Note specific paths to the folder containg p3d and to the folder
% containing this mfile are specified for running p3d and saving .in and
% .out files respectively
% 
% 
% KEY functions written specifically for this modeling
%
% Other related functions
% - p3din_FAULT_func_v1
%

clear all, close all

tic

%% 1. Define OBSERVATION GRID RANGES
% Generate observation grids in global coordinates.

% AREAL GRIDS: 2D

% Extent of WADGER thermal model
% User Coordinate System
x1o = 574990.317494;
x2o = 5383724.92181;
x3o = 0;
rot1 = 0;
rot2 = 0;
rot3 = [1.84761192547237];
CS_WADGER = [x1o, x2o, x3o, rot1, rot2, rot3, 123];% matrix used in p3din_FAULT_func_v1

% min/max values 1000ft spacing at 200m depth
minx = 0;  % min value of x
maxx = 32582.8545423913;  % max value of x
miny = 0;  % min value of y
maxy = 34714.6109179353; % max value of y
minz = -200;  % min value of z
maxz = -200;  % max value of z    
npx  = 108; % number of points corresponding to inc in each dimension
npy  = 115; % see also function: linspace
npz  = 1;
OBSgridWADGER200 = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1
minz = -3000;  % min value of z
maxz = -3000;  % max value of z
OBSgridWADGER3km = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1

%% 2. Define Boundary Conditions to run

% depth to water table(meters)
dw = 20;

% import stress tensor(s)
% 200m
Sigma200 = importdata('StressTensorMB200.csv',',');
d = .2;% depth km
Pp200 = (9.733*(d-(dw/1000)));
Pf200 = Pp200*1000000;% fluid pressure used in poly3D
% 3000m
Sigma3km = importdata('StressTensorMBV3km.csv',',');
d = 3;% depth km
Pp3km = (9.733*(d-(dw/1000)));
Pf3km = Pp3km*1000000;% fluid pressure used in poly3D

% Elastic Properties
nu = 0.25; % poisson's ratio
E = 30000000000; % Young's Modulus in Pa

% stress boundary of deformation source based on 420 nanostrain/yr
Tn_ul = (-.42+.14)*E;
Tn_ll = (-.42-.14)*E;
        
    %% 3. IMPORT FAULTS
    
% upper residuals
    
    % Straight Creek Fault
    XYZscf = xlsread('Straight_Creek_Fault_ul.xls','XYZscf','A2:C10000');
    tnscf = xlsread('Straight_Creek_Fault_ul.xls','tnscf','A1:C10000');

    % Anderson Creek Fault
    XYZacf_200m_ul = xlsread('Anderson_Creek_Fault_ul.xls','XYZacf_200m','A2:C10000');
    tnacf_200m_ul = xlsread('Anderson_Creek_Fault_ul.xls','tnacf_200m','A1:C10000');
    XYZacf_3km_ul = xlsread('Anderson_Creek_Fault_ul.xls','XYZacf_3km','A2:C10000');
    tnacf_3km_ul = xlsread('Anderson_Creek_Fault_ul.xls','tnacf_3km','A1:C10000');
    
    % Darrington-Devils Mountain Fault
    XYZddmf = xlsread('Darrington-Devils_Mountain_Fault.xls','XYZddmf','A2:C10000');
    tnddmf = xlsread('Darrington-Devils_Mountain_Fault.xls','tnddmf','A1:C10000');

    % Twin Sisters Mountain Fault
    XYZtsmf_200m_ul = xlsread('Sisters_Mountain_Fault_ul.xls','XYZtsmf_200m','A2:C10000');
    tntsmf_200m_ul = xlsread('Sisters_Mountain_Fault_ul.xls','tntsmf_200m','A1:C10000');
    XYZtsmf_3km_ul = xlsread('Sisters_Mountain_Fault_ul.xls','XYZtsmf_3km','A2:C10000');
    tntsmf_3km_ul = xlsread('Sisters_Mountain_Fault_ul.xls','tntsmf_3km','A1:C10000');
    
    % Rocky Creek Fault
    XYZrcf_200m_ul = xlsread('Rocky_Creek_Fault_ul.xls','XYZrcf_200m','A2:C10000');
    tnrcf_200m_ul = xlsread('Rocky_Creek_Fault_ul.xls','tnrcf_200m','A1:C10000');
    XYZrcf_3km_ul = xlsread('Rocky_Creek_Fault_ul.xls','XYZrcf_3km','A2:C10000');
    tnrcf_3km_ul = xlsread('Rocky_Creek_Fault_ul.xls','tnrcf_3km','A1:C10000');
    
    % Baker Lake Fault
    XYZblf_200m_ul = xlsread('Baker_Lake_Fault_ul.xls','XYZblf_200m','A2:C10000');
    tnblf_200m_ul = xlsread('Baker_Lake_Fault_ul.xls','tnblf_200m','A1:C10000');
    XYZblf_3km_ul = xlsread('Baker_Lake_Fault_ul.xls','XYZblf_3km','A2:C10000');
    tnblf_3km_ul = xlsread('Baker_Lake_Fault_ul.xls','tnblf_3km','A1:C10000');
    
    % Mount Watson Fault
    XYZmwf_200m_ul = xlsread('Mount_Watson_Fault_ul.xls','XYZmwf_200m','A2:C10000');
    tnmwf_200m_ul = xlsread('Mount_Watson_Fault_ul.xls','tnmwf_200m','A1:C10000');
    XYZmwf_3km_ul = xlsread('Mount_Watson_Fault_ul.xls','XYZmwf_3km','A2:C10000');
    tnmwf_3km_ul = xlsread('Mount_Watson_Fault_ul.xls','tnmwf_3km','A1:C10000');
    
    % Rainbow Creek Fault
    XYZracf_200m_ul = xlsread('Rainbow_Creek_Fault_ul.xls','XYZracf_200m','A2:C10000');
    tnracf_200m_ul = xlsread('Rainbow_Creek_Fault_ul.xls','tnracf_200m','A1:C10000');
    XYZracf_3km_ul = xlsread('Rainbow_Creek_Fault_ul.xls','XYZracf_3km','A2:C10000');
    tnracf_3km_ul = xlsread('Rainbow_Creek_Fault_ul.xls','tnracf_3km','A1:C10000');
    
    % Swift Creek Fault
    XYZscf1_200m_ul = xlsread('Swift_Creek_Fault_ul.xls','XYZscf1_200m','A2:C10000');
    tnscf1_200m_ul = xlsread('Swift_Creek_Fault_ul.xls','tnscf1_200m','A1:C10000');
    XYZscf1_3km_ul = xlsread('Swift_Creek_Fault_ul.xls','XYZscf1_3km','A2:C10000');
    tnscf1_3km_ul = xlsread('Swift_Creek_Fault_ul.xls','tnscf1_3km','A1:C10000');
    XYZscf2_200m_ul = xlsread('Swift_Creek_Fault_ul.xls','XYZscf2_200m','A2:C10000');
    tnscf2_200m_ul = xlsread('Swift_Creek_Fault_ul.xls','tnscf2_200m','A1:C10000');
    XYZscf2_3km_ul = xlsread('Swift_Creek_Fault_ul.xls','XYZscf2_3km','A2:C10000');
    tnscf2_3km_ul = xlsread('Swift_Creek_Fault_ul.xls','tnscf2_3km','A1:C10000');
    XYZscf3_200m_ul = xlsread('Swift_Creek_Fault_ul.xls','XYZscf3_200m','A2:C10000');
    tnscf3_200m_ul = xlsread('Swift_Creek_Fault_ul.xls','tnscf3_200m','A1:C10000');
    XYZscf3_3km_ul = xlsread('Swift_Creek_Fault_ul.xls','XYZscf3_3km','A2:C10000');
    tnscf3_3km_ul = xlsread('Swift_Creek_Fault_ul.xls','tnscf3_3km','A1:C10000');
    
    % Damfino Fault
    XYZdf_200m_ul = xlsread('Damfino_Fault_ul.xls','XYZdf_200m','A2:C10000');
    tndf_200m_ul = xlsread('Damfino_Fault_ul.xls','tndf_200m','A1:C10000');
    XYZdf_3km_ul = xlsread('Damfino_Fault_ul.xls','XYZdf_3km','A2:C10000');
    tndf_3km_ul = xlsread('Damfino_Fault_ul.xls','tndf_3km','A1:C10000');
    
    % Slate Mountain Fault
    XYZsmf_200m_ul = xlsread('Slate_Mountain_Fault_ul.xls','XYZsmf_200m','A2:C10000');
    tnsmf_200m_ul = xlsread('Slate_Mountain_Fault_ul.xls','tnsmf_200m','A1:C10000');
    XYZsmf_3km_ul = xlsread('Slate_Mountain_Fault_ul.xls','XYZsmf_3km','A2:C10000');
    tnsmf_3km_ul = xlsread('Slate_Mountain_Fault_ul.xls','tnsmf_3km','A1:C10000');
    
    % Barometer Mountain Fault
    XYZbmf_200m_ul = xlsread('Barometer_Mountain_Fault_ul.xls','XYZbmf_200m','A2:C10000');
    tnbmf_200m_ul = xlsread('Barometer_Mountain_Fault_ul.xls','tnbmf_200m','A1:C10000');
    XYZbmf_3km_ul = xlsread('Barometer_Mountain_Fault_ul.xls','XYZbmf_3km','A2:C10000');
    tnbmf_3km_ul = xlsread('Barometer_Mountain_Fault_ul.xls','tnbmf_3km','A1:C10000');
    
    % Table Mountain Fault
    XYZtmf_200m_ul = xlsread('Table_Mountain_Fault_ul.xls','XYZtmf_200m','A2:C10000');
    tntmf_200m_ul = xlsread('Table_Mountain_Fault_ul.xls','tntmf_200m','A1:C10000');
    XYZtmf_3km_ul = xlsread('Table_Mountain_Fault_ul.xls','XYZtmf_3km','A2:C10000');
    tntmf_3km_ul = xlsread('Table_Mountain_Fault_ul.xls','tntmf_3km','A1:C10000');
    
    % Winchester Fault
    XYZwf_200m_ul = xlsread('Winchester_Fault_ul.xls','XYZwf_200m','A2:C10000');
    tnwf_200m_ul = xlsread('Winchester_Fault_ul.xls','tnwf_200m','A1:C10000');
    XYZwf_3km_ul = xlsread('Winchester_Fault_ul.xls','XYZwf_3km','A2:C10000');
    tnwf_3km_ul = xlsread('Winchester_Fault_ul.xls','tnwf_3km','A1:C10000');
    
    % Nooksack River Fault
    XYZnrf1_200m_ul = xlsread('Nooksack_River_Fault_ul.xls','XYZnrf1_200m','A2:C10000');
    tnnrf1_200m_ul = xlsread('Nooksack_River_Fault_ul.xls','tnnrf1_200m','A1:C10000');
    XYZnrf1_3km_ul = xlsread('Nooksack_River_Fault_ul.xls','XYZnrf1_3km','A2:C10000');
    tnnrf1_3km_ul = xlsread('Nooksack_River_Fault_ul.xls','tnnrf1_3km','A1:C10000');
    XYZnrf2_200m_ul = xlsread('Nooksack_River_Fault_ul.xls','XYZnrf2_200m','A2:C10000');
    tnnrf2_200m_ul = xlsread('Nooksack_River_Fault_ul.xls','tnnrf2_200m','A1:C10000');
    XYZnrf2_3km_ul = xlsread('Nooksack_River_Fault_ul.xls','XYZnrf2_3km','A2:C10000');
    tnnrf2_3km_ul = xlsread('Nooksack_River_Fault_ul.xls','tnnrf2_3km','A1:C10000');
    XYZnrf3a_200m_ul = xlsread('Nooksack_River_Fault_ul.xls','XYZnrf3a_200m','A2:C10000');
    tnnrf3a_200m_ul = xlsread('Nooksack_River_Fault_ul.xls','tnnrf3a_200m','A1:C10000');
    XYZnrf3a_3km_ul = xlsread('Nooksack_River_Fault_ul.xls','XYZnrf3a_3km','A2:C10000');
    tnnrf3a_3km_ul = xlsread('Nooksack_River_Fault_ul.xls','tnnrf3a_3km','A1:C10000');
    XYZnrf3b_200m_ul = xlsread('Nooksack_River_Fault_ul.xls','XYZnrf3b_200m','A2:C10000');
    tnnrf3b_200m_ul = xlsread('Nooksack_River_Fault_ul.xls','tnnrf3b_200m','A1:C10000');
    XYZnrf3b_3km_ul = xlsread('Nooksack_River_Fault_ul.xls','XYZnrf3b_3km','A2:C10000');
    tnnrf3b_3km_ul = xlsread('Nooksack_River_Fault_ul.xls','tnnrf3b_3km','A1:C10000');
    
    % Thompson Creek Fault
    XYZtcf_200m_ul = xlsread('Thompson_Creek_Fault_ul.xls','XYZtcf_200m','A2:C10000');
    tntcf_200m_ul = xlsread('Thompson_Creek_Fault_ul.xls','tntcf_200m','A1:C10000');
    XYZtcf_3km_ul = xlsread('Thompson_Creek_Fault_ul.xls','XYZtcf_3km','A2:C10000');
    tntcf_3km_ul = xlsread('Thompson_Creek_Fault_ul.xls','tntcf_3km','A1:C10000');
    
    % Gallop Creek Fault
    XYZgcf_200m_ul = xlsread('Gallop_Creek_Fault_ul.xls','XYZgcf_200m','A2:C10000');
    tngcf_200m_ul = xlsread('Gallop_Creek_Fault_ul.xls','tngcf_200m','A1:C10000');
    XYZgcf_3km_ul = xlsread('Gallop_Creek_Fault_ul.xls','XYZgcf_3km','A2:C10000');
    tngcf_3km_ul = xlsread('Gallop_Creek_Fault_ul.xls','tngcf_3km','A1:C10000');
    
    % Warm Creek Fault
    XYZwcf1_200m_ul = xlsread('Warm_Creek_Fault_ul.xls','XYZwcf1_200m','A2:C10000');
    tnwcf1_200m_ul = xlsread('Warm_Creek_Fault_ul.xls','tnwcf1_200m','A1:C10000');
    XYZwcf1_3km_ul = xlsread('Warm_Creek_Fault_ul.xls','XYZwcf1_3km','A2:C10000');
    tnwcf1_3km_ul = xlsread('Warm_Creek_Fault_ul.xls','tnwcf1_3km','A1:C10000');
    XYZwcf2_200m_ul = xlsread('Warm_Creek_Fault_ul.xls','XYZwcf2_200m','A2:C10000');
    tnwcf2_200m_ul = xlsread('Warm_Creek_Fault_ul.xls','tnwcf2_200m','A1:C10000');
    XYZwcf2_3km_ul = xlsread('Warm_Creek_Fault_ul.xls','XYZwcf2_3km','A2:C10000');
    tnwcf2_3km_ul = xlsread('Warm_Creek_Fault_ul.xls','tnwcf2_3km','A1:C10000');
    
    % Loomis Mountain Fault
    XYZlmf_200m_ul = xlsread('Loomis_Mountain_Fault_ul.xls','XYZlmf_200m','A2:C10000');
    tnlmf_200m_ul = xlsread('Loomis_Mountain_Fault_ul.xls','tnlmf_200m','A1:C10000');
    XYZlmf_3km_ul = xlsread('Loomis_Mountain_Fault_ul.xls','XYZlmf_3km','A2:C10000');
    tnlmf_3km_ul = xlsread('Loomis_Mountain_Fault_ul.xls','tnlmf_3km','A1:C10000');
    
    % Wanlick Creek Fault
    XYZwcf_200m_ul = xlsread('Wanlick_Creek_Fault_ul.xls','XYZwcf_200m','A2:C10000');
    tnwcf_200m_ul = xlsread('Wanlick_Creek_Fault_ul.xls','tnwcf_200m','A1:C10000');
    XYZwcf_3km_ul = xlsread('Wanlick_Creek_Fault_ul.xls','XYZwcf_3km','A2:C10000');
    tnwcf_3km_ul = xlsread('Wanlick_Creek_Fault_ul.xls','tnwcf_3km','A1:C10000');
    
    % Chilliwack River Fault
    XYZcrf_200m_ul = xlsread('Chilliwack_River_Fault_ul.xls','XYZcrf_200m','A2:C10000');
    tncrf_200m_ul = xlsread('Chilliwack_River_Fault_ul.xls','tncrf_200m','A1:C10000');
    XYZcrf_3km_ul = xlsread('Chilliwack_River_Fault_ul.xls','XYZcrf_3km','A2:C10000');
    tncrf_3km_ul = xlsread('Chilliwack_River_Fault_ul.xls','tncrf_3km','A1:C10000');
    
    % Ruth Creek Fault
    XYZrcf1_200m_ul = xlsread('Ruth_Creek_Fault_ul.xls','XYZrcf1_200m','A2:C10000');
    tnrcf1_200m_ul = xlsread('Ruth_Creek_Fault_ul.xls','tnrcf1_200m','A1:C10000');
    XYZrcf1_3km_ul = xlsread('Ruth_Creek_Fault_ul.xls','XYZrcf1_3km','A2:C10000');
    tnrcf1_3km_ul = xlsread('Ruth_Creek_Fault_ul.xls','tnrcf1_3km','A1:C10000');
    XYZrcf2_200m_ul = xlsread('Ruth_Creek_Fault_ul.xls','XYZrcf2_200m','A2:C10000');
    tnrcf2_200m_ul = xlsread('Ruth_Creek_Fault_ul.xls','tnrcf2_200m','A1:C10000');
    XYZrcf2_3km_ul = xlsread('Ruth_Creek_Fault_ul.xls','XYZrcf2_3km','A2:C10000');
    tnrcf2_3km_ul = xlsread('Ruth_Creek_Fault_ul.xls','tnrcf2_3km','A1:C10000');
    
    % Glacier Extensional Fault
    XYZgex1_200m_ul = xlsread('Glacier_Extensional_Fault_ul.xls','XYZgex1_200m','A2:C10000');
    tngex1_200m_ul = xlsread('Glacier_Extensional_Fault_ul.xls','tngex1_200m','A1:C10000');
    XYZgex1_3km_ul = xlsread('Glacier_Extensional_Fault_ul.xls','XYZgex1_3km','A2:C10000');
    tngex1_3km_ul = xlsread('Glacier_Extensional_Fault_ul.xls','tngex1_3km','A1:C10000');
    XYZgex2_200m_ul = xlsread('Glacier_Extensional_Fault_ul.xls','XYZgex2_200m','A2:C10000');
    tngex2_200m_ul = xlsread('Glacier_Extensional_Fault_ul.xls','tngex2_200m','A1:C10000');
    XYZgex2_3km_ul = xlsread('Glacier_Extensional_Fault_ul.xls','XYZgex2_3km','A2:C10000');
    tngex2_3km_ul = xlsread('Glacier_Extensional_Fault_ul.xls','tngex2_3km','A1:C10000');
    
    % Thunder Creek Fault
    XYZthcf_200m_ul = xlsread('Thunder_Creek_Fault_ul.xls','XYZthcf_200m','A2:C10000');
    tnthcf_200m_ul = xlsread('Thunder_Creek_Fault_ul.xls','tnthcf_200m','A1:C10000');
    XYZthcf_3km_ul = xlsread('Thunder_Creek_Fault_ul.xls','XYZthcf_3km','A2:C10000');
    tnthcf_3km_ul = xlsread('Thunder_Creek_Fault_ul.xls','tnthcf_3km','A1:C10000');
    
    % South Fork Fault
    XYZsff_200m_ul = xlsread('South_Fork_Fault_ul.xls','XYZsff_200m','A2:C10000');
    tnsff_200m_ul = xlsread('South_Fork_Fault_ul.xls','tnsff_200m','A1:C10000');
    XYZsff_3km_ul = xlsread('South_Fork_Fault_ul.xls','XYZsff_3km','A2:C10000');
    tnsff_3km_ul = xlsread('South_Fork_Fault_ul.xls','tnsff_3km','A1:C10000');
    
    % North Fork Fault
    XYZnff_200m_ul = xlsread('North_Fork_Fault_ul.xls','XYZnff_200m','A2:C10000');
    tnnff_200m_ul = xlsread('North_Fork_Fault_ul.xls','tnnff_200m','A1:C10000');
    XYZnff_3km_ul = xlsread('North_Fork_Fault_ul.xls','XYZnff_3km','A2:C10000');
    tnnff_3km_ul = xlsread('North_Fork_Fault_ul.xls','tnnff_3km','A1:C10000');
    
    % Mount Baker Point Source Deformation
    XYZpsd = xlsread('MtBaker_point_source_deformation.xls','XYZpsd','A2:C10000');
    tnpsd = xlsread('MtBaker_point_source_deformation.xls','tnpsd','A1:C10000');
    
% lower residuals
    
    % Straight Creek Fault
    XYZscf = xlsread('Straight_Creek_Fault.xls','XYZscf','A2:C10000');
    tnscf = xlsread('Straight_Creek_Fault.xls','tnscf','A1:C10000');

    % Anderson Creek Fault
    XYZacf_200m = xlsread('Anderson_Creek_Fault.xls','XYZacf_200m','A2:C10000');
    tnacf_200m = xlsread('Anderson_Creek_Fault.xls','tnacf_200m','A1:C10000');
    XYZacf_3km = xlsread('Anderson_Creek_Fault.xls','XYZacf_3km','A2:C10000');
    tnacf_3km = xlsread('Anderson_Creek_Fault.xls','tnacf_3km','A1:C10000');
    
    % Darrington-Devils Mountain Fault
    XYZddmf = xlsread('Darrington-Devils_Mountain_Fault.xls','XYZddmf','A2:C10000');
    tnddmf = xlsread('Darrington-Devils_Mountain_Fault.xls','tnddmf','A1:C10000');

    % Twin Sisters Mountain Fault
    XYZtsmf_200m = xlsread('Sisters_Mountain_Fault.xls','XYZtsmf_200m','A2:C10000');
    tntsmf_200m = xlsread('Sisters_Mountain_Fault.xls','tntsmf_200m','A1:C10000');
    XYZtsmf_3km = xlsread('Sisters_Mountain_Fault.xls','XYZtsmf_3km','A2:C10000');
    tntsmf_3km = xlsread('Sisters_Mountain_Fault.xls','tntsmf_3km','A1:C10000');
    
    % Rocky Creek Fault
    XYZrcf_200m = xlsread('Rocky_Creek_Fault.xls','XYZrcf_200m','A2:C10000');
    tnrcf_200m = xlsread('Rocky_Creek_Fault.xls','tnrcf_200m','A1:C10000');
    XYZrcf_3km = xlsread('Rocky_Creek_Fault.xls','XYZrcf_3km','A2:C10000');
    tnrcf_3km = xlsread('Rocky_Creek_Fault.xls','tnrcf_3km','A1:C10000');
    
    % Baker Lake Fault
    XYZblf_200m = xlsread('Baker_Lake_Fault.xls','XYZblf_200m','A2:C10000');
    tnblf_200m = xlsread('Baker_Lake_Fault.xls','tnblf_200m','A1:C10000');
    XYZblf_3km = xlsread('Baker_Lake_Fault.xls','XYZblf_3km','A2:C10000');
    tnblf_3km = xlsread('Baker_Lake_Fault.xls','tnblf_3km','A1:C10000');
    
    % Mount Watson Fault
    XYZmwf_200m = xlsread('Mount_Watson_Fault.xls','XYZmwf_200m','A2:C10000');
    tnmwf_200m = xlsread('Mount_Watson_Fault.xls','tnmwf_200m','A1:C10000');
    XYZmwf_3km = xlsread('Mount_Watson_Fault.xls','XYZmwf_3km','A2:C10000');
    tnmwf_3km = xlsread('Mount_Watson_Fault.xls','tnmwf_3km','A1:C10000');
    
    % Rainbow Creek Fault
    XYZracf_200m = xlsread('Rainbow_Creek_Fault.xls','XYZracf_200m','A2:C10000');
    tnracf_200m = xlsread('Rainbow_Creek_Fault.xls','tnracf_200m','A1:C10000');
    XYZracf_3km = xlsread('Rainbow_Creek_Fault.xls','XYZracf_3km','A2:C10000');
    tnracf_3km = xlsread('Rainbow_Creek_Fault.xls','tnracf_3km','A1:C10000');
    
    % Swift Creek Fault
    XYZscf1_200m = xlsread('Swift_Creek_Fault.xls','XYZscf1_200m','A2:C10000');
    tnscf1_200m = xlsread('Swift_Creek_Fault.xls','tnscf1_200m','A1:C10000');
    XYZscf1_3km = xlsread('Swift_Creek_Fault.xls','XYZscf1_3km','A2:C10000');
    tnscf1_3km = xlsread('Swift_Creek_Fault.xls','tnscf1_3km','A1:C10000');
    XYZscf2_200m = xlsread('Swift_Creek_Fault.xls','XYZscf2_200m','A2:C10000');
    tnscf2_200m = xlsread('Swift_Creek_Fault.xls','tnscf2_200m','A1:C10000');
    XYZscf2_3km = xlsread('Swift_Creek_Fault.xls','XYZscf2_3km','A2:C10000');
    tnscf2_3km = xlsread('Swift_Creek_Fault.xls','tnscf2_3km','A1:C10000');
    XYZscf3_200m = xlsread('Swift_Creek_Fault.xls','XYZscf3_200m','A2:C10000');
    tnscf3_200m = xlsread('Swift_Creek_Fault.xls','tnscf3_200m','A1:C10000');
    XYZscf3_3km = xlsread('Swift_Creek_Fault.xls','XYZscf3_3km','A2:C10000');
    tnscf3_3km = xlsread('Swift_Creek_Fault.xls','tnscf3_3km','A1:C10000');
    
    % Damfino Fault
    XYZdf_200m = xlsread('Damfino_Fault.xls','XYZdf_200m','A2:C10000');
    tndf_200m = xlsread('Damfino_Fault.xls','tndf_200m','A1:C10000');
    XYZdf_3km = xlsread('Damfino_Fault.xls','XYZdf_3km','A2:C10000');
    tndf_3km = xlsread('Damfino_Fault.xls','tndf_3km','A1:C10000');
    
    % Slate Mountain Fault
    XYZsmf_200m = xlsread('Slate_Mountain_Fault.xls','XYZsmf_200m','A2:C10000');
    tnsmf_200m = xlsread('Slate_Mountain_Fault.xls','tnsmf_200m','A1:C10000');
    XYZsmf_3km = xlsread('Slate_Mountain_Fault.xls','XYZsmf_3km','A2:C10000');
    tnsmf_3km = xlsread('Slate_Mountain_Fault.xls','tnsmf_3km','A1:C10000');
    
    % Barometer Mountain Fault
    XYZbmf_200m = xlsread('Barometer_Mountain_Fault.xls','XYZbmf_200m','A2:C10000');
    tnbmf_200m = xlsread('Barometer_Mountain_Fault.xls','tnbmf_200m','A1:C10000');
    XYZbmf_3km = xlsread('Barometer_Mountain_Fault.xls','XYZbmf_3km','A2:C10000');
    tnbmf_3km = xlsread('Barometer_Mountain_Fault.xls','tnbmf_3km','A1:C10000');
    
    % Table Mountain Fault
    XYZtmf_200m = xlsread('Table_Mountain_Fault.xls','XYZtmf_200m','A2:C10000');
    tntmf_200m = xlsread('Table_Mountain_Fault.xls','tntmf_200m','A1:C10000');
    XYZtmf_3km = xlsread('Table_Mountain_Fault.xls','XYZtmf_3km','A2:C10000');
    tntmf_3km = xlsread('Table_Mountain_Fault.xls','tntmf_3km','A1:C10000');
    
    % Winchester Fault
    XYZwf_200m = xlsread('Winchester_Fault.xls','XYZwf_200m','A2:C10000');
    tnwf_200m = xlsread('Winchester_Fault.xls','tnwf_200m','A1:C10000');
    XYZwf_3km = xlsread('Winchester_Fault.xls','XYZwf_3km','A2:C10000');
    tnwf_3km = xlsread('Winchester_Fault.xls','tnwf_3km','A1:C10000');
    
    % Nooksack River Fault
    XYZnrf1_200m = xlsread('Nooksack_River_Fault.xls','XYZnrf1_200m','A2:C10000');
    tnnrf1_200m = xlsread('Nooksack_River_Fault.xls','tnnrf1_200m','A1:C10000');
    XYZnrf1_3km = xlsread('Nooksack_River_Fault.xls','XYZnrf1_3km','A2:C10000');
    tnnrf1_3km = xlsread('Nooksack_River_Fault.xls','tnnrf1_3km','A1:C10000');
    XYZnrf2_200m = xlsread('Nooksack_River_Fault.xls','XYZnrf2_200m','A2:C10000');
    tnnrf2_200m = xlsread('Nooksack_River_Fault.xls','tnnrf2_200m','A1:C10000');
    XYZnrf2_3km = xlsread('Nooksack_River_Fault.xls','XYZnrf2_3km','A2:C10000');
    tnnrf2_3km = xlsread('Nooksack_River_Fault.xls','tnnrf2_3km','A1:C10000');
    XYZnrf3a_200m = xlsread('Nooksack_River_Fault.xls','XYZnrf3a_200m','A2:C10000');
    tnnrf3a_200m = xlsread('Nooksack_River_Fault.xls','tnnrf3a_200m','A1:C10000');
    XYZnrf3a_3km = xlsread('Nooksack_River_Fault.xls','XYZnrf3a_3km','A2:C10000');
    tnnrf3a_3km = xlsread('Nooksack_River_Fault.xls','tnnrf3a_3km','A1:C10000');
    XYZnrf3b_200m = xlsread('Nooksack_River_Fault.xls','XYZnrf3b_200m','A2:C10000');
    tnnrf3b_200m = xlsread('Nooksack_River_Fault.xls','tnnrf3b_200m','A1:C10000');
    XYZnrf3b_3km = xlsread('Nooksack_River_Fault.xls','XYZnrf3b_3km','A2:C10000');
    tnnrf3b_3km = xlsread('Nooksack_River_Fault.xls','tnnrf3b_3km','A1:C10000');
    
    % Thompson Creek Fault
    XYZtcf_200m = xlsread('Thompson_Creek_Fault.xls','XYZtcf_200m','A2:C10000');
    tntcf_200m = xlsread('Thompson_Creek_Fault.xls','tntcf_200m','A1:C10000');
    XYZtcf_3km = xlsread('Thompson_Creek_Fault.xls','XYZtcf_3km','A2:C10000');
    tntcf_3km = xlsread('Thompson_Creek_Fault.xls','tntcf_3km','A1:C10000');
    
    % Gallop Creek Fault
    XYZgcf_200m = xlsread('Gallop_Creek_Fault.xls','XYZgcf_200m','A2:C10000');
    tngcf_200m = xlsread('Gallop_Creek_Fault.xls','tngcf_200m','A1:C10000');
    XYZgcf_3km = xlsread('Gallop_Creek_Fault.xls','XYZgcf_3km','A2:C10000');
    tngcf_3km = xlsread('Gallop_Creek_Fault.xls','tngcf_3km','A1:C10000');
    
    % Warm Creek Fault
    XYZwcf1_200m = xlsread('Warm_Creek_Fault.xls','XYZwcf1_200m','A2:C10000');
    tnwcf1_200m = xlsread('Warm_Creek_Fault.xls','tnwcf1_200m','A1:C10000');
    XYZwcf1_3km = xlsread('Warm_Creek_Fault.xls','XYZwcf1_3km','A2:C10000');
    tnwcf1_3km = xlsread('Warm_Creek_Fault.xls','tnwcf1_3km','A1:C10000');
    XYZwcf2_200m = xlsread('Warm_Creek_Fault.xls','XYZwcf2_200m','A2:C10000');
    tnwcf2_200m = xlsread('Warm_Creek_Fault.xls','tnwcf2_200m','A1:C10000');
    XYZwcf2_3km = xlsread('Warm_Creek_Fault.xls','XYZwcf2_3km','A2:C10000');
    tnwcf2_3km = xlsread('Warm_Creek_Fault.xls','tnwcf2_3km','A1:C10000');
    
    % Loomis Mountain Fault
    XYZlmf_200m = xlsread('Loomis_Mountain_Fault.xls','XYZlmf_200m','A2:C10000');
    tnlmf_200m = xlsread('Loomis_Mountain_Fault.xls','tnlmf_200m','A1:C10000');
    XYZlmf_3km = xlsread('Loomis_Mountain_Fault.xls','XYZlmf_3km','A2:C10000');
    tnlmf_3km = xlsread('Loomis_Mountain_Fault.xls','tnlmf_3km','A1:C10000');
    
    % Wanlick Creek Fault
    XYZwcf_200m = xlsread('Wanlick_Creek_Fault.xls','XYZwcf_200m','A2:C10000');
    tnwcf_200m = xlsread('Wanlick_Creek_Fault.xls','tnwcf_200m','A1:C10000');
    XYZwcf_3km = xlsread('Wanlick_Creek_Fault.xls','XYZwcf_3km','A2:C10000');
    tnwcf_3km = xlsread('Wanlick_Creek_Fault.xls','tnwcf_3km','A1:C10000');
    
    % Chilliwack River Fault
    XYZcrf_200m = xlsread('Chilliwack_River_Fault.xls','XYZcrf_200m','A2:C10000');
    tncrf_200m = xlsread('Chilliwack_River_Fault.xls','tncrf_200m','A1:C10000');
    XYZcrf_3km = xlsread('Chilliwack_River_Fault.xls','XYZcrf_3km','A2:C10000');
    tncrf_3km = xlsread('Chilliwack_River_Fault.xls','tncrf_3km','A1:C10000');
    
    % Ruth Creek Fault
    XYZrcf1_200m = xlsread('Ruth_Creek_Fault.xls','XYZrcf1_200m','A2:C10000');
    tnrcf1_200m = xlsread('Ruth_Creek_Fault.xls','tnrcf1_200m','A1:C10000');
    XYZrcf1_3km = xlsread('Ruth_Creek_Fault.xls','XYZrcf1_3km','A2:C10000');
    tnrcf1_3km = xlsread('Ruth_Creek_Fault.xls','tnrcf1_3km','A1:C10000');
    XYZrcf2_200m = xlsread('Ruth_Creek_Fault.xls','XYZrcf2_200m','A2:C10000');
    tnrcf2_200m = xlsread('Ruth_Creek_Fault.xls','tnrcf2_200m','A1:C10000');
    XYZrcf2_3km = xlsread('Ruth_Creek_Fault.xls','XYZrcf2_3km','A2:C10000');
    tnrcf2_3km = xlsread('Ruth_Creek_Fault.xls','tnrcf2_3km','A1:C10000');
    
    % Glacier Extensional Fault
    XYZgex1_200m = xlsread('Glacier_Extensional_Fault.xls','XYZgex1_200m','A2:C10000');
    tngex1_200m = xlsread('Glacier_Extensional_Fault.xls','tngex1_200m','A1:C10000');
    XYZgex1_3km = xlsread('Glacier_Extensional_Fault.xls','XYZgex1_3km','A2:C10000');
    tngex1_3km = xlsread('Glacier_Extensional_Fault.xls','tngex1_3km','A1:C10000');
    XYZgex2_200m = xlsread('Glacier_Extensional_Fault.xls','XYZgex2_200m','A2:C10000');
    tngex2_200m = xlsread('Glacier_Extensional_Fault.xls','tngex2_200m','A1:C10000');
    XYZgex2_3km = xlsread('Glacier_Extensional_Fault.xls','XYZgex2_3km','A2:C10000');
    tngex2_3km = xlsread('Glacier_Extensional_Fault.xls','tngex2_3km','A1:C10000');
    
    % Thunder Creek Fault
    XYZthcf_200m = xlsread('Thunder_Creek_Fault.xls','XYZthcf_200m','A2:C10000');
    tnthcf_200m = xlsread('Thunder_Creek_Fault.xls','tnthcf_200m','A1:C10000');
    XYZthcf_3km = xlsread('Thunder_Creek_Fault.xls','XYZthcf_3km','A2:C10000');
    tnthcf_3km = xlsread('Thunder_Creek_Fault.xls','tnthcf_3km','A1:C10000');
    
    % South Fork Fault
    XYZsff_200m = xlsread('South_Fork_Fault.xls','XYZsff_200m','A2:C10000');
    tnsff_200m = xlsread('South_Fork_Fault.xls','tnsff_200m','A1:C10000');
    XYZsff_3km = xlsread('South_Fork_Fault.xls','XYZsff_3km','A2:C10000');
    tnsff_3km = xlsread('South_Fork_Fault.xls','tnsff_3km','A1:C10000');
    
    % North Fork Fault
    XYZnff_200m = xlsread('North_Fork_Fault.xls','XYZnff_200m','A2:C10000');
    tnnff_200m = xlsread('North_Fork_Fault.xls','tnnff_200m','A1:C10000');
    XYZnff_3km = xlsread('North_Fork_Fault.xls','XYZnff_3km','A2:C10000');
    tnnff_3km = xlsread('North_Fork_Fault.xls','tnnff_3km','A1:C10000');
    
    % Mount Baker Point Source Deformation
    XYZpsd = xlsread('MtBaker_point_source_deformation.xls','XYZpsd','A2:C10000');
    tnpsd = xlsread('MtBaker_point_source_deformation.xls','tnpsd','A1:C10000');
    
    %% 4. RUN p3din_FAULT_v1.m to generate P3D input file and run P3D

    filename = 'MountBaker200_ul';
    path_in = 'InputOutputFiles/';
    filename_in  = [path_in,filename,'.in'];

        % p3din_FAULT_v1
        p3din_FAULT_func_v1_MB200m(E,nu,Sigma200,Pf200,Tn_ul,filename_in,XYZscf,XYZacf_200m,XYZddmf,XYZtsmf_200m,XYZrcf_200m,XYZblf_200m,XYZmwf_200m,XYZracf_200m,XYZscf1_200m,XYZscf2_200m,XYZscf3_200m,XYZdf_200m,XYZsmf_200m,XYZbmf_200m,XYZtmf_200m,XYZwf_200m,XYZnrf1_200m,XYZnrf2_200m,XYZnrf3a_200m,XYZnrf3b_200m,XYZtcf_200m,XYZgcf_200m,XYZwcf1_200m,XYZwcf2_200m,XYZlmf_200m,XYZwcf_200m,XYZcrf_200m,XYZrcf1_200m,XYZrcf2_200m,XYZgex1_200m,XYZgex2_200m,XYZthcf_200m,XYZsff_200m,XYZnff_200m,XYZpsd,tnscf,tnacf_200m,tnddmf,tntsmf_200m,tnrcf_200m,tnblf_200m,tnmwf_200m,tnracf_200m,tnscf1_200m,tnscf2_200m,tnscf3_200m,tndf_200m,tnsmf_200m,tnbmf_200m,tntmf_200m,tnwf_200m,tnnrf1_200m,tnnrf2_200m,tnnrf3a_200m,tnnrf3b_200m,tntcf_200m,tngcf_200m,tnwcf1_200m,tnwcf2_200m,tnlmf_200m,tnwcf_200m,tncrf_200m,tnrcf1_200m,tnrcf2_200m,tngex1_200m,tngex2_200m,tnthcf_200m,tnsff_200m,tnnff_200m,tnpsd,CS_WADGER,OBSgridWADGER200,OBSgridWADGER3km)
        
        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

    filename = 'MountBaker3km_ul';
    path_in = 'InputOutputFiles/';
    filename_in  = [path_in,filename,'.in'];

        % p3din_FAULT_v1
        p3din_FAULT_func_v1_MB3km(E,nu,Sigma3km,Pf3km,Tn_ul,filename_in,XYZscf,XYZacf_3km,XYZddmf,XYZtsmf_3km,XYZrcf_3km,XYZblf_3km,XYZmwf_3km,XYZracf_3km,XYZscf1_3km,XYZscf2_3km,XYZscf3_3km,XYZdf_3km,XYZsmf_3km,XYZbmf_3km,XYZtmf_3km,XYZwf_3km,XYZnrf1_3km,XYZnrf2_3km,XYZnrf3a_3km,XYZnrf3b_3km,XYZtcf_3km,XYZgcf_3km,XYZwcf1_3km,XYZwcf2_3km,XYZlmf_3km,XYZwcf_3km,XYZcrf_3km,XYZrcf1_3km,XYZrcf2_3km,XYZgex1_3km,XYZgex2_3km,XYZthcf_3km,XYZsff_3km,XYZnff_3km,XYZpsd,tnscf,tnacf_3km,tnddmf,tntsmf_3km,tnrcf_3km,tnblf_3km,tnmwf_3km,tnracf_3km,tnscf1_3km,tnscf2_3km,tnscf3_3km,tndf_3km,tnsmf_3km,tnbmf_3km,tntmf_3km,tnwf_3km,tnnrf1_3km,tnnrf2_3km,tnnrf3a_3km,tnnrf3b_3km,tntcf_3km,tngcf_3km,tnwcf1_3km,tnwcf2_3km,tnlmf_3km,tnwcf_3km,tncrf_3km,tnrcf1_3km,tnrcf2_3km,tngex1_3km,tngex2_3km,tnthcf_3km,tnsff_3km,tnnff_3km,tnpsd,CS_WADGER,OBSgridWADGER200,OBSgridWADGER3km)

        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

    filename = 'MountBaker200_ll';
    path_in = 'InputOutputFiles/';
    filename_in  = [path_in,filename,'.in'];

        % p3din_FAULT_v1
        p3din_FAULT_func_v1_MB200m(E,nu,Sigma200,Pf200,Tn_ll,filename_in,XYZscf,XYZacf_200m,XYZddmf,XYZtsmf_200m,XYZrcf_200m,XYZblf_200m,XYZmwf_200m,XYZracf_200m,XYZscf1_200m,XYZscf2_200m,XYZscf3_200m,XYZdf_200m,XYZsmf_200m,XYZbmf_200m,XYZtmf_200m,XYZwf_200m,XYZnrf1_200m,XYZnrf2_200m,XYZnrf3a_200m,XYZnrf3b_200m,XYZtcf_200m,XYZgcf_200m,XYZwcf1_200m,XYZwcf2_200m,XYZlmf_200m,XYZwcf_200m,XYZcrf_200m,XYZrcf1_200m,XYZrcf2_200m,XYZgex1_200m,XYZgex2_200m,XYZthcf_200m,XYZsff_200m,XYZnff_200m,XYZpsd,tnscf,tnacf_200m,tnddmf,tntsmf_200m,tnrcf_200m,tnblf_200m,tnmwf_200m,tnracf_200m,tnscf1_200m,tnscf2_200m,tnscf3_200m,tndf_200m,tnsmf_200m,tnbmf_200m,tntmf_200m,tnwf_200m,tnnrf1_200m,tnnrf2_200m,tnnrf3a_200m,tnnrf3b_200m,tntcf_200m,tngcf_200m,tnwcf1_200m,tnwcf2_200m,tnlmf_200m,tnwcf_200m,tncrf_200m,tnrcf1_200m,tnrcf2_200m,tngex1_200m,tngex2_200m,tnthcf_200m,tnsff_200m,tnnff_200m,tnpsd,CS_WADGER,OBSgridWADGER200,OBSgridWADGER3km)

        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

    filename = 'MountBaker3km_ll';
    path_in = 'InputOutputFiles/';
    filename_in  = [path_in,filename,'.in'];

        % p3din_FAULT_v1
        p3din_FAULT_func_v1_MB3km(E,nu,Sigma3km,Pf3km,Tn_ll,filename_in,XYZscf,XYZacf_3km,XYZddmf,XYZtsmf_3km,XYZrcf_3km,XYZblf_3km,XYZmwf_3km,XYZracf_3km,XYZscf1_3km,XYZscf2_3km,XYZscf3_3km,XYZdf_3km,XYZsmf_3km,XYZbmf_3km,XYZtmf_3km,XYZwf_3km,XYZnrf1_3km,XYZnrf2_3km,XYZnrf3a_3km,XYZnrf3b_3km,XYZtcf_3km,XYZgcf_3km,XYZwcf1_3km,XYZwcf2_3km,XYZlmf_3km,XYZwcf_3km,XYZcrf_3km,XYZrcf1_3km,XYZrcf2_3km,XYZgex1_3km,XYZgex2_3km,XYZthcf_3km,XYZsff_3km,XYZnff_3km,XYZpsd,tnscf,tnacf_3km,tnddmf,tntsmf_3km,tnrcf_3km,tnblf_3km,tnmwf_3km,tnracf_3km,tnscf1_3km,tnscf2_3km,tnscf3_3km,tndf_3km,tnsmf_3km,tnbmf_3km,tntmf_3km,tnwf_3km,tnnrf1_3km,tnnrf2_3km,tnnrf3a_3km,tnnrf3b_3km,tntcf_3km,tngcf_3km,tnwcf1_3km,tnwcf2_3km,tnlmf_3km,tnwcf_3km,tncrf_3km,tnrcf1_3km,tnrcf2_3km,tngex1_3km,tngex2_3km,tnthcf_3km,tnsff_3km,tnnff_3km,tnpsd,CS_WADGER,OBSgridWADGER200,OBSgridWADGER3km)

        %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

toc