% MB_PermeabilityModel_200m.m
%
% AUTHOR:           Michael Swyer
% DATE CREATED:     8/24/2015
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:
%   Read Poly3D .out file and process data for permeability potential
%         
% PURPOSE OF MODIFICATION:
%
% INPUT: Poly3D output file
%           MtBaker200m.out
% 
% OUTPUT:
%   fault/stress model outputs:
%           -FAULT_GRID: x, y, z, slip tendency, dilation tendency, displacement(m), displacement gradient(m/m)
%           -STRESS_GRID: x, y, z, maximum Coulomb shear stress(Pa), sigma3(Pa)
%   Permeability potential layers:
%           -Fault.sliptendency: x, y, z, slip tendency
%           -Fault.dilationtendency: x, y, z, dilation tendency
%           -Fault.displacement: x, y, z, normalized displacement
%           -Fault.displacementgradient: x, y, z, normalized displacement gradient
%           -Stress.MaximumCoulombShearStress: x, y, z, normalized maximum Coulomb shear stress
%           -Stress.Sigma3: x, y, z, normalized sigma 3
%
% NOTE: 
%
% KEY functions written specifically for this modeling
%
% Other related functions
% - p3doutputreader_v04
% - redblue

clear all;close all

filename = 'InputOutputFiles\MountBaker200.out';

out = p3doutputreader_v04(filename);
% Generates structured array including
%   FAULT OBJECTS
%   out.fault.xyz   = array of vertex locations
% 
%   out.fault.vert  = array of vertices
%                     [VERTNUM X1 X2 X3]
% 
%   out.fault.disp  = cell array contain displacements for each fault obj
%                     [ELT X1C X2C X3C B1 U1(+) U1(-) B2 U2(+) U2(-) B3 U3(+)]
%                     ELT = element number, for use in tri
%                     X1C, X2C, X3C = element centroid coordinates
%                     B1, B2, B3 are the burgers vectos components as
%                       (strike,dip,normal)
%                     Ui(+), Ui(-) = relative displacment at centroid
%
%   out.fault.tract = cell array contain tractions for each fault obj
%                     [ELT X1C X2C X3C T1 T2 T3]
%                     T1,T2,T3 are the traction components
%                       (strike,dip,normal)
%   out.fault.name  = cell array contain displacements for each fault obj
% 
%
%   OBSERVATION GRID
%   out.obs.xyz     = array containing the obs grid pts [X1,X2,X3]
%
%   out.obs.disp    = array containing displacements at obs pts
%                     [X1 X2 X3 U1 U2 U3]
%                     U1,U2,U3 = components of the displacement vector
%                     
%   out.obs.pstress = array containing principal stress and principal
%                     stress direcitons at obs pts
%                     [X1 X2 X3 N1 N2 N3 SIG1 N1 N2 N3 SIG2 N1 N2 N3 SIG3]
%                     SIG1,2,3 = principal stress components (tensoral
%                     convention) at each observation point
%                     N1,N2,N3 = principal stress direction vectors for the
%                       following principal stress in the array)
%
%   out.obs.stress  = array contain 
%                     [X1 X2 X3 SIG11 SIG22 SIG33 SIG12 SIG23 SIG13]
%                     SIG11,22,33,12,23,13 = stress tensor component at
%                     each observation point

Sigma200 = importdata('StressTensorMB200.csv',',');
[V,PS200] = eig(Sigma200);% PS200 = eigenvalues as principal stresses

%% Slip/Dilation Tendency/Displacement/Displacement Gradient

%%% 200m %%%
% Anderson Creek Fault
nvecacf = xlsread('Anderson_Creek_Fault.xls','nvecacf_200m','A2:C2000');
I = find(out.fault.disp{1,2}(:,4)<-90&out.fault.disp{1,2}(:,4)>-210);
% Tractions
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,2}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecacf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecacf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STacf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTacf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispacf(i,1) = (out.fault.disp{1,2}(I(i),5)^2 + out.fault.disp{1,2}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STacf = STacf(I,1);
DTacf = DTacf(I,1);
Dispacf = Dispacf(I,1);
% Displacement Gradient
for i=1:length(I)
    if i==1
        dg(i,1) = Dispacf(i)/100;
    else
        dg(i,1) = abs(Dispacf(i)-Dispacf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispacf(i)/100;
for i=1:length(I)
    DGacf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Ltacf(:,1) = unique(J(:,1));
for i=1:length(Ltacf)
    I = find(J(:,1)==Ltacf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Ltacf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Ltacf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltacf(i,2) = J(I(K),2);
end


% Twin Sisters Mountain Fault
nvectsmf = xlsread('Sisters_Mountain_Fault.xls','nvectsmf_200m','A2:C6000');
I = find(out.fault.disp{1,4}(:,4)<-90&out.fault.disp{1,4}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,4}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvectsmf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectsmf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtsmf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtsmf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Disptsmf(i,1) = (out.fault.disp{1,4}(I(i),5)^2 + out.fault.disp{1,4}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtsmf = STtsmf(I,1);
DTtsmf = DTtsmf(I,1);
Disptsmf = Disptsmf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptsmf(i)/100;
    else
        dg(i,1) = abs(Disptsmf(i)-Disptsmf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptsmf(i)/100;
for i=1:length(I)
    DGtsmf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ltsmf(:,1) = unique(J(:,1));
for i=1:length(Ltsmf)
    I = find(J(:,1)==Ltsmf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Ltsmf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Ltsmf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltsmf(i,2) = J(I(K),2);
end


% Rocky Creek Fault
nvecracf = xlsread('Rocky_Creek_Fault.xls','nvecrcf_200m','A2:C6000');
I = find(out.fault.disp{1,5}(:,4)<-90&out.fault.disp{1,5}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,5}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecracf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecracf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STrcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTrcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Disprcf(i,1) = (out.fault.disp{1,5}(I(i),5)^2 + out.fault.disp{1,5}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STrcf = STrcf(I,1);
DTrcf = DTrcf(I,1);
Disprcf = Disprcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disprcf(i)/100;
    else
        dg(i,1) = abs(Disprcf(i)-Disprcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disprcf(i)/100;
for i=1:length(I)
    DGrcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf(:,1) = unique(J(:,1));
for i=1:length(Lrcf)
    I = find(J(:,1)==Lrcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lrcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lrcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf(i,2) = J(I(K),2);
end


% Baker Lake Fault
nvecblf = xlsread('Baker_Lake_Fault.xls','nvecrcf_200m','A2:C6000');
I = find(out.fault.disp{1,6}(:,4)<-90&out.fault.disp{1,6}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,6}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecblf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecblf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STblf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTblf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispblf(i,1) = (out.fault.disp{1,6}(I(i),5)^2 + out.fault.disp{1,6}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STblf = STblf(I,1);
DTblf = DTblf(I,1);
Dispblf = Dispblf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispblf(i)/100;
    else
        dg(i,1) = abs(Dispblf(i)-Dispblf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispblf(i)/100;
for i=1:length(I)
    DGblf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lblf(:,1) = unique(J(:,1));
for i=1:length(Lblf)
    I = find(J(:,1)==Lblf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lblf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lblf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lblf(i,2) = J(I(K),2);
end


% Mount Watson Fault
nvecmwf = xlsread('Mount_Watson_Fault.xls','nvecmwf_200m','A2:C6000');
I = find(out.fault.disp{1,7}(:,4)<-90&out.fault.disp{1,7}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,7}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecmwf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecmwf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STmwf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTmwf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispmwf(i,1) = (out.fault.disp{1,7}(I(i),5)^2 + out.fault.disp{1,7}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STmwf = STmwf(I,1);
DTmwf = DTmwf(I,1);
Dispmwf = Dispmwf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispmwf(i)/100;
    else
        dg(i,1) = abs(Dispmwf(i)-Dispmwf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispmwf(i)/100;
for i=1:length(I)
    DGmwf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lmwf(:,1) = unique(J(:,1));
for i=1:length(Lmwf)
    I = find(J(:,1)==Lmwf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lmwf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lmwf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lmwf(i,2) = J(I(K),2);
end


% Rainbow Creek Fault
nvecracf = xlsread('Rainbow_Creek_Fault','nvecracf_200m','A2:C6000');
I = find(out.fault.disp{1,8}(:,4)<-90&out.fault.disp{1,8}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,8}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecracf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecracf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STracf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTracf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispracf(i,1) = (out.fault.disp{1,8}(I(i),5)^2 + out.fault.disp{1,8}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STracf = STracf(I,1);
DTracf = DTracf(I,1);
Dispracf = Dispracf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispracf(i)/100;
    else
        dg(i,1) = abs(Dispracf(i)-Dispracf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispracf(i)/100;
for i=1:length(I)
    DGracf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lracf(:,1) = unique(J(:,1));
for i=1:length(Lracf)
    I = find(J(:,1)==Lracf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lracf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lracf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lracf(i,2) = J(I(K),2);
end


% Swift Creek Fault1
nvecscf1 = xlsread('Swift_Creek_Fault','nvecscf1_200m','A2:C6000');
I = find(out.fault.disp{1,9}(:,4)<-90&out.fault.disp{1,9}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,9}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecscf1(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecscf1(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STscf1(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTscf1(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispscf1(i,1) = (out.fault.disp{1,9}(I(i),5)^2 + out.fault.disp{1,9}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STscf1 = STscf1(I,1);
DTscf1 = DTscf1(I,1);
Dispscf1 = Dispscf1(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispscf1(i)/100;
    else
        dg(i,1) = abs(Dispscf1(i)-Dispscf1(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispscf1(i)/100;
for i=1:length(I)
    DGscf1(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lscf1(:,1) = unique(J(:,1));
for i=1:length(Lscf1)
    I = find(J(:,1)==Lscf1(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lscf1(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lscf1(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lscf1(i,2) = J(I(K),2);
end


% Swift Creek Fault 2
nvecscf2 = xlsread('Swift_Creek_Fault.xls','nvecscf2_200m','A2:C6000');
I = find(out.fault.disp{1,10}(:,4)<-90&out.fault.disp{1,10}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,10}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecscf2(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecscf2(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STscf2(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTscf2(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispscf2(i,1) = (out.fault.disp{1,10}(I(i),5)^2 + out.fault.disp{1,10}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STscf2 = STscf2(I,1);
DTscf2 = DTscf2(I,1);
Dispscf2 = Dispscf2(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispscf2(i)/100;
    else
        dg(i,1) = abs(Dispscf2(i)-Dispscf2(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispscf2(i)/100;
for i=1:length(I)
    DGscf2(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lscf2(:,1) = unique(J(:,1));
for i=1:length(Lscf2)
    I = find(J(:,1)==Lscf2(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lscf2(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lscf2(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lscf2(i,2) = J(I(K),2);
end


% Swift Creek Fault 3
nvecscf3 = xlsread('Swift_Creek_Fault.xls','nvecscf3_200m','A2:C6000');
I = find(out.fault.disp{1,11}(:,4)<-90&out.fault.disp{1,11}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,11}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecscf3(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecscf3(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STscf3(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTscf3(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispscf3(i,1) = (out.fault.disp{1,11}(I(i),5)^2 + out.fault.disp{1,11}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STscf3 = STscf3(I,1);
DTscf3 = DTscf3(I,1);
Dispscf3 = Dispscf3(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispscf3(i)/100;
    else
        dg(i,1) = abs(Dispscf3(i)-Dispscf3(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispscf3(i)/100;
for i=1:length(I)
    DGscf3(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lscf3(:,1) = unique(J(:,1));
for i=1:length(Lscf3)
    I = find(J(:,1)==Lscf3(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lscf3(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lscf3(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lscf3(i,2) = J(I(K),2);
end


% Damfino Fault
nvecdf = xlsread('Damfino_Fault.xls','nvecdf_200m','A2:C6000');
I = find(out.fault.disp{1,12}(:,4)<-90&out.fault.disp{1,12}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,12}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecdf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecdf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STdf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTdf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispdf(i,1) = (out.fault.disp{1,12}(I(i),5)^2 + out.fault.disp{1,12}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STdf = STdf(I,1);
DTdf = DTdf(I,1);
Dispdf = Dispdf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispdf(i)/100;
    else
        dg(i,1) = abs(Dispdf(i)-Dispdf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispdf(i)/100;
for i=1:length(I)
    DGdf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ldf(:,1) = unique(J(:,1));
for i=1:length(Ldf)
    I = find(J(:,1)==Ldf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Ldf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Ldf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ldf(i,2) = J(I(K),2);
end


% Slate Mountain Fault
nvecsmf = xlsread('Slate_Mountain_Fault.xls','nvecsmf_200m','A2:C6000');
I = find(out.fault.disp{1,13}(:,4)<-90&out.fault.disp{1,13}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,13}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecsmf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsmf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsmf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsmf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispsmf(i,1) = (out.fault.disp{1,13}(I(i),5)^2 + out.fault.disp{1,13}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsmf = STsmf(I,1);
DTsmf = DTsmf(I,1);
Dispsmf = Dispsmf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispsmf(i)/100;
    else
        dg(i,1) = abs(Dispsmf(i)-Dispsmf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispsmf(i)/100;
for i=1:length(I)
    DGsmf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lsmf(:,1) = unique(J(:,1));
for i=1:length(Lsmf)
    I = find(J(:,1)==Lsmf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lsmf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lsmf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsmf(i,2) = J(I(K),2);
end


% Barometer Mountain Fault
nvecbmf = xlsread('Barometer_Mountain_Fault.xls','nvecbmf_200m','A2:C6000');
I = find(out.fault.disp{1,14}(:,4)<-90&out.fault.disp{1,14}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,14}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbmf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbmf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbmf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbmf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbmf(i,1) = (out.fault.disp{1,14}(I(i),5)^2 + out.fault.disp{1,14}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbmf = STbmf(I,1);
DTbmf = DTbmf(I,1);
Dispbmf = Dispbmf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbmf(i)/100;
    else
        dg(i,1) = abs(Dispbmf(i)-Dispbmf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbmf(i)/100;
for i=1:length(I)
    DGbmf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbmf(:,1) = unique(J(:,1));
for i=1:length(Lbmf)
    I = find(J(:,1)==Lbmf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lbmf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lbmf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbmf(i,2) = J(I(K),2);
end


% Table Mountain Fault
nvectmf = xlsread('Table_Mountain_Fault.xls','nvectmf_200m','A2:C6000');
I = find(out.fault.disp{1,15}(:,4)<-90&out.fault.disp{1,15}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,15}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvectmf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectmf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtmf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtmf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Disptmf(i,1) = (out.fault.disp{1,15}(I(i),5)^2 + out.fault.disp{1,15}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtmf = STtmf(I,1);
DTtmf = DTtmf(I,1);
Disptmf = Disptmf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptmf(i)/100;
    else
        dg(i,1) = abs(Disptmf(i)-Disptmf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptmf(i)/100;
for i=1:length(I)
    DGtmf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ltmf(:,1) = unique(J(:,1));
for i=1:length(Ltmf)
    I = find(J(:,1)==Ltmf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Ltmf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Ltmf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltmf(i,2) = J(I(K),2);
end


% Winchester Fault
nvecwf = xlsread('Winchester_Fault.xls','nvecwf_200m','A2:C6000');
I = find(out.fault.disp{1,16}(:,4)<-90&out.fault.disp{1,16}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,16}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwf(i,1) = (out.fault.disp{1,16}(I(i),5)^2 + out.fault.disp{1,16}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwf = STwf(I,1);
DTwf = DTwf(I,1);
Dispwf = Dispwf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwf(i)/100;
    else
        dg(i,1) = abs(Dispwf(i)-Dispwf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwf(i)/100;
for i=1:length(I)
    DGwf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwf(:,1) = unique(J(:,1));
for i=1:length(Lwf)
    I = find(J(:,1)==Lwf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwf(i,2) = J(I(K),2);
end


% Nooksack River Fault 1
nvecnrf1 = xlsread('Nooksack_River_Fault.xls','nvecnrf1_200m','A2:C6000');
I = find(out.fault.disp{1,17}(:,4)<-90&out.fault.disp{1,17}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,17}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecnrf1(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf1(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf1(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf1(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispnrf1(i,1) = (out.fault.disp{1,17}(I(i),5)^2 + out.fault.disp{1,17}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf1 = STnrf1(I,1);
DTnrf1 = DTnrf1(I,1);
Dispnrf1 = Dispnrf1(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf1(i)/100;
    else
        dg(i,1) = abs(Dispnrf1(i)-Dispnrf1(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf1(i)/100;
for i=1:length(I)
    DGnrf1(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf1(:,1) = unique(J(:,1));
for i=1:length(Lnrf1)
    I = find(J(:,1)==Lnrf1(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lnrf1(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lnrf1(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf1(i,2) = J(I(K),2);
end


% Nooksack River Fault 2
nvecnrf2 = xlsread('Nooksack_River_Fault.xls','nvecnrf2_200m','A2:C6000');
I = find(out.fault.disp{1,18}(:,4)<-90&out.fault.disp{1,18}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,18}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecnrf2(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf2(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf2(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf2(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispnrf2(i,1) = (out.fault.disp{1,18}(I(i),5)^2 + out.fault.disp{1,18}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf2 = STnrf2(I,1);
DTnrf2 = DTnrf2(I,1);
Dispnrf2 = Dispnrf2(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf2(i)/100;
    else
        dg(i,1) = abs(Dispnrf2(i)-Dispnrf2(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf2(i)/100;
for i=1:length(I)
    DGnrf2(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf2(:,1) = unique(J(:,1));
for i=1:length(Lnrf2)
    I = find(J(:,1)==Lnrf2(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lnrf2(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lnrf2(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf2(i,2) = J(I(K),2);
end


% Nooksack River Fault 3a
nvecnrf3a = xlsread('Nooksack_River_Fault.xls','nvecnrf3a_200m','A2:C6000');
I = find(out.fault.disp{1,19}(:,4)<-90&out.fault.disp{1,19}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,19}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecnrf3a(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf3a(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf3a(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf3a(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispnrf3a(i,1) = (out.fault.disp{1,19}(I(i),5)^2 + out.fault.disp{1,19}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf3a = STnrf3a(I,1);
DTnrf3a = DTnrf3a(I,1);
Dispnrf3a = Dispnrf3a(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf3a(i)/100;
    else
        dg(i,1) = abs(Dispnrf3a(i)-Dispnrf3a(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf3a(i)/100;
for i=1:length(I)
    DGnrf3a(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf3a(:,1) = unique(J(:,1));
for i=1:length(Lnrf3a)
    I = find(J(:,1)==Lnrf3a(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lnrf3a(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lnrf3a(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf3a(i,2) = J(I(K),2);
end


% Nooksack River Fault 3b
nvecnrf3b = xlsread('Nooksack_River_Fault.xls','nvecnrf3b_200m','A2:C6000');
I = find(out.fault.disp{1,20}(:,4)<-90&out.fault.disp{1,20}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,20}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecnrf3b(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf3b(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf3b(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf3b(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispnrf3b(i,1) = (out.fault.disp{1,20}(I(i),5)^2 + out.fault.disp{1,20}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf3b = STnrf3b(I,1);
DTnrf3b = DTnrf3b(I,1);
Dispnrf3b = Dispnrf3b(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf3b(i)/100;
    else
        dg(i,1) = abs(Dispnrf3b(i)-Dispnrf3b(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf3b(i)/100;
for i=1:length(I)
    DGnrf3b(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf3b(:,1) = unique(J(:,1));
for i=1:length(Lnrf3b)
    I = find(J(:,1)==Lnrf3b(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lnrf3b(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lnrf3b(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf3b(i,2) = J(I(K),2);
end


% Thompson Creek Fault 
nvectcf = xlsread('Thompson_Creek_Fault.xls','nvectcf_200m','A2:C6000');
I = find(out.fault.disp{1,21}(:,4)<-90&out.fault.disp{1,21}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,21}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvectcf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectcf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Disptcf(i,1) = (out.fault.disp{1,21}(I(i),5)^2 + out.fault.disp{1,21}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtcf = STtcf(I,1);
DTtcf = DTtcf(I,1);
Disptcf = Disptcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptcf(i)/100;
    else
        dg(i,1) = abs(Disptcf(i)-Disptcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptcf(i)/100;
for i=1:length(I)
    DGtcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ltcf(:,1) = unique(J(:,1));
for i=1:length(Ltcf)
    I = find(J(:,1)==Ltcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Ltcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Ltcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltcf(i,2) = J(I(K),2);
end


% Gallop Creek Fault
nvecgcf = xlsread('Gallop_Creek_Fault.xls','nvecgcf_200m','A2:C6000');
I = find(out.fault.disp{1,22}(:,4)<-90&out.fault.disp{1,22}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,22}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecgcf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecgcf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STgcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTgcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispgcf(i,1) = (out.fault.disp{1,22}(I(i),5)^2 + out.fault.disp{1,22}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STgcf = STgcf(I,1);
DTgcf = DTgcf(I,1);
Dispgcf = Dispgcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispgcf(i)/100;
    else
        dg(i,1) = abs(Dispgcf(i)-Dispgcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispgcf(i)/100;
for i=1:length(I)
    DGgcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lgcf(:,1) = unique(J(:,1));
for i=1:length(Lgcf)
    I = find(J(:,1)==Lgcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lgcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lgcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lgcf(i,2) = J(I(K),2);
end


% Warm Creek Fault 1
nvecwcf1 = xlsread('Warm_Creek_Fault.xls','nvecwcf1_200m','A2:C6000');
I = find(out.fault.disp{1,23}(:,4)<-90&out.fault.disp{1,23}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,23}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwcf1(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwcf1(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwcf1(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwcf1(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwcf1(i,1) = (out.fault.disp{1,23}(I(i),5)^2 + out.fault.disp{1,23}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwcf1 = STwcf1(I,1);
DTwcf1 = DTwcf1(I,1);
Dispwcf1 = Dispwcf1(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwcf1(i)/100;
    else
        dg(i,1) = abs(Dispwcf1(i)-Dispwcf1(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwcf1(i)/100;
for i=1:length(I)
    DGwcf1(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwcf1(:,1) = unique(J(:,1));
for i=1:length(Lwcf1)
    I = find(J(:,1)==Lwcf1(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwcf1(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwcf1(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwcf1(i,2) = J(I(K),2);
end


% Warm Creek Fault 2
nvecwcf2 = xlsread('Warm_Creek_Fault.xls','nvecwcf2_200m','A2:C6000');
I = find(out.fault.disp{1,24}(:,4)<-90&out.fault.disp{1,24}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,24}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwcf2(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwcf2(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwcf2(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwcf2(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwcf2(i,1) = (out.fault.disp{1,24}(I(i),5)^2 + out.fault.disp{1,24}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwcf2 = STwcf2(I,1);
DTwcf2 = DTwcf2(I,1);
Dispwcf2 = Dispwcf2(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwcf2(i)/100;
    else
        dg(i,1) = abs(Dispwcf2(i)-Dispwcf2(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwcf2(i)/100;
for i=1:length(I)
    DGwcf2(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwcf2(:,1) = unique(J(:,1));
for i=1:length(Lwcf2)
    I = find(J(:,1)==Lwcf2(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwcf2(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwcf2(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwcf2(i,2) = J(I(K),2);
end


% Loomis Mountain Fault
nveclmf = xlsread('Loomis_Mountain_Fault.xls','nveclmf_200m','A2:C6000');
I = find(out.fault.disp{1,25}(:,4)<-90&out.fault.disp{1,25}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,25}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nveclmf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveclmf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STlmf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTlmf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Displmf(i,1) = (out.fault.disp{1,25}(I(i),5)^2 + out.fault.disp{1,25}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STlmf = STlmf(I,1);
DTlmf = DTlmf(I,1);
Displmf = Displmf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Displmf(i)/100;
    else
        dg(i,1) = abs(Displmf(i)-Displmf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Displmf(i)/100;
for i=1:length(I)
    DGlmf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Llmf(:,1) = unique(J(:,1));
for i=1:length(Llmf)
    I = find(J(:,1)==Llmf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Llmf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Llmf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Llmf(i,2) = J(I(K),2);
end


% Wanlick Creek Fault
nvecwcf = xlsread('Wanlick_Creek_Fault.xls','nvecwcf_200m','A2:C6000');
I = find(out.fault.disp{1,26}(:,4)<-90&out.fault.disp{1,26}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,26}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwcf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwcf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwcf(i,1) = (out.fault.disp{1,26}(I(i),5)^2 + out.fault.disp{1,26}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwcf = STwcf(I,1);
DTwcf = DTwcf(I,1);
Dispwcf = Dispwcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwcf(i)/100;
    else
        dg(i,1) = abs(Dispwcf(i)-Dispwcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwcf(i)/100;
for i=1:length(I)
    DGwcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwcf(:,1) = unique(J(:,1));
for i=1:length(Lwcf)
    I = find(J(:,1)==Lwcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwcf(i,2) = J(I(K),2);
end


% Chilliwack River Fault
nveccrf = xlsread('Chilliwack_River_Fault.xls','nveccrf_200m','A2:C6000');
I = find(out.fault.disp{1,27}(:,4)<-90&out.fault.disp{1,27}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,27}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nveccrf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveccrf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STcrf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTcrf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispcrf(i,1) = (out.fault.disp{1,27}(I(i),5)^2 + out.fault.disp{1,27}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STcrf = STcrf(I,1);
DTcrf = DTcrf(I,1);
Dispcrf = Dispcrf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispcrf(i)/100;
    else
        dg(i,1) = abs(Dispcrf(i)-Dispcrf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispcrf(i)/100;
for i=1:length(I)
    DGcrf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lcrf(:,1) = unique(J(:,1));
for i=1:length(Lcrf)
    I = find(J(:,1)==Lcrf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lcrf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lcrf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lcrf(i,2) = J(I(K),2);
end


% Ruth Creek Fault 1
nvecrcf1 = xlsread('Ruth_Creek_Fault.xls','nvecrcf1_200m','A2:C6000');
I = find(out.fault.disp{1,28}(:,4)<-90&out.fault.disp{1,28}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,28}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecrcf1(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecrcf1(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STrcf1(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTrcf1(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Disprcf1(i,1) = (out.fault.disp{1,28}(I(i),5)^2 + out.fault.disp{1,28}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STrcf1 = STrcf1(I,1);
DTrcf1 = DTrcf1(I,1);
Disprcf1 = Disprcf1(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disprcf1(i)/100;
    else
        dg(i,1) = abs(Disprcf1(i)-Disprcf1(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disprcf1(i)/100;
for i=1:length(I)
    DGrcf1(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf1(:,1) = unique(J(:,1));
for i=1:length(Lrcf1)
    I = find(J(:,1)==Lrcf1(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lrcf1(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lrcf1(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf1(i,2) = J(I(K),2);
end


% Ruth Creek Fault 2
nvecrcf2 = xlsread('Ruth_Creek_Fault.xls','nvecrcf2_200m','A2:C6000');
I = find(out.fault.disp{1,29}(:,4)<-90&out.fault.disp{1,29}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,29}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecrcf2(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecrcf2(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STrcf2(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTrcf2(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Disprcf2(i,1) = (out.fault.disp{1,29}(I(i),5)^2 + out.fault.disp{1,29}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STrcf2 = STrcf2(I,1);
DTrcf2 = DTrcf2(I,1);
Disprcf2 = Disprcf2(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disprcf2(i)/100;
    else
        dg(i,1) = abs(Disprcf2(i)-Disprcf2(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disprcf2(i)/100;
for i=1:length(I)
    DGrcf2(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf2(:,1) = unique(J(:,1));
for i=1:length(Lrcf2)
    I = find(J(:,1)==Lrcf2(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lrcf2(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lrcf2(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf2(i,2) = J(I(K),2);
end


% Glacier Extensional Fault 1
nvecgex1 = xlsread('Glacier_Extensional_Fault.xls','nvecgex1_200m','A2:C6000');
I = find(out.fault.disp{1,30}(:,4)<-90&out.fault.disp{1,30}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,30}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecgex1(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecgex1(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STgex1(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTgex1(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispgex1(i,1) = (out.fault.disp{1,30}(I(i),5)^2 + out.fault.disp{1,30}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STgex1 = STgex1(I,1);
DTgex1 = DTgex1(I,1);
Dispgex1 = Dispgex1(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispgex1(i)/100;
    else
        dg(i,1) = abs(Dispgex1(i)-Dispgex1(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispgex1(i)/100;
for i=1:length(I)
    DGgex1(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lgex1(:,1) = unique(J(:,1));
for i=1:length(Lgex1)
    I = find(J(:,1)==Lgex1(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lgex1(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lgex1(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lgex1(i,2) = J(I(K),2);
end


% Glacier Extensional Fault 2
nvecgex2 = xlsread('Glacier_Extensional_Fault.xls','nvecgex2_200m','A2:C6000');
I = find(out.fault.disp{1,31}(:,4)<-90&out.fault.disp{1,31}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,31}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecgex2(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecgex2(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STgex2(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTgex2(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispgex2(i,1) = (out.fault.disp{1,31}(I(i),5)^2 + out.fault.disp{1,31}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STgex2 = STgex2(I,1);
DTgex2 = DTgex2(I,1);
Dispgex2 = Dispgex2(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispgex2(i)/100;
    else
        dg(i,1) = abs(Dispgex2(i)-Dispgex2(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispgex2(i)/100;
for i=1:length(I)
    DGgex2(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lgex2(:,1) = unique(J(:,1));
for i=1:length(Lgex2)
    I = find(J(:,1)==Lgex2(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lgex2(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lgex2(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lgex2(i,2) = J(I(K),2);
end


% Thunder Creek Fault
nvecthcf = xlsread('Thunder_Creek_Fault.xls','nvecthcf_200m','A2:C6000');
I = find(out.fault.disp{1,32}(:,4)<-90&out.fault.disp{1,32}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,32}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecthcf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecthcf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STthcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTthcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispthcf(i,1) = (out.fault.disp{1,32}(I(i),5)^2 + out.fault.disp{1,32}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STthcf = STthcf(I,1);
DTthcf = DTthcf(I,1);
Dispthcf = Dispthcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispthcf(i)/100;
    else
        dg(i,1) = abs(Dispthcf(i)-Dispthcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispthcf(i)/100;
for i=1:length(I)
    DGthcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lthcf(:,1) = unique(J(:,1));
for i=1:length(Lthcf)
    I = find(J(:,1)==Lthcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lthcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lthcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lthcf(i,2) = J(I(K),2);
end


% South Fork Fault
nvecsff = xlsread('South_Fork_Fault.xls','nvecsff_200m','A2:C6000');
I = find(out.fault.disp{1,33}(:,4)<-90&out.fault.disp{1,33}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,33}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecsff(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsff(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsff(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsff(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispsff(i,1) = (out.fault.disp{1,33}(I(i),5)^2 + out.fault.disp{1,33}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsff = STsff(I,1);
DTsff = DTsff(I,1);
Dispsff = Dispsff(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispsff(i)/100;
    else
        dg(i,1) = abs(Dispsff(i)-Dispsff(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispsff(i)/100;
for i=1:length(I)
    DGsff(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lsff(:,1) = unique(J(:,1));
for i=1:length(Lsff)
    I = find(J(:,1)==Lsff(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lsff(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lsff(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsff(i,2) = J(I(K),2);
end


% North Fork Fault
nvecnff = xlsread('North_Fork_Fault.xls','nvecnff_200m','A2:C6000');
I = find(out.fault.disp{1,34}(:,4)<-90&out.fault.disp{1,34}(:,4)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,34}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecnff(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnff(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnff(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnff(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispnff(i,1) = (out.fault.disp{1,34}(I(i),5)^2 + out.fault.disp{1,34}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnff = STnff(I,1);
DTnff = DTnff(I,1);
Dispnff = Dispnff(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnff(i)/100;
    else
        dg(i,1) = abs(Dispnff(i)-Dispnff(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnff(i)/100;
for i=1:length(I)
    DGnff(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnff(:,1) = unique(J(:,1));
for i=1:length(Lnff)
    I = find(J(:,1)==Lnff(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lnff(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lnff(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnff(i,2) = J(I(K),2);
end


% Shuskan Thrust Fault
XYZsktf = xlsread('Shuskan_Thrust_Fault.xls','XYZsktf','A2:C6000');
tnsktf = xlsread('Shuskan_Thrust_Fault.xls','tnsktf','A1:C6000');
clear C
for i=1:length(tnsktf)
    C(i,1) = mean([XYZsktf(tnsktf(i,1),1) XYZsktf(tnsktf(i,2),1) XYZsktf(tnsktf(i,3),1)]);
    C(i,2) = mean([XYZsktf(tnsktf(i,1),2) XYZsktf(tnsktf(i,2),2) XYZsktf(tnsktf(i,3),2)]);
    C(i,3) = mean([XYZsktf(tnsktf(i,1),3) XYZsktf(tnsktf(i,2),3) XYZsktf(tnsktf(i,3),3)]);
end
nvecsktf = xlsread('Shuskan_Thrust_Fault.xls','nvecsktf','A2:C6000');
I = find(C(:,3)<-90&C(:,3)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma200*nvecsktf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsktf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsktf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsktf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispsktf = zeros(length(XYZ),1);
DGsktf = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lsktf(:,1) = unique(J(:,1));
for i=1:length(Lsktf)
    I = find(J(:,1)==Lsktf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lsktf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lsktf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsktf(i,2) = J(I(K),2);
end


% Welker Peak Thrust Fault east 1
XYZwptfe1 = xlsread('Welker_Peak_Thrust_Fault.xls','XYZwptfe1','A2:C6000');
tnwptfe1 = xlsread('Welker_Peak_Thrust_Fault.xls','tnwptfe1','A1:C6000');
clear C
for i=1:length(tnwptfe1)
    C(i,1) = mean([XYZwptfe1(tnwptfe1(i,1),1) XYZwptfe1(tnwptfe1(i,2),1) XYZwptfe1(tnwptfe1(i,3),1)]);
    C(i,2) = mean([XYZwptfe1(tnwptfe1(i,1),2) XYZwptfe1(tnwptfe1(i,2),2) XYZwptfe1(tnwptfe1(i,3),2)]);
    C(i,3) = mean([XYZwptfe1(tnwptfe1(i,1),3) XYZwptfe1(tnwptfe1(i,2),3) XYZwptfe1(tnwptfe1(i,3),3)]);
end
nvecwptfe1 = xlsread('Welker_Peak_Thrust_Fault.xls','nvecwptfe1','A2:C6000');
I = find(C(:,3)<-90&C(:,3)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma200*nvecwptfe1(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwptfe1(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwptfe1(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwptfe1(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispwptfe1 = zeros(length(XYZ),1);
DGwptfe1 = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwptfe1(:,1) = unique(J(:,1));
for i=1:length(Lwptfe1)
    I = find(J(:,1)==Lwptfe1(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwptfe1(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwptfe1(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwptfe1(i,2) = J(I(K),2);
end


% Welker Peak Thrust Fault east 2
XYZwptfe2 = xlsread('Welker_Peak_Thrust_Fault.xls','XYZwptfe2','A2:C6000');
tnwptfe2 = xlsread('Welker_Peak_Thrust_Fault.xls','tnwptfe2','A1:C6000');
clear C
for i=1:length(tnwptfe2)
    C(i,1) = mean([XYZwptfe2(tnwptfe2(i,1),1) XYZwptfe2(tnwptfe2(i,2),1) XYZwptfe2(tnwptfe2(i,3),1)]);
    C(i,2) = mean([XYZwptfe2(tnwptfe2(i,1),2) XYZwptfe2(tnwptfe2(i,2),2) XYZwptfe2(tnwptfe2(i,3),2)]);
    C(i,3) = mean([XYZwptfe2(tnwptfe2(i,1),3) XYZwptfe2(tnwptfe2(i,2),3) XYZwptfe2(tnwptfe2(i,3),3)]);
end
nvecwptfe2 = xlsread('Welker_Peak_Thrust_Fault.xls','nvecwptfe2','A2:C6000');
I = find(C(:,3)<-90&C(:,3)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma200*nvecwptfe2(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwptfe2(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwptfe2(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwptfe2(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispwptfe2 = zeros(length(XYZ),1);
DGwptfe2 = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwptfe2(:,1) = unique(J(:,1));
for i=1:length(Lwptfe2)
    I = find(J(:,1)==Lwptfe2(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwptfe2(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwptfe2(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwptfe2(i,2) = J(I(K),2);
end


% Welker Peak Thrust Fault west
XYZwptfw = xlsread('Welker_Peak_Thrust_Fault.xls','XYZwptfw','A2:C6000');
tnwptfw = xlsread('Welker_Peak_Thrust_Fault.xls','tnwptfw','A1:C6000');
clear C
for i=1:length(tnwptfw)
    C(i,1) = mean([XYZwptfw(tnwptfw(i,1),1) XYZwptfw(tnwptfw(i,2),1) XYZwptfw(tnwptfw(i,3),1)]);
    C(i,2) = mean([XYZwptfw(tnwptfw(i,1),2) XYZwptfw(tnwptfw(i,2),2) XYZwptfw(tnwptfw(i,3),2)]);
    C(i,3) = mean([XYZwptfw(tnwptfw(i,1),3) XYZwptfw(tnwptfw(i,2),3) XYZwptfw(tnwptfw(i,3),3)]);
end
nvecwptfw = xlsread('Welker_Peak_Thrust_Fault.xls','nvecwptfw','A2:C6000');
I = find(C(:,3)<-90&C(:,3)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma200*nvecwptfw(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwptfw(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwptfw(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwptfw(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispwptfw = zeros(length(XYZ),1);
DGwptfw = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwptfw(:,1) = unique(J(:,1));
for i=1:length(Lwptfw)
    I = find(J(:,1)==Lwptfw(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lwptfw(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lwptfw(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwptfw(i,2) = J(I(K),2);
end


% Shuksan Thrust Fault 1
XYZkstf1 = xlsread('Shuksan_Thrust_Fault.xls','XYZkstf1','A2:C6000');
tnkstf1 = xlsread('Shuksan_Thrust_Fault.xls','tnkstf1','A1:C6000');
clear C
for i=1:length(tnkstf1)
    C(i,1) = mean([XYZkstf1(tnkstf1(i,1),1) XYZkstf1(tnkstf1(i,2),1) XYZkstf1(tnkstf1(i,3),1)]);
    C(i,2) = mean([XYZkstf1(tnkstf1(i,1),2) XYZkstf1(tnkstf1(i,2),2) XYZkstf1(tnkstf1(i,3),2)]);
    C(i,3) = mean([XYZkstf1(tnkstf1(i,1),3) XYZkstf1(tnkstf1(i,2),3) XYZkstf1(tnkstf1(i,3),3)]);
end
nveckstf1 = xlsread('Shuksan_Thrust_Fault.xls','nveckstf1','A2:C6000');
I = find(C(:,3)<-90&C(:,3)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma200*nveckstf1(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveckstf1(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STkstf1(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTkstf1(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispkstf1 = zeros(length(XYZ),1);
DGkstf1 = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lkstf1(:,1) = unique(J(:,1));
for i=1:length(Lkstf1)
    I = find(J(:,1)==Lkstf1(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lkstf1(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lkstf1(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lkstf1(i,2) = J(I(K),2);
end


% Shuksan Thrust Fault 2
XYZkstf2 = xlsread('Shuksan_Thrust_Fault.xls','XYZkstf2','A2:C6000');
tnkstf2 = xlsread('Shuksan_Thrust_Fault.xls','tnkstf2','A1:C6000');
clear C
for i=1:length(tnkstf2)
    C(i,1) = mean([XYZkstf2(tnkstf2(i,1),1) XYZkstf2(tnkstf2(i,2),1) XYZkstf2(tnkstf2(i,3),1)]);
    C(i,2) = mean([XYZkstf2(tnkstf2(i,1),2) XYZkstf2(tnkstf2(i,2),2) XYZkstf2(tnkstf2(i,3),2)]);
    C(i,3) = mean([XYZkstf2(tnkstf2(i,1),3) XYZkstf2(tnkstf2(i,2),3) XYZkstf2(tnkstf2(i,3),3)]);
end
nveckstf2 = xlsread('Shuksan_Thrust_Fault.xls','nveckstf2','A2:C6000');
I = find(C(:,3)<-90&C(:,3)>-210);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma200*nveckstf2(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveckstf2(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STkstf2(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTkstf2(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispkstf2 = zeros(length(XYZ),1);
DGkstf2 = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out.obs.xyz(j,1))^2 + (XYZ(i,2)-out.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lkstf2(:,1) = unique(J(:,1));
for i=1:length(Lkstf2)
    I = find(J(:,1)==Lkstf2(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.xyz(Lkstf2(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.xyz(Lkstf2(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lkstf2(i,2) = J(I(K),2);
end

%% combine fault layers
L = [Ltacf;Ltsmf;Lrcf;Lblf;Lmwf;Lracf;Lscf1;Lscf2;Lscf3;Ldf;Lsmf;Lbmf;Ltmf;Lwf;Lnrf1;Lnrf2;Lnrf3a;Lnrf3b;Ltcf;Lgcf;Lwcf1;Lwcf2;Llmf;Lwcf;Lcrf;Lrcf1;Lrcf2;Lgex1;Lgex2;Lthcf;Lsff;Lnff;Lsktf;Lwptfe1;Lwptfe2;Lwptfw;Lkstf1;Lkstf2];
STall = [STacf(Ltacf(:,2));STtsmf(Ltsmf(:,2));STrcf(Lrcf(:,2));STblf(Lblf(:,2));STmwf(Lmwf(:,2));STracf(Lracf(:,2));STscf1(Lscf1(:,2));STscf2(Lscf2(:,2));STscf3(Lscf3(:,2));STdf(Ldf(:,2));STsmf(Lsmf(:,2));STbmf(Lbmf(:,2));STtmf(Ltmf(:,2));STwf(Lwf(:,2));STnrf1(Lnrf1(:,2));STnrf2(Lnrf2(:,2));STnrf3a(Lnrf3a(:,2));STnrf3b(Lnrf3b(:,2));STtcf(Ltcf(:,2));STgcf(Lgcf(:,2));STwcf1(Lwcf1(:,2));STwcf2(Lwcf2(:,2));STlmf(Llmf(:,2));STwcf(Lwcf(:,2));STcrf(Lcrf(:,2));STrcf1(Lrcf1(:,2));STrcf2(Lrcf2(:,2));STgex1(Lgex1(:,2));STgex2(Lgex2(:,2));STthcf(Lthcf(:,2));STsff(Lsff(:,2));STnff(Lnff(:,2));STsktf(Lsktf(:,2));STwptfe1(Lwptfe1(:,2));STwptfe2(Lwptfe2(:,2));STwptfw(Lwptfw(:,2));STkstf1(Lkstf1(:,2));STkstf2(Lkstf2(:,2))];
DTall = [DTacf(Ltacf(:,2));DTtsmf(Ltsmf(:,2));DTrcf(Lrcf(:,2));DTblf(Lblf(:,2));DTmwf(Lmwf(:,2));DTracf(Lracf(:,2));DTscf1(Lscf1(:,2));DTscf2(Lscf2(:,2));DTscf3(Lscf3(:,2));DTdf(Ldf(:,2));DTsmf(Lsmf(:,2));DTbmf(Lbmf(:,2));DTtmf(Ltmf(:,2));DTwf(Lwf(:,2));DTnrf1(Lnrf1(:,2));DTnrf2(Lnrf2(:,2));DTnrf3a(Lnrf3a(:,2));DTnrf3b(Lnrf3b(:,2));DTtcf(Ltcf(:,2));DTgcf(Lgcf(:,2));DTwcf1(Lwcf1(:,2));DTwcf2(Lwcf2(:,2));DTlmf(Llmf(:,2));DTwcf(Lwcf(:,2));DTcrf(Lcrf(:,2));DTrcf1(Lrcf1(:,2));DTrcf2(Lrcf2(:,2));DTgex1(Lgex1(:,2));DTgex2(Lgex2(:,2));DTthcf(Lthcf(:,2));DTsff(Lsff(:,2));DTnff(Lnff(:,2));DTsktf(Lsktf(:,2));DTwptfe1(Lwptfe1(:,2));DTwptfe2(Lwptfe2(:,2));DTwptfw(Lwptfw(:,2));DTkstf1(Lkstf1(:,2));DTkstf2(Lkstf2(:,2))];
Dispall = [Dispacf(Ltacf(:,2));Disptsmf(Ltsmf(:,2));Disprcf(Lrcf(:,2));Dispblf(Lblf(:,2));Dispmwf(Lmwf(:,2));Dispracf(Lracf(:,2));Dispscf1(Lscf1(:,2));Dispscf2(Lscf2(:,2));Dispscf3(Lscf3(:,2));Dispdf(Ldf(:,2));Dispsmf(Lsmf(:,2));Dispbmf(Lbmf(:,2));Disptmf(Ltmf(:,2));Dispwf(Lwf(:,2));Dispnrf1(Lnrf1(:,2));Dispnrf2(Lnrf2(:,2));Dispnrf3a(Lnrf3a(:,2));Dispnrf3b(Lnrf3b(:,2));Disptcf(Ltcf(:,2));Dispgcf(Lgcf(:,2));Dispwcf1(Lwcf1(:,2));Dispwcf2(Lwcf2(:,2));Displmf(Llmf(:,2));Dispwcf(Lwcf(:,2));Dispcrf(Lcrf(:,2));Disprcf1(Lrcf1(:,2));Disprcf2(Lrcf2(:,2));Dispgex1(Lgex1(:,2));Dispgex2(Lgex2(:,2));Dispthcf(Lthcf(:,2));Dispsff(Lsff(:,2));Dispnff(Lnff(:,2));Dispsktf(Lsktf(:,2));Dispwptfe1(Lwptfe1(:,2));Dispwptfe2(Lwptfe2(:,2));Dispwptfw(Lwptfw(:,2));Dispkstf1(Lkstf1(:,2));Dispkstf2(Lkstf2(:,2))];
DGall = [DGacf(Ltacf(:,2));DGtsmf(Ltsmf(:,2));DGrcf(Lrcf(:,2));DGblf(Lblf(:,2));DGmwf(Lmwf(:,2));DGracf(Lracf(:,2));DGscf1(Lscf1(:,2));DGscf2(Lscf2(:,2));DGscf3(Lscf3(:,2));DGdf(Ldf(:,2));DGsmf(Lsmf(:,2));DGbmf(Lbmf(:,2));DGtmf(Ltmf(:,2));DGwf(Lwf(:,2));DGnrf1(Lnrf1(:,2));DGnrf2(Lnrf2(:,2));DGnrf3a(Lnrf3a(:,2));DGnrf3b(Lnrf3b(:,2));DGtcf(Ltcf(:,2));DGgcf(Lgcf(:,2));DGwcf1(Lwcf1(:,2));DGwcf2(Lwcf2(:,2));DGlmf(Llmf(:,2));DGwcf(Lwcf(:,2));DGcrf(Lcrf(:,2));DGrcf1(Lrcf1(:,2));DGrcf2(Lrcf2(:,2));DGgex1(Lgex1(:,2));DGgex2(Lgex2(:,2));DGthcf(Lthcf(:,2));DGsff(Lsff(:,2));DGnff(Lnff(:,2));DGsktf(Lsktf(:,2));DGwptfe1(Lwptfe1(:,2));DGwptfe2(Lwptfe2(:,2));DGwptfw(Lwptfw(:,2));DGkstf1(Lkstf1(:,2));DGkstf2(Lkstf2(:,2))];

% FAULT_GRID --> X,Y,Z,slip tendency,dilation tendency,displacement gradient
FAULT_GRID(:,1:3) = out.obs.xyz(:,1:3);
for i=1:length(L)
        FAULT_GRID(L(i,1),4) = STall(i);
        FAULT_GRID(L(i,1),5) = DTall(i);
        FAULT_GRID(L(i,1),6) = Dispall(i);
        FAULT_GRID(L(i,1),7) = DGall(i);
end

%% Combine Stress layers

% 2D smoothing
for j=0:114
for i=0:107
    X(1+i,1+j) = out.obs.xyz((1+i)+108*j,1);
    Y(1+i,1+j) = out.obs.xyz((1+i)+108*j,2);
    ScXY(1+i,1+j) = ((((-out.obs.pstress((1+i)+108*j,15))-(-out.obs.pstress((1+i)+108*j,7)))/2)*(1+.6^2)^.5 - .6*(((-out.obs.pstress((1+i)+108*j,15))+(-out.obs.pstress((1+i)+108*j,7)))/2));%/1000000;
    S3XY(1+i,1+j) = (-out.obs.pstress((1+i)+108*j,7));%/1000000;
    if find(L(:,1)==((1+i)+108*j))
        ScXY(1+i,1+j) = NaN;
        S3XY(1+i,1+j) = NaN;
    end
end
end
Nrc = 2;
ScXY = smooth2a(ScXY,Nrc);
S3XY = smooth2a(S3XY,Nrc);
for i=1:numel(ScXY(1,:))
    Sc(1+(i-1)*numel(ScXY(:,1)):i*numel(ScXY(:,1)),1) = ScXY(:,i);
    S3(1+(i-1)*numel(ScXY(:,1)):i*numel(ScXY(:,1)),1) = S3XY(:,i);
end

% extract stress values to compute means and standard deviations
k=1;
for i=1:length(Sc)
    if isnan(Sc(i))
    else
        ScReal(k,1) = Sc(i);
        S3Real(k,1) = S3(i);
        k=k+1;
    end
end

% Mean and Standard Deviation
% Sc
Scmean = mean(ScReal);
SigSc = std(ScReal);
% Shmin
S3mean = mean(S3Real);
SigShmin = std(S3Real);

% STRESS_GRID --> X,Y,Z,maximum Coulomb shear stress,Shmin
STRESS_GRID(:,1:3) = out.obs.xyz(:,1:3);
STRESS_GRID(:,4) = Sc;
STRESS_GRID(:,5) = S3;

%% Permeability Model Layer Normalization

% Fault Layers
% no normalization needed for slip/dilation tendency (0-1)
Fault.sliptendency(:,1:3) = FAULT_GRID(:,1:3);
Fault.sliptendency(:,4) = FAULT_GRID(:,4);
Fault.dilationtendency(:,1:3) = FAULT_GRID(:,1:3);
Fault.dilationtendency(:,4) = FAULT_GRID(:,5);
% displacement
Fault.displacement(:,1:3) = FAULT_GRID(:,1:3);
Fault.displacement(:,4) = FAULT_GRID(:,6)/max(FAULT_GRID(:,6));
% displacement gradient
Fault.displacementgradient(:,1:3) = FAULT_GRID(:,1:3);
Fault.displacementgradient(:,4) = FAULT_GRID(:,7)/max(FAULT_GRID(:,7));

% Stress Layers
% normalization between +/- X standard deviations
nsd = 3;% # of standard deviations
Stress.MaximumCoulombShearStress(:,1:3) = STRESS_GRID(:,1:3);
Stress.MaximumCoulombShearStress(:,4) = (STRESS_GRID(:,4)-(Scmean-nsd*SigSc))/(2*nsd*SigSc);
I = find(Stress.MaximumCoulombShearStress(:,4)<0);
Stress.MaximumCoulombShearStress(I,4) = 0;
I = find(Stress.MaximumCoulombShearStress(:,4)>1);
Stress.MaximumCoulombShearStress(I,4) = 1;
for i=1:length(L)
    Stress.MaximumCoulombShearStress(L(i,1),4) = 0;
end

% Inverse Shmin values by adding 2*mean to negative values
Stress.Sigma3(:,1:3) = STRESS_GRID(:,1:3);
Stress.Sigma3(:,4) = -STRESS_GRID(:,5);
Stress.Sigma3(:,4) = (Stress.Sigma3(:,4)-(-S3mean-nsd*SigShmin))/(2*nsd*SigShmin);
I = find(Stress.Sigma3(:,4)<0);
Stress.Sigma3(I,4) = 0;
I = find(Stress.Sigma3(:,4)>1);
Stress.Sigma3(I,4) = 1;
for i=1:length(L)
    Stress.Sigma3(L(i,1),4) = 0;
end

%% FIGURES

figure
plot([1:numel(Sc)],Sc,'k-');ylabel('Sc')
hold on
plot([0 9292],[Scmean+nsd*SigSc Scmean+nsd*SigSc])
plot([0 9292],[Scmean-nsd*SigSc Scmean-nsd*SigSc])
figure
plot([1:numel(S3)],S3,'k-');ylabel('Shmin')
hold on
plot([0 9292],[S3mean+nsd*SigShmin S3mean+nsd*SigShmin])
plot([0 9292],[S3mean-nsd*SigShmin S3mean-nsd*SigShmin])

figure
plot([1:numel(Stress.MaximumCoulombShearStress(:,4))],Stress.MaximumCoulombShearStress(:,4),'k.');ylabel('Sc favorability')
figure
plot([1:numel(Stress.Sigma3(:,4))],Stress.Sigma3(:,4),'k.');ylabel('Shmin favorability')


% grid data for contour plots
for j=0:114
for i=0:107
    X(1+i,1+j) = out.obs.xyz((1+i)+108*j,1);
    Y(1+i,1+j) = out.obs.xyz((1+i)+108*j,2);
    ScXY(1+i,1+j) = Sc((1+i)+108*j,1)/1000000;
    S3XY(1+i,1+j) = S3((1+i)+108*j,1)/1000000;
    STXY(1+i,1+j) = FAULT_GRID((1+i)+108*j,4);
    DTXY(1+i,1+j) = FAULT_GRID((1+i)+108*j,5);
    DXY(1+i,1+j) = FAULT_GRID((1+i)+108*j,6);
    DGXY(1+i,1+j) = FAULT_GRID((1+i)+108*j,7);
    if find(L(:,1)==((1+i)+108*j))
        ScXY(1+i,1+j) = NaN;
        S3XY(1+i,1+j) = NaN;
    end
end
end

% Sc contour intervals
ci = ((Scmean+nsd*SigSc)/1000000 - (Scmean-nsd*SigSc)/1000000)/20;
Vm = [(Scmean-nsd*SigSc)/1000000:ci:(Scmean+nsd*SigSc)/1000000];
figure
contourf(X,Y,ScXY,Vm)
hold on
contour(X,Y,ScXY,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sc(MPa)','Fontsize',14);
caxis([(Scmean-nsd*SigSc)/1000000 (Scmean+nsd*SigSc)/1000000]);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% S3 contour intervals
ci = ((S3mean+nsd*SigShmin)/1000000 - (S3mean-nsd*SigShmin)/1000000)/20;
Vm = [(S3mean-nsd*SigShmin)/1000000:ci:(S3mean+nsd*SigShmin)/1000000];
figure
contourf(X,Y,S3XY,Vm)
hold on
contour(X,Y,S3XY,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sigma3(MPa)','Fontsize',14);
caxis([(S3mean-nsd*SigShmin)/1000000 (S3mean+nsd*SigShmin)/1000000]);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% ST
figure
contourf(X,Y,STXY)
hold on
contour(X,Y,STXY)
c=colorbar;
set(get(c,'ylabel'),'String','Slip Tendency','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% DT
figure
contourf(X,Y,DTXY)
hold on
contour(X,Y,DTXY)
c=colorbar;
set(get(c,'ylabel'),'String','Dilation Tendency','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% Disp
figure
contourf(X,Y,DXY)
hold on
contour(X,Y,DXY)
c=colorbar;
set(get(c,'ylabel'),'String','Displacement(m)','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% DG
figure
contourf(X,Y,DGXY)
hold on
contour(X,Y,DGXY)
c=colorbar;
set(get(c,'ylabel'),'String','Displacement Gradient(m/m)','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)