% MB_strainrate_v3.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/03/26
% DATE MODIFIED:    2015/06/24
% VERSION:          v.3
%
% PURPOSE:  To construct 3D fault geometry around Mount Saint Helens for
% permeability potential modeling for play fairway analysis
%
% PURPOSE OF MODIFICATION: now using rotational component of strain tensor.
% with strain rates near block boundary removed.
% VERSION 3: filter strain rates based on higher levels of perturbation
% (use strainrates less than mean strainrate), and only use data from Southern
% Vancouver Island plate (SoVI).
% 
% INPUT: 2D strain rate tensor components near Mount Saint Helens from spline
%        tension model using rotational component with 0.3 spline tension and
%        modeled strainrates removed from block boundary.
%           1) MB_e_e_60km_SoVI.csv
%           2) MB_mean_e_n_60km_SoVI.csv
%           3) MB_n_n_60km_SoVI.csv
%
% OUTPUT: 3D stress tensor in Pa at 200m and 3km depths.
%
% NOTE: 
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m



% Version 3: filter strain rates based on higher levels of perturbation
% (strainrates less than mean strainrate), and only use data from Southern
% Vancouver Island plate.

clear all;close all

%% Import Data
e_e = importdata('MB_e_e_60km_SoVI.csv',',');
e_n_M = importdata('MB_mean_e_n_60km_SoVI.csv',',');
n_n = importdata('MB_n_n_60km_SoVI.csv',',');

k=1;
for i=1:length(e_e.data)
    % 2D strain rate tensor componenets
    e{i}(1,1) = e_e.data(i,3);
    e{i}(1,2) = e_n_M.data(i,3);
    e{i}(2,1) = e_n_M.data(i,3);
    e{i}(2,2) = n_n.data(i,3);
    lat(i,1) = e_e.data(i,2);
    lon(i,1) = e_e.data(i,1);
    [v{i},d{i}] = eig(e{i});% principal 2D strain rates
    e{i}(3,3) = -.25*(d{i}(1,1) + d{i}(2,2));% vertical strain rate using Hooke's Law and Poisson's ratio of 0.25
    [v3d{i},d3d{i}] = eig(e{i});
    % 2D strain rate tensors
    E11(k) = e{i}(1,1);
    E22(k) = e{i}(2,2);
    E33(k) = e{i}(3,3);
    E12(k) = e{i}(1,2);
    k=k+1;
end
[x,y,utmzone] = deg2utm(lat,lon);

%% filter strain rates

% filter by max compressive strain
for i=1:numel(d)
    sH(i) = d{i}(1,1);
    sh(i) = d{i}(2,2);
end
I = find(sH>mean(sH)&sh>0);
xy(:,1) = x(I);xy(:,2) = y(I);

% Average 2D Strain Tensor
E(1,1) = mean(E11(I));E(2,2) = mean(E22(I));E(3,3) = mean(E33(I));E(1,2) = mean(E12(I));E(2,1) = mean(E12(I));
[V,D] = eig(E);

% WRV boundary
latB = [48.601796 48.914596 48.919337 48.60651 48.601796];
lonB = [-121.983973 -121.992901 -121.545959 -121.539702 -121.983973];
[xB,yB,utmzone] = deg2utm(latB,lonB);
% Southern Vancouver Island plate Block Boundary
BB = importdata('SoVI.csv');
xBB = BB.data(:,3);
yBB = BB.data(:,4);

%% plot 2D and 3D strain rates
% 2D strainrates
figure
h3 = plot(xB,yB,'k-');
hold on
h4 = plot(xBB,yBB,'r-','linewidth',4);
for i=1:numel(x(I))
    h1=quiver(x(I(i)),y(I(i)),v{I(i)}(1,1),v{I(i)}(2,1),1000,'b');
    quiver(x(I(i)),y(I(i)),-v{I(i)}(1,1),-v{I(i)}(2,1),1000,'b')
    h2=quiver(x(I(i)),y(I(i)),v{I(i)}(1,2),v{I(i)}(2,2),1000,'r');
    quiver(x(I(i)),y(I(i)),-v{I(i)}(1,2),-v{I(i)}(2,2),1000,'r')
end
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
legend([h1 h2 h3 h4],'\epsilon_H','\epsilon_h','Model Boundary','Block Boundary');
title('Mount Baker Infinitesimal Strain Rate Tensors','fontsize',12)
xlim([min(x) max(x)])
ylim([min(y) max(y)])

% azimuth of maximum compression
S1az = round((180/pi)*atan(V(1,1)/V(2,1)))
S1az = (180/pi)*atan(V(1,1)/V(2,1));

% 2D strainrate
figure
h1=quiver3(V(1,1)*abs(D(1,1)),V(2,1)*abs(D(1,1)),V(3,1)*abs(D(1,1)),-V(1,1),-V(2,1),-V(3,1),abs(D(1,1)),'b');
hold on
quiver3(-V(1,1)*abs(D(1,1)),-V(2,1)*abs(D(1,1)),-V(3,1)*abs(D(1,1)),V(1,1),V(2,1),V(3,1),abs(D(1,1)),'b')
h2=quiver3(V(1,2)*abs(D(2,2)),V(2,2)*abs(D(2,2)),V(3,2)*abs(D(2,2)),-V(1,2),-V(2,2),-V(3,2),abs(D(2,2)),'g');
quiver3(-V(1,2)*abs(D(2,2)),-V(2,2)*abs(D(2,2)),-V(3,2)*abs(D(2,2)),V(1,2),V(2,2),V(3,2),abs(D(2,2)),'g')
h3=quiver3(0,0,0,-V(1,3),-V(2,3),-V(3,3),abs(D(3,3)),'r');
quiver3(0,0,0,V(1,3),V(2,3),V(3,3),abs(D(3,3)),'r')
text(.5e-3,2.5e-3,strcat('S1 az=',num2str(round(S1az))))
axis equal
xlim([-.005 .005]);ylim([-.005 .005]);zlim([-.005 .005])
xlabel('X','fontsize',12);ylabel('Y','fontsize',12);zlabel('Z','fontsize',12);
view(0,90)
legend([h1 h3],strcat('\epsilon_H =',' ',num2str(D(1,1))),strcat('\epsilon_h =',' ',num2str(D(3,3))))
title('Mount Baker 2D Strain Tensor','fontsize',12)

% 3D strainrate
figure
h1=quiver3(V(1,1)*abs(D(1,1)),V(2,1)*abs(D(1,1)),V(3,1)*abs(D(1,1)),-V(1,1),-V(2,1),-V(3,1),abs(D(1,1)),'b','linewidth',2);
hold on
quiver3(-V(1,1)*abs(D(1,1)),-V(2,1)*abs(D(1,1)),-V(3,1)*abs(D(1,1)),V(1,1),V(2,1),V(3,1),abs(D(1,1)),'b','linewidth',2)
h2=quiver3(V(1,2)*abs(D(2,2)),V(2,2)*abs(D(2,2)),V(3,2)*abs(D(2,2)),-V(1,2),-V(2,2),-V(3,2),abs(D(2,2)),'color',[0 .5 0],'linewidth',2);
quiver3(-V(1,2)*abs(D(2,2)),-V(2,2)*abs(D(2,2)),-V(3,2)*abs(D(2,2)),V(1,2),V(2,2),V(3,2),abs(D(2,2)),'color',[0 .5 0],'linewidth',2)
h3=quiver3(0,0,0,-V(1,3),-V(2,3),-V(3,3),abs(D(3,3)),'r','linewidth',2);
quiver3(0,0,0,V(1,3),V(2,3),V(3,3),abs(D(3,3)),'r','linewidth',2)
axis equal
xlim([-.005 .005]);ylim([-.005 .005]);zlim([-.005 .005])
xlabel('X','fontsize',12);ylabel('Y','fontsize',12);zlabel('Z','fontsize',12);
legend([h1 h3 h2],strcat('\epsilon_H =',' ',num2str(D(1,1))),strcat('\epsilon_h =',' ',num2str(D(3,3))),strcat('\epsilon_V =',' ',num2str(D(2,2))))
title('Mount Baker 3D Strain Tensor','fontsize',12)

%% calculate 3D remote stress
E = 3e10;% Youngs Modulus in Pa
S = D*E;
% depth to water table(meters)
dw = 20;
% 3km
de = 3;% depth km
Sv3km = 20*.1 + 27*(de-.1);
[V3km,D3km] = eig(S);
Sigma3km = D3km - (Sv3km*1000000+S(2,2));
Sigma3km(3,1:2) = 0;Sigma3km(1:2,3) = 0;
Sigma3km(2,1) = 0;Sigma3km(1,2) = 0;
Sv = Sigma3km(2,2);Sh = Sigma3km(3,3);
Sigma3km(2,2) = Sh;Sigma3km(3,3) = Sv;
A = [cos((90-S1az)*(pi/180)) -sin((90-S1az)*(pi/180)) 0;sin((90-S1az)*(pi/180)) cos((90-S1az)*(pi/180)) 0;0 0 1];
Sigma3km = A*Sigma3km*A';
[V3km,D3km] = eig(Sigma3km);

% Find 200m stress by factoring the vertical stress gradient
de = .2;% depth km
Sv200 = 20*.1 + 27*(de-.1);
Sigma200 = Sigma3km*(Sv200/Sv3km);
[V200,D200] = eig(Sigma200);

%% plot stress tensor gradients
figure
h1 = plot([0 -D3km(2,2)/1e6],[0 3000],'b-');
hold on
h2 = plot([0 -D3km(3,3)/1e6],[0 3000],'-','color',[0 .5 0]);
h3 = plot([0 -D3km(1,1)/1e6],[0 3000],'r-');
plot([0 160],[200 200],'k--')
xlabel('Stress(MPa)')
ylabel('Depth(m)')
set(gca,'YDir','reverse');
legend([h1 h2 h3],'SHmax','Sv','Shmin')
title('Mount Baker Stress','fontsize',12)
grid on