% MB_Sensitivity_3km.m
%
% AUTHOR:           Michael Swyer
% DATE CREATED:     8/24/2015
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:
%   Read Poly3D .out file and process data for permeability potential
%         
% PURPOSE OF MODIFICATION:
%
% INPUT: Poly3D output file
%           MtBaker3km_ul.out
%           MtBaker3km_ll.out
% 
% OUTPUT:
%   fault/stress model outputs:
%           -FAULT_GRID: x, y, z, slip tendency, dilation tendency, displacement(m), displacement gradient(m/m)
%           -STRESS_GRID: x, y, z, maximum Coulomb shear stress(Pa), sigma3(Pa)
%   Permeability potential layers:
%           -Fault.sliptendency: x, y, z, slip tendency
%           -Fault.dilationtendency: x, y, z, dilation tendency
%           -Fault.displacement: x, y, z, normalized displacement
%           -Fault.displacementgradient: x, y, z, normalized displacement gradient
%           -Stress.MaximumCoulombShearStress: x, y, z, normalized maximum Coulomb shear stress
%           -Stress.Sigma3: x, y, z, normalized sigma 3
%
% NOTE: 
%
% KEY functions written specifically for this modeling
%
% Other related functions
% - p3doutputreader_v04
% - redblue

clear all;close all

filename = 'InputOutputFiles\MountBaker3km_ul.out';
out1 = p3doutputreader_v04(filename);
filename = 'InputOutputFiles\MountBaker3km_ll.out';
out2 = p3doutputreader_v04(filename);
% Generates structured array including
%   FAULT OBJECTS
%   out.fault.xyz   = array of vertex locations
% 
%   out.fault.vert  = array of vertices
%                     [VERTNUM X1 X2 X3]
% 
%   out.fault.disp  = cell array contain displacements for each fault obj
%                     [ELT X1C X2C X3C B1 U1(+) U1(-) B2 U2(+) U2(-) B3 U3(+)]
%                     ELT = element number, for use in tri
%                     X1C, X2C, X3C = element centroid coordinates
%                     B1, B2, B3 are the burgers vectos components as
%                       (strike,dip,normal)
%                     Ui(+), Ui(-) = relative displacment at centroid
%
%   out.fault.tract = cell array contain tractions for each fault obj
%                     [ELT X1C X2C X3C T1 T2 T3]
%                     T1,T2,T3 are the traction components
%                       (strike,dip,normal)
%   out.fault.name  = cell array contain displacements for each fault obj
% 
%
%   OBSERVATION GRID
%   out.obs.xyz     = array containing the obs grid pts [X1,X2,X3]
%
%   out.obs.disp    = array containing displacements at obs pts
%                     [X1 X2 X3 U1 U2 U3]
%                     U1,U2,U3 = components of the displacement vector
%                     
%   out.obs.pstress = array containing principal stress and principal
%                     stress direcitons at obs pts
%                     [X1 X2 X3 N1 N2 N3 SIG1 N1 N2 N3 SIG2 N1 N2 N3 SIG3]
%                     SIG1,2,3 = principal stress components (tensoral
%                     convention) at each observation point
%                     N1,N2,N3 = principal stress direction vectors for the
%                       following principal stress in the array)
%
%   out.obs.stress  = array contain 
%                     [X1 X2 X3 SIG11 SIG22 SIG33 SIG12 SIG23 SIG13]
%                     SIG11,22,33,12,23,13 = stress tensor component at
%                     each observation point

Sigma3km = importdata('StressTensorMB3km.csv',',');
[V,PS3km] = eig(Sigma3km);% PS3km = eigenvalues as principal stresses

%% Slip/Dilation Tendency/Displacement/Displacement Gradient

%%% 200m %%%
% Anderson Creek Fault
% upper residuals
nvecacf_ul = xlsread('Anderson_Creek_Fault_ul.xls','nvecacf_3km','A2:C2000');
I = find(out1.fault.disp{1,2}(:,4)<-2700&out1.fault.disp{1,2}(:,4)>-3000);
% Tractions
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,2}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecacf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecacf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STacf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTacf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispacf_ul(i,1) = (out1.fault.disp{1,2}(I(i),5)^2 + out1.fault.disp{1,2}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STacf_ul = STacf_ul(I,1);
DTacf_ul = DTacf_ul(I,1);
Dispacf_ul = Dispacf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispacf_ul(i)/100;
    else
        dg(i,1) = abs(Dispacf_ul(i)-Dispacf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispacf_ul(i)/100;
for i=1:length(I)
    DGacf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Ltacf_ul(:,1) = unique(J(:,1));
for i=1:length(Ltacf_ul)
    I = find(J(:,1)==Ltacf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Ltacf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Ltacf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltacf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecacf_ll = xlsread('Anderson_Creek_Fault.xls','nvecacf_3km','A2:C2000');
I = find(out2.fault.disp{1,2}(:,4)<-2700&out2.fault.disp{1,2}(:,4)>-3000);
% Tractions
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,2}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecacf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecacf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STacf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTacf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispacf_ll(i,1) = (out2.fault.disp{1,2}(I(i),5)^2 + out2.fault.disp{1,2}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STacf_ll = STacf_ll(I,1);
DTacf_ll = DTacf_ll(I,1);
Dispacf_ll = Dispacf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispacf_ll(i)/100;
    else
        dg(i,1) = abs(Dispacf_ll(i)-Dispacf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispacf_ll(i)/100;
for i=1:length(I)
    DGacf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Ltacf_ll(:,1) = unique(J(:,1));
for i=1:length(Ltacf_ll)
    I = find(J(:,1)==Ltacf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Ltacf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Ltacf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltacf_ll(i,2) = J(I(K),2);
end


% Twin Sisters Mountain Fault
% upper residuals
nvectsmf_ul = xlsread('Sisters_Mountain_Fault_ul.xls','nvectsmf_3km','A2:C6000');
I = find(out1.fault.disp{1,4}(:,4)<-2700&out1.fault.disp{1,4}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,4}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvectsmf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectsmf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtsmf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtsmf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disptsmf_ul(i,1) = (out1.fault.disp{1,4}(I(i),5)^2 + out1.fault.disp{1,4}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtsmf_ul = STtsmf_ul(I,1);
DTtsmf_ul = DTtsmf_ul(I,1);
Disptsmf_ul = Disptsmf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptsmf_ul(i)/100;
    else
        dg(i,1) = abs(Disptsmf_ul(i)-Disptsmf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptsmf_ul(i)/100;
for i=1:length(I)
    DGtsmf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ltsmf_ul(:,1) = unique(J(:,1));
for i=1:length(Ltsmf_ul)
    I = find(J(:,1)==Ltsmf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Ltsmf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Ltsmf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltsmf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvectsmf_ll = xlsread('Sisters_Mountain_Fault.xls','nvectsmf_3km','A2:C6000');
I = find(out2.fault.disp{1,4}(:,4)<-2700&out2.fault.disp{1,4}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,4}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvectsmf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectsmf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtsmf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtsmf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disptsmf_ll(i,1) = (out2.fault.disp{1,4}(I(i),5)^2 + out2.fault.disp{1,4}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtsmf_ll = STtsmf_ll(I,1);
DTtsmf_ll = DTtsmf_ll(I,1);
Disptsmf_ll = Disptsmf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptsmf_ll(i)/100;
    else
        dg(i,1) = abs(Disptsmf_ll(i)-Disptsmf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptsmf_ll(i)/100;
for i=1:length(I)
    DGtsmf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ltsmf_ll(:,1) = unique(J(:,1));
for i=1:length(Ltsmf_ll)
    I = find(J(:,1)==Ltsmf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Ltsmf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Ltsmf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltsmf_ll(i,2) = J(I(K),2);
end


% Rocky Creek Fault
% upper residuals
nvecracf_ll = xlsread('Rocky_Creek_Fault_ul.xls','nvecrcf_3km','A2:C6000');
I = find(out1.fault.disp{1,5}(:,4)<-2700&out1.fault.disp{1,5}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,5}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecracf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecracf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STrcf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTrcf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disprcf_ul(i,1) = (out1.fault.disp{1,5}(I(i),5)^2 + out1.fault.disp{1,5}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STrcf_ul = STrcf_ul(I,1);
DTrcf_ul = DTrcf_ul(I,1);
Disprcf_ul = Disprcf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disprcf_ul(i)/100;
    else
        dg(i,1) = abs(Disprcf_ul(i)-Disprcf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disprcf_ul(i)/100;
for i=1:length(I)
    DGrcf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf_ul(:,1) = unique(J(:,1));
for i=1:length(Lrcf_ul)
    I = find(J(:,1)==Lrcf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lrcf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lrcf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecracf_ll = xlsread('Rocky_Creek_Fault.xls','nvecrcf_3km','A2:C6000');
I = find(out2.fault.disp{1,5}(:,4)<-2700&out2.fault.disp{1,5}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,5}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecracf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecracf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STrcf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTrcf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disprcf_ll(i,1) = (out2.fault.disp{1,5}(I(i),5)^2 + out2.fault.disp{1,5}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STrcf_ll = STrcf_ll(I,1);
DTrcf_ll = DTrcf_ll(I,1);
Disprcf_ll = Disprcf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disprcf_ll(i)/100;
    else
        dg(i,1) = abs(Disprcf_ll(i)-Disprcf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disprcf_ll(i)/100;
for i=1:length(I)
    DGrcf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
        J(i,1) = find(Dobs==min(Dobs));
        J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf_ll(:,1) = unique(J(:,1));
for i=1:length(Lrcf_ll)
    I = find(J(:,1)==Lrcf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lrcf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lrcf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf_ll(i,2) = J(I(K),2);
end


% Baker Lake Fault
% upper residuals
nvecblf_ul = xlsread('Baker_Lake_Fault_ul.xls','nvecrcf_3km','A2:C6000');
I = find(out1.fault.disp{1,6}(:,4)<-2700&out1.fault.disp{1,6}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,6}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecblf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecblf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STblf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTblf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispblf_ul(i,1) = (out1.fault.disp{1,6}(I(i),5)^2 + out1.fault.disp{1,6}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STblf_ul = STblf_ul(I,1);
DTblf_ul = DTblf_ul(I,1);
Dispblf_ul = Dispblf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispblf_ul(i)/100;
    else
        dg(i,1) = abs(Dispblf_ul(i)-Dispblf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispblf_ul(i)/100;
for i=1:length(I)
    DGblf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lblf_ul(:,1) = unique(J(:,1));
for i=1:length(Lblf_ul)
    I = find(J(:,1)==Lblf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lblf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lblf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lblf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecblf_ll = xlsread('Baker_Lake_Fault.xls','nvecrcf_3km','A2:C6000');
I = find(out2.fault.disp{1,6}(:,4)<-2700&out2.fault.disp{1,6}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,6}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecblf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecblf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STblf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTblf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispblf_ll(i,1) = (out2.fault.disp{1,6}(I(i),5)^2 + out2.fault.disp{1,6}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STblf_ll = STblf_ll(I,1);
DTblf_ll = DTblf_ll(I,1);
Dispblf_ll = Dispblf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispblf_ll(i)/100;
    else
        dg(i,1) = abs(Dispblf_ll(i)-Dispblf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispblf_ll(i)/100;
for i=1:length(I)
    DGblf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lblf_ll(:,1) = unique(J(:,1));
for i=1:length(Lblf_ll)
    I = find(J(:,1)==Lblf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lblf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lblf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lblf_ll(i,2) = J(I(K),2);
end


% Mount Watson Fault
% upper residuals
nvecmwf_ul = xlsread('Mount_Watson_Fault_ul.xls','nvecmwf_3km','A2:C6000');
I = find(out1.fault.disp{1,7}(:,4)<-2700&out1.fault.disp{1,7}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,7}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecmwf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecmwf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STmwf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTmwf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispmwf_ul(i,1) = (out1.fault.disp{1,7}(I(i),5)^2 + out1.fault.disp{1,7}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STmwf_ul = STmwf_ul(I,1);
DTmwf_ul = DTmwf_ul(I,1);
Dispmwf_ul = Dispmwf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispmwf_ul(i)/100;
    else
        dg(i,1) = abs(Dispmwf_ul(i)-Dispmwf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispmwf_ul(i)/100;
for i=1:length(I)
    DGmwf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lmwf_ul(:,1) = unique(J(:,1));
for i=1:length(Lmwf_ul)
    I = find(J(:,1)==Lmwf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lmwf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lmwf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lmwf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecmwf_ll = xlsread('Mount_Watson_Fault.xls','nvecmwf_3km','A2:C6000');
I = find(out2.fault.disp{1,7}(:,4)<-2700&out2.fault.disp{1,7}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,7}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecmwf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecmwf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STmwf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTmwf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispmwf_ll(i,1) = (out2.fault.disp{1,7}(I(i),5)^2 + out2.fault.disp{1,7}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STmwf_ll = STmwf_ll(I,1);
DTmwf_ll = DTmwf_ll(I,1);
Dispmwf_ll = Dispmwf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispmwf_ll(i)/100;
    else
        dg(i,1) = abs(Dispmwf_ll(i)-Dispmwf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispmwf_ll(i)/100;
for i=1:length(I)
    DGmwf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lmwf_ll(:,1) = unique(J(:,1));
for i=1:length(Lmwf_ll)
    I = find(J(:,1)==Lmwf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lmwf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lmwf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lmwf_ll(i,2) = J(I(K),2);
end


% Rainbow Creek Fault
% upper residuals
nvecracf_ul = xlsread('Rainbow_Creek_Fault_ul','nvecracf_3km','A2:C6000');
I = find(out1.fault.disp{1,8}(:,4)<-2700&out1.fault.disp{1,8}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,8}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecracf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecracf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STracf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTracf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispracf_ul(i,1) = (out1.fault.disp{1,8}(I(i),5)^2 + out1.fault.disp{1,8}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STracf_ul = STracf_ul(I,1);
DTracf_ul = DTracf_ul(I,1);
Dispracf_ul = Dispracf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispracf_ul(i)/100;
    else
        dg(i,1) = abs(Dispracf_ul(i)-Dispracf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispracf_ul(i)/100;
for i=1:length(I)
    DGracf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lracf_ul(:,1) = unique(J(:,1));
for i=1:length(Lracf_ul)
    I = find(J(:,1)==Lracf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lracf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lracf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lracf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecracf_ll = xlsread('Rainbow_Creek_Fault','nvecracf_3km','A2:C6000');
I = find(out2.fault.disp{1,8}(:,4)<-2700&out2.fault.disp{1,8}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,8}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecracf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecracf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STracf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTracf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispracf_ll(i,1) = (out2.fault.disp{1,8}(I(i),5)^2 + out2.fault.disp{1,8}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STracf_ll = STracf_ll(I,1);
DTracf_ll = DTracf_ll(I,1);
Dispracf_ll = Dispracf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispracf_ll(i)/100;
    else
        dg(i,1) = abs(Dispracf_ll(i)-Dispracf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispracf_ll(i)/100;
for i=1:length(I)
    DGracf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lracf_ll(:,1) = unique(J(:,1));
for i=1:length(Lracf_ll)
    I = find(J(:,1)==Lracf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lracf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lracf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lracf_ll(i,2) = J(I(K),2);
end


% Swift Creek Fault1
% upper residuals
nvecscf1_ul = xlsread('Swift_Creek_Fault_ul','nvecscf1_3km','A2:C6000');
I = find(out1.fault.disp{1,9}(:,4)<-2700&out1.fault.disp{1,9}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,9}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecscf1_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecscf1_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STscf1_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTscf1_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispscf1_ul(i,1) = (out1.fault.disp{1,9}(I(i),5)^2 + out1.fault.disp{1,9}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STscf1_ul = STscf1_ul(I,1);
DTscf1_ul = DTscf1_ul(I,1);
Dispscf1_ul = Dispscf1_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispscf1_ul(i)/100;
    else
        dg(i,1) = abs(Dispscf1_ul(i)-Dispscf1_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispscf1_ul(i)/100;
for i=1:length(I)
    DGscf1_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lscf1_ul(:,1) = unique(J(:,1));
for i=1:length(Lscf1_ul)
    I = find(J(:,1)==Lscf1_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lscf1_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lscf1_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lscf1_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecscf1_ll = xlsread('Swift_Creek_Fault','nvecscf1_3km','A2:C6000');
I = find(out2.fault.disp{1,9}(:,4)<-2700&out2.fault.disp{1,9}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,9}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecscf1_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecscf1_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STscf1_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTscf1_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispscf1_ll(i,1) = (out2.fault.disp{1,9}(I(i),5)^2 + out2.fault.disp{1,9}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STscf1_ll = STscf1_ll(I,1);
DTscf1_ll = DTscf1_ll(I,1);
Dispscf1_ll = Dispscf1_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispscf1_ll(i)/100;
    else
        dg(i,1) = abs(Dispscf1_ll(i)-Dispscf1_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispscf1_ll(i)/100;
for i=1:length(I)
    DGscf1_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lscf1_ll(:,1) = unique(J(:,1));
for i=1:length(Lscf1_ll)
    I = find(J(:,1)==Lscf1_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lscf1_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lscf1_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lscf1_ll(i,2) = J(I(K),2);
end


% Swift Creek Fault 2
% upper residuals
nvecscf2_ul = xlsread('Swift_Creek_Fault_ul.xls','nvecscf2_3km','A2:C6000');
I = find(out1.fault.disp{1,10}(:,4)<-2700&out1.fault.disp{1,10}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,10}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecscf2_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecscf2_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STscf2_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTscf2_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispscf2_ul(i,1) = (out1.fault.disp{1,10}(I(i),5)^2 + out1.fault.disp{1,10}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STscf2_ul = STscf2_ul(I,1);
DTscf2_ul = DTscf2_ul(I,1);
Dispscf2_ul = Dispscf2_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispscf2_ul(i)/100;
    else
        dg(i,1) = abs(Dispscf2_ul(i)-Dispscf2_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispscf2_ul(i)/100;
for i=1:length(I)
    DGscf2_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lscf2_ul(:,1) = unique(J(:,1));
for i=1:length(Lscf2_ul)
    I = find(J(:,1)==Lscf2_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lscf2_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lscf2_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lscf2_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecscf2_ll = xlsread('Swift_Creek_Fault.xls','nvecscf2_3km','A2:C6000');
I = find(out2.fault.disp{1,10}(:,4)<-2700&out2.fault.disp{1,10}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,10}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecscf2_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecscf2_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STscf2_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTscf2_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispscf2_ll(i,1) = (out2.fault.disp{1,10}(I(i),5)^2 + out2.fault.disp{1,10}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STscf2_ll = STscf2_ll(I,1);
DTscf2_ll = DTscf2_ll(I,1);
Dispscf2_ll = Dispscf2_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispscf2_ll(i)/100;
    else
        dg(i,1) = abs(Dispscf2_ll(i)-Dispscf2_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispscf2_ll(i)/100;
for i=1:length(I)
    DGscf2_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lscf2_ll(:,1) = unique(J(:,1));
for i=1:length(Lscf2_ll)
    I = find(J(:,1)==Lscf2_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lscf2_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lscf2_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lscf2_ll(i,2) = J(I(K),2);
end


% Swift Creek Fault 3
% upper residuals
nvecscf3_ul = xlsread('Swift_Creek_Fault_ul.xls','nvecscf3_3km','A2:C6000');
I = find(out1.fault.disp{1,11}(:,4)<-2700&out1.fault.disp{1,11}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,11}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecscf3_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecscf3_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STscf3_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTscf3_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispscf3_ul(i,1) = (out1.fault.disp{1,11}(I(i),5)^2 + out1.fault.disp{1,11}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STscf3_ul = STscf3_ul(I,1);
DTscf3_ul = DTscf3_ul(I,1);
Dispscf3_ul = Dispscf3_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispscf3_ul(i)/100;
    else
        dg(i,1) = abs(Dispscf3_ul(i)-Dispscf3_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispscf3_ul(i)/100;
for i=1:length(I)
    DGscf3_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lscf3_ul(:,1) = unique(J(:,1));
for i=1:length(Lscf3_ul)
    I = find(J(:,1)==Lscf3_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lscf3_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lscf3_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lscf3_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecscf3_ll = xlsread('Swift_Creek_Fault.xls','nvecscf3_3km','A2:C6000');
I = find(out2.fault.disp{1,11}(:,4)<-2700&out2.fault.disp{1,11}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,11}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecscf3_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecscf3_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STscf3_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTscf3_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispscf3_ll(i,1) = (out2.fault.disp{1,11}(I(i),5)^2 + out2.fault.disp{1,11}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STscf3_ll = STscf3_ll(I,1);
DTscf3_ll = DTscf3_ll(I,1);
Dispscf3_ll = Dispscf3_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispscf3_ll(i)/100;
    else
        dg(i,1) = abs(Dispscf3_ll(i)-Dispscf3_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispscf3_ll(i)/100;
for i=1:length(I)
    DGscf3_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lscf3_ll(:,1) = unique(J(:,1));
for i=1:length(Lscf3_ll)
    I = find(J(:,1)==Lscf3_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lscf3_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lscf3_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lscf3_ll(i,2) = J(I(K),2);
end


% Damfino Fault
% upper residuals
nvecdf_ul = xlsread('Damfino_Fault_ul.xls','nvecdf_3km','A2:C6000');
I = find(out1.fault.disp{1,12}(:,4)<-2700&out1.fault.disp{1,12}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,12}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecdf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecdf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STdf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTdf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispdf_ul(i,1) = (out1.fault.disp{1,12}(I(i),5)^2 + out1.fault.disp{1,12}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STdf_ul = STdf_ul(I,1);
DTdf_ul = DTdf_ul(I,1);
Dispdf_ul = Dispdf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispdf_ul(i)/100;
    else
        dg(i,1) = abs(Dispdf_ul(i)-Dispdf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispdf_ul(i)/100;
for i=1:length(I)
    DGdf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ldf_ul(:,1) = unique(J(:,1));
for i=1:length(Ldf_ul)
    I = find(J(:,1)==Ldf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Ldf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Ldf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ldf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecdf_ll = xlsread('Damfino_Fault.xls','nvecdf_3km','A2:C6000');
I = find(out2.fault.disp{1,12}(:,4)<-2700&out2.fault.disp{1,12}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,12}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecdf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecdf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STdf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTdf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispdf_ll(i,1) = (out2.fault.disp{1,12}(I(i),5)^2 + out2.fault.disp{1,12}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STdf_ll = STdf_ll(I,1);
DTdf_ll = DTdf_ll(I,1);
Dispdf_ll = Dispdf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispdf_ll(i)/100;
    else
        dg(i,1) = abs(Dispdf_ll(i)-Dispdf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispdf_ll(i)/100;
for i=1:length(I)
    DGdf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ldf_ll(:,1) = unique(J(:,1));
for i=1:length(Ldf_ll)
    I = find(J(:,1)==Ldf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Ldf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Ldf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ldf_ll(i,2) = J(I(K),2);
end


% Slate Mountain Fault
% upper residuals
nvecsmf_ul = xlsread('Slate_Mountain_Fault_ul.xls','nvecsmf_3km','A2:C6000');
I = find(out1.fault.disp{1,13}(:,4)<-2700&out1.fault.disp{1,13}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,13}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecsmf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsmf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsmf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsmf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispsmf_ul(i,1) = (out1.fault.disp{1,13}(I(i),5)^2 + out1.fault.disp{1,13}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsmf_ul = STsmf_ul(I,1);
DTsmf_ul = DTsmf_ul(I,1);
Dispsmf_ul = Dispsmf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispsmf_ul(i)/100;
    else
        dg(i,1) = abs(Dispsmf_ul(i)-Dispsmf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispsmf_ul(i)/100;
for i=1:length(I)
    DGsmf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lsmf_ul(:,1) = unique(J(:,1));
for i=1:length(Lsmf_ul)
    I = find(J(:,1)==Lsmf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lsmf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lsmf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsmf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecsmf_ll = xlsread('Slate_Mountain_Fault.xls','nvecsmf_3km','A2:C6000');
I = find(out1.fault.disp{1,13}(:,4)<-2700&out1.fault.disp{1,13}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,13}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecsmf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsmf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsmf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsmf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispsmf_ll(i,1) = (out1.fault.disp{1,13}(I(i),5)^2 + out1.fault.disp{1,13}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsmf_ll = STsmf_ll(I,1);
DTsmf_ll = DTsmf_ll(I,1);
Dispsmf_ll = Dispsmf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispsmf_ll(i)/100;
    else
        dg(i,1) = abs(Dispsmf_ll(i)-Dispsmf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispsmf_ll(i)/100;
for i=1:length(I)
    DGsmf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lsmf_ll(:,1) = unique(J(:,1));
for i=1:length(Lsmf_ll)
    I = find(J(:,1)==Lsmf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lsmf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lsmf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsmf_ll(i,2) = J(I(K),2);
end


% Barometer Mountain Fault
% upper residuals
nvecbmf_ul = xlsread('Barometer_Mountain_Fault_ul.xls','nvecbmf_3km','A2:C6000');
I = find(out1.fault.disp{1,14}(:,4)<-2700&out1.fault.disp{1,14}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,14}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecbmf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbmf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbmf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbmf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispbmf_ul(i,1) = (out1.fault.disp{1,14}(I(i),5)^2 + out1.fault.disp{1,14}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbmf_ul = STbmf_ul(I,1);
DTbmf_ul = DTbmf_ul(I,1);
Dispbmf_ul = Dispbmf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbmf_ul(i)/100;
    else
        dg(i,1) = abs(Dispbmf_ul(i)-Dispbmf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbmf_ul(i)/100;
for i=1:length(I)
    DGbmf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbmf_ul(:,1) = unique(J(:,1));
for i=1:length(Lbmf_ul)
    I = find(J(:,1)==Lbmf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lbmf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lbmf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbmf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecbmf_ll = xlsread('Barometer_Mountain_Fault.xls','nvecbmf_3km','A2:C6000');
I = find(out2.fault.disp{1,14}(:,4)<-2700&out2.fault.disp{1,14}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,14}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecbmf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbmf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbmf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbmf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispbmf_ll(i,1) = (out2.fault.disp{1,14}(I(i),5)^2 + out2.fault.disp{1,14}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbmf_ll = STbmf_ll(I,1);
DTbmf_ll = DTbmf_ll(I,1);
Dispbmf_ll = Dispbmf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbmf_ll(i)/100;
    else
        dg(i,1) = abs(Dispbmf_ll(i)-Dispbmf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbmf_ll(i)/100;
for i=1:length(I)
    DGbmf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lbmf_ll(:,1) = unique(J(:,1));
for i=1:length(Lbmf_ll)
    I = find(J(:,1)==Lbmf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lbmf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lbmf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbmf_ll(i,2) = J(I(K),2);
end


% Table Mountain Fault
% upper residuals
nvectmf_ul = xlsread('Table_Mountain_Fault_ul.xls','nvectmf_3km','A2:C6000');
I = find(out1.fault.disp{1,15}(:,4)<-2700&out1.fault.disp{1,15}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,15}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvectmf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectmf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtmf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtmf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disptmf_ul(i,1) = (out1.fault.disp{1,15}(I(i),5)^2 + out1.fault.disp{1,15}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtmf_ul = STtmf_ul(I,1);
DTtmf_ul = DTtmf_ul(I,1);
Disptmf_ul = Disptmf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptmf_ul(i)/100;
    else
        dg(i,1) = abs(Disptmf_ul(i)-Disptmf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptmf_ul(i)/100;
for i=1:length(I)
    DGtmf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ltmf_ul(:,1) = unique(J(:,1));
for i=1:length(Ltmf_ul)
    I = find(J(:,1)==Ltmf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Ltmf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Ltmf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltmf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvectmf_ll = xlsread('Table_Mountain_Fault.xls','nvectmf_3km','A2:C6000');
I = find(out2.fault.disp{1,15}(:,4)<-2700&out2.fault.disp{1,15}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,15}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvectmf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectmf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtmf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtmf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disptmf_ll(i,1) = (out2.fault.disp{1,15}(I(i),5)^2 + out2.fault.disp{1,15}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtmf_ll = STtmf_ll(I,1);
DTtmf_ll = DTtmf_ll(I,1);
Disptmf_ll = Disptmf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptmf_ll(i)/100;
    else
        dg(i,1) = abs(Disptmf_ll(i)-Disptmf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptmf_ll(i)/100;
for i=1:length(I)
    DGtmf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ltmf_ll(:,1) = unique(J(:,1));
for i=1:length(Ltmf_ll)
    I = find(J(:,1)==Ltmf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Ltmf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Ltmf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltmf_ll(i,2) = J(I(K),2);
end


% Winchester Fault
% upper residuals
nvecwf_ul = xlsread('Winchester_Fault_ul.xls','nvecwf_3km','A2:C6000');
I = find(out1.fault.disp{1,16}(:,4)<-2700&out1.fault.disp{1,16}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,16}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecwf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispwf_ul(i,1) = (out1.fault.disp{1,16}(I(i),5)^2 + out1.fault.disp{1,16}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwf_ul = STwf_ul(I,1);
DTwf_ul = DTwf_ul(I,1);
Dispwf_ul = Dispwf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwf_ul(i)/100;
    else
        dg(i,1) = abs(Dispwf_ul(i)-Dispwf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwf_ul(i)/100;
for i=1:length(I)
    DGwf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwf_ul(:,1) = unique(J(:,1));
for i=1:length(Lwf_ul)
    I = find(J(:,1)==Lwf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecwf_ll = xlsread('Winchester_Fault.xls','nvecwf_3km','A2:C6000');
I = find(out2.fault.disp{1,16}(:,4)<-2700&out2.fault.disp{1,16}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,16}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecwf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispwf_ll(i,1) = (out2.fault.disp{1,16}(I(i),5)^2 + out2.fault.disp{1,16}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwf_ll = STwf_ll(I,1);
DTwf_ll = DTwf_ll(I,1);
Dispwf_ll = Dispwf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwf_ll(i)/100;
    else
        dg(i,1) = abs(Dispwf_ll(i)-Dispwf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwf_ll(i)/100;
for i=1:length(I)
    DGwf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwf_ll(:,1) = unique(J(:,1));
for i=1:length(Lwf_ll)
    I = find(J(:,1)==Lwf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lwf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lwf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwf_ll(i,2) = J(I(K),2);
end


% Nooksack River Fault 1
% upper residuals
nvecnrf1_ul = xlsread('Nooksack_River_Fault_ul.xls','nvecnrf1_3km','A2:C6000');
I = find(out1.fault.disp{1,17}(:,4)<-2700&out1.fault.disp{1,17}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,17}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnrf1_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf1_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf1_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf1_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnrf1_ul(i,1) = (out1.fault.disp{1,17}(I(i),5)^2 + out1.fault.disp{1,17}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf1_ul = STnrf1_ul(I,1);
DTnrf1_ul = DTnrf1_ul(I,1);
Dispnrf1_ul = Dispnrf1_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf1_ul(i)/100;
    else
        dg(i,1) = abs(Dispnrf1_ul(i)-Dispnrf1_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf1_ul(i)/100;
for i=1:length(I)
    DGnrf1_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf1_ul(:,1) = unique(J(:,1));
for i=1:length(Lnrf1_ul)
    I = find(J(:,1)==Lnrf1_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lnrf1_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lnrf1_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf1_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecnrf1_ll = xlsread('Nooksack_River_Fault.xls','nvecnrf1_3km','A2:C6000');
I = find(out2.fault.disp{1,17}(:,4)<-2700&out2.fault.disp{1,17}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,17}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnrf1_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf1_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf1_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf1_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnrf1_ll(i,1) = (out2.fault.disp{1,17}(I(i),5)^2 + out2.fault.disp{1,17}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf1_ll = STnrf1_ll(I,1);
DTnrf1_ll = DTnrf1_ll(I,1);
Dispnrf1_ll = Dispnrf1_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf1_ll(i)/100;
    else
        dg(i,1) = abs(Dispnrf1_ll(i)-Dispnrf1_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf1_ll(i)/100;
for i=1:length(I)
    DGnrf1_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf1_ll(:,1) = unique(J(:,1));
for i=1:length(Lnrf1_ll)
    I = find(J(:,1)==Lnrf1_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lnrf1_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lnrf1_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf1_ll(i,2) = J(I(K),2);
end


% Nooksack River Fault 2
% upper residuals
nvecnrf2_ul = xlsread('Nooksack_River_Fault_ul.xls','nvecnrf2_3km','A2:C6000');
I = find(out1.fault.disp{1,18}(:,4)<-2700&out1.fault.disp{1,18}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,18}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnrf2_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf2_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf2_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf2_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnrf2_ul(i,1) = (out1.fault.disp{1,18}(I(i),5)^2 + out1.fault.disp{1,18}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf2_ul = STnrf2_ul(I,1);
DTnrf2_ul = DTnrf2_ul(I,1);
Dispnrf2_ul = Dispnrf2_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf2_ul(i)/100;
    else
        dg(i,1) = abs(Dispnrf2_ul(i)-Dispnrf2_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf2_ul(i)/100;
for i=1:length(I)
    DGnrf2_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf2_ul(:,1) = unique(J(:,1));
for i=1:length(Lnrf2_ul)
    I = find(J(:,1)==Lnrf2_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lnrf2_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lnrf2_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf2_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecnrf2_ll = xlsread('Nooksack_River_Fault.xls','nvecnrf2_3km','A2:C6000');
I = find(out2.fault.disp{1,18}(:,4)<-2700&out2.fault.disp{1,18}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,18}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnrf2_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf2_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf2_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf2_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnrf2_ll(i,1) = (out2.fault.disp{1,18}(I(i),5)^2 + out2.fault.disp{1,18}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf2_ll = STnrf2_ll(I,1);
DTnrf2_ll = DTnrf2_ll(I,1);
Dispnrf2_ll = Dispnrf2_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf2_ll(i)/100;
    else
        dg(i,1) = abs(Dispnrf2_ll(i)-Dispnrf2_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf2_ll(i)/100;
for i=1:length(I)
    DGnrf2_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf2_ll(:,1) = unique(J(:,1));
for i=1:length(Lnrf2_ll)
    I = find(J(:,1)==Lnrf2_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lnrf2_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lnrf2_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf2_ll(i,2) = J(I(K),2);
end


% Nooksack River Fault 3a
% upper residuals
nvecnrf3a_ul = xlsread('Nooksack_River_Fault_ul.xls','nvecnrf3a_3km','A2:C6000');
I = find(out1.fault.disp{1,19}(:,4)<-2700&out1.fault.disp{1,19}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,19}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnrf3a_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf3a_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf3a_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf3a_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnrf3a_ul(i,1) = (out1.fault.disp{1,19}(I(i),5)^2 + out1.fault.disp{1,19}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf3a_ul = STnrf3a_ul(I,1);
DTnrf3a_ul = DTnrf3a_ul(I,1);
Dispnrf3a_ul = Dispnrf3a_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf3a_ul(i)/100;
    else
        dg(i,1) = abs(Dispnrf3a_ul(i)-Dispnrf3a_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf3a_ul(i)/100;
for i=1:length(I)
    DGnrf3a_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf3a_ul(:,1) = unique(J(:,1));
for i=1:length(Lnrf3a_ul)
    I = find(J(:,1)==Lnrf3a_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lnrf3a_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lnrf3a_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf3a_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecnrf3a_ll = xlsread('Nooksack_River_Fault.xls','nvecnrf3a_3km','A2:C6000');
I = find(out2.fault.disp{1,19}(:,4)<-2700&out2.fault.disp{1,19}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,19}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnrf3a_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf3a_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf3a_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf3a_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnrf3a_ll(i,1) = (out2.fault.disp{1,19}(I(i),5)^2 + out2.fault.disp{1,19}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf3a_ll = STnrf3a_ll(I,1);
DTnrf3a_ll = DTnrf3a_ll(I,1);
Dispnrf3a_ll = Dispnrf3a_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf3a_ll(i)/100;
    else
        dg(i,1) = abs(Dispnrf3a_ll(i)-Dispnrf3a_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf3a_ll(i)/100;
for i=1:length(I)
    DGnrf3a_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf3a_ll(:,1) = unique(J(:,1));
for i=1:length(Lnrf3a_ll)
    I = find(J(:,1)==Lnrf3a_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lnrf3a_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lnrf3a_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf3a_ll(i,2) = J(I(K),2);
end


% Nooksack River Fault 3b
% upper residuals
nvecnrf3b_ul = xlsread('Nooksack_River_Fault_ul.xls','nvecnrf3b_3km','A2:C6000');
I = find(out1.fault.disp{1,20}(:,4)<-2700&out1.fault.disp{1,20}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,20}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnrf3b_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf3b_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf3b_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf3b_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnrf3b_ul(i,1) = (out1.fault.disp{1,20}(I(i),5)^2 + out1.fault.disp{1,20}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf3b_ul = STnrf3b_ul(I,1);
DTnrf3b_ul = DTnrf3b_ul(I,1);
Dispnrf3b_ul = Dispnrf3b_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf3b_ul(i)/100;
    else
        dg(i,1) = abs(Dispnrf3b_ul(i)-Dispnrf3b_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf3b_ul(i)/100;
for i=1:length(I)
    DGnrf3b_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf3b_ul(:,1) = unique(J(:,1));
for i=1:length(Lnrf3b_ul)
    I = find(J(:,1)==Lnrf3b_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lnrf3b_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lnrf3b_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf3b_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecnrf3b_ll = xlsread('Nooksack_River_Fault.xls','nvecnrf3b_3km','A2:C6000');
I = find(out2.fault.disp{1,20}(:,4)<-2700&out2.fault.disp{1,20}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,20}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnrf3b_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnrf3b_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnrf3b_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnrf3b_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnrf3b_ll(i,1) = (out2.fault.disp{1,20}(I(i),5)^2 + out2.fault.disp{1,20}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnrf3b_ll = STnrf3b_ll(I,1);
DTnrf3b_ll = DTnrf3b_ll(I,1);
Dispnrf3b_ll = Dispnrf3b_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnrf3b_ll(i)/100;
    else
        dg(i,1) = abs(Dispnrf3b_ll(i)-Dispnrf3b_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnrf3b_ll(i)/100;
for i=1:length(I)
    DGnrf3b_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnrf3b_ll(:,1) = unique(J(:,1));
for i=1:length(Lnrf3b_ll)
    I = find(J(:,1)==Lnrf3b_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lnrf3b_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lnrf3b_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnrf3b_ll(i,2) = J(I(K),2);
end


% Thompson Creek Fault
% upper residuals
nvectcf_ul = xlsread('Thompson_Creek_Fault_ul.xls','nvectcf_3km','A2:C6000');
I = find(out1.fault.disp{1,21}(:,4)<-2700&out1.fault.disp{1,21}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,21}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvectcf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectcf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtcf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtcf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disptcf_ul(i,1) = (out1.fault.disp{1,21}(I(i),5)^2 + out1.fault.disp{1,21}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtcf_ul = STtcf_ul(I,1);
DTtcf_ul = DTtcf_ul(I,1);
Disptcf_ul = Disptcf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptcf_ul(i)/100;
    else
        dg(i,1) = abs(Disptcf_ul(i)-Disptcf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptcf_ul(i)/100;
for i=1:length(I)
    DGtcf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ltcf_ul(:,1) = unique(J(:,1));
for i=1:length(Ltcf_ul)
    I = find(J(:,1)==Ltcf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Ltcf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Ltcf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltcf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvectcf_ll = xlsread('Thompson_Creek_Fault.xls','nvectcf_3km','A2:C6000');
I = find(out2.fault.disp{1,21}(:,4)<-2700&out2.fault.disp{1,21}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,21}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvectcf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvectcf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STtcf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTtcf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disptcf_ll(i,1) = (out2.fault.disp{1,21}(I(i),5)^2 + out2.fault.disp{1,21}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STtcf_ll = STtcf_ll(I,1);
DTtcf_ll = DTtcf_ll(I,1);
Disptcf_ll = Disptcf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disptcf_ll(i)/100;
    else
        dg(i,1) = abs(Disptcf_ll(i)-Disptcf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disptcf_ll(i)/100;
for i=1:length(I)
    DGtcf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Ltcf_ll(:,1) = unique(J(:,1));
for i=1:length(Ltcf_ll)
    I = find(J(:,1)==Ltcf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Ltcf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Ltcf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Ltcf_ll(i,2) = J(I(K),2);
end


% Gallop Creek Fault
% upper residuals
nvecgcf_ul = xlsread('Gallop_Creek_Fault_ul.xls','nvecgcf_3km','A2:C6000');
I = find(out1.fault.disp{1,22}(:,4)<-2700&out1.fault.disp{1,22}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,22}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecgcf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecgcf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STgcf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTgcf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispgcf_ul(i,1) = (out1.fault.disp{1,22}(I(i),5)^2 + out1.fault.disp{1,22}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STgcf_ul = STgcf_ul(I,1);
DTgcf_ul = DTgcf_ul(I,1);
Dispgcf_ul = Dispgcf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispgcf_ul(i)/100;
    else
        dg(i,1) = abs(Dispgcf_ul(i)-Dispgcf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispgcf_ul(i)/100;
for i=1:length(I)
    DGgcf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lgcf_ul(:,1) = unique(J(:,1));
for i=1:length(Lgcf_ul)
    I = find(J(:,1)==Lgcf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lgcf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lgcf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lgcf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecgcf_ll = xlsread('Gallop_Creek_Fault.xls','nvecgcf_3km','A2:C6000');
I = find(out2.fault.disp{1,22}(:,4)<-2700&out2.fault.disp{1,22}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,22}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecgcf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecgcf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STgcf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTgcf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispgcf_ll(i,1) = (out2.fault.disp{1,22}(I(i),5)^2 + out2.fault.disp{1,22}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STgcf_ll = STgcf_ll(I,1);
DTgcf_ll = DTgcf_ll(I,1);
Dispgcf_ll = Dispgcf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispgcf_ll(i)/100;
    else
        dg(i,1) = abs(Dispgcf_ll(i)-Dispgcf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispgcf_ll(i)/100;
for i=1:length(I)
    DGgcf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lgcf_ll(:,1) = unique(J(:,1));
for i=1:length(Lgcf_ll)
    I = find(J(:,1)==Lgcf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lgcf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lgcf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lgcf_ll(i,2) = J(I(K),2);
end


% Warm Creek Fault 1
% upper residuals
nvecwcf1_ul = xlsread('Warm_Creek_Fault_ul.xls','nvecwcf1_3km','A2:C6000');
I = find(out1.fault.disp{1,23}(:,4)<-2700&out1.fault.disp{1,23}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,23}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecwcf1_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwcf1_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwcf1_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwcf1_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispwcf1_ul(i,1) = (out1.fault.disp{1,23}(I(i),5)^2 + out1.fault.disp{1,23}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwcf1_ul = STwcf1_ul(I,1);
DTwcf1_ul = DTwcf1_ul(I,1);
Dispwcf1_ul = Dispwcf1_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwcf1_ul(i)/100;
    else
        dg(i,1) = abs(Dispwcf1_ul(i)-Dispwcf1_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwcf1_ul(i)/100;
for i=1:length(I)
    DGwcf1_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwcf1_ul(:,1) = unique(J(:,1));
for i=1:length(Lwcf1_ul)
    I = find(J(:,1)==Lwcf1_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwcf1_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwcf1_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwcf1_ul(i,2) = J(I(K),2);
end
% upper residuals
nvecwcf1_ll = xlsread('Warm_Creek_Fault.xls','nvecwcf1_3km','A2:C6000');
I = find(out2.fault.disp{1,23}(:,4)<-2700&out2.fault.disp{1,23}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,23}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecwcf1_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwcf1_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwcf1_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwcf1_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispwcf1_ll(i,1) = (out2.fault.disp{1,23}(I(i),5)^2 + out2.fault.disp{1,23}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwcf1_ll = STwcf1_ll(I,1);
DTwcf1_ll = DTwcf1_ll(I,1);
Dispwcf1_ll = Dispwcf1_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwcf1_ll(i)/100;
    else
        dg(i,1) = abs(Dispwcf1_ll(i)-Dispwcf1_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwcf1_ll(i)/100;
for i=1:length(I)
    DGwcf1_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwcf1_ll(:,1) = unique(J(:,1));
for i=1:length(Lwcf1_ll)
    I = find(J(:,1)==Lwcf1_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lwcf1_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lwcf1_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwcf1_ll(i,2) = J(I(K),2);
end


% Warm Creek Fault 2
% upper residuals
nvecwcf2_ul = xlsread('Warm_Creek_Fault_ul.xls','nvecwcf2_3km','A2:C6000');
I = find(out1.fault.disp{1,24}(:,4)<-2700&out1.fault.disp{1,24}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,24}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecwcf2_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwcf2_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwcf2_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwcf2_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispwcf2_ul(i,1) = (out1.fault.disp{1,24}(I(i),5)^2 + out1.fault.disp{1,24}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwcf2_ul = STwcf2_ul(I,1);
DTwcf2_ul = DTwcf2_ul(I,1);
Dispwcf2_ul = Dispwcf2_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwcf2_ul(i)/100;
    else
        dg(i,1) = abs(Dispwcf2_ul(i)-Dispwcf2_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwcf2_ul(i)/100;
for i=1:length(I)
    DGwcf2_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwcf2_ul(:,1) = unique(J(:,1));
for i=1:length(Lwcf2_ul)
    I = find(J(:,1)==Lwcf2_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwcf2_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwcf2_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwcf2_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecwcf2_ll = xlsread('Warm_Creek_Fault.xls','nvecwcf2_3km','A2:C6000');
I = find(out2.fault.disp{1,24}(:,4)<-2700&out2.fault.disp{1,24}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,24}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecwcf2_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwcf2_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwcf2_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwcf2_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispwcf2_ll(i,1) = (out2.fault.disp{1,24}(I(i),5)^2 + out2.fault.disp{1,24}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwcf2_ll = STwcf2_ll(I,1);
DTwcf2_ll = DTwcf2_ll(I,1);
Dispwcf2_ll = Dispwcf2_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwcf2_ll(i)/100;
    else
        dg(i,1) = abs(Dispwcf2_ll(i)-Dispwcf2_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwcf2_ll(i)/100;
for i=1:length(I)
    DGwcf2_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwcf2_ll(:,1) = unique(J(:,1));
for i=1:length(Lwcf2_ll)
    I = find(J(:,1)==Lwcf2_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lwcf2_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lwcf2_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwcf2_ll(i,2) = J(I(K),2);
end


% Loomis Mountain Fault
% upper residuals
nveclmf_ul = xlsread('Loomis_Mountain_Fault_ul.xls','nveclmf_3km','A2:C6000');
I = find(out1.fault.disp{1,25}(:,4)<-2700&out1.fault.disp{1,25}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,25}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nveclmf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveclmf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STlmf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTlmf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Displmf_ul(i,1) = (out1.fault.disp{1,25}(I(i),5)^2 + out1.fault.disp{1,25}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STlmf_ul = STlmf_ul(I,1);
DTlmf_ul = DTlmf_ul(I,1);
Displmf_ul = Displmf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Displmf_ul(i)/100;
    else
        dg(i,1) = abs(Displmf_ul(i)-Displmf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Displmf_ul(i)/100;
for i=1:length(I)
    DGlmf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Llmf_ul(:,1) = unique(J(:,1));
for i=1:length(Llmf_ul)
    I = find(J(:,1)==Llmf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Llmf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Llmf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Llmf_ul(i,2) = J(I(K),2);
end
% lower residuals
nveclmf_ll = xlsread('Loomis_Mountain_Fault.xls','nveclmf_3km','A2:C6000');
I = find(out2.fault.disp{1,25}(:,4)<-2700&out2.fault.disp{1,25}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,25}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nveclmf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveclmf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STlmf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTlmf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Displmf_ll(i,1) = (out2.fault.disp{1,25}(I(i),5)^2 + out2.fault.disp{1,25}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STlmf_ll = STlmf_ll(I,1);
DTlmf_ll = DTlmf_ll(I,1);
Displmf_ll = Displmf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Displmf_ll(i)/100;
    else
        dg(i,1) = abs(Displmf_ll(i)-Displmf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Displmf_ll(i)/100;
for i=1:length(I)
    DGlmf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Llmf_ll(:,1) = unique(J(:,1));
for i=1:length(Llmf_ll)
    I = find(J(:,1)==Llmf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Llmf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Llmf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Llmf_ll(i,2) = J(I(K),2);
end


% Wanlick Creek Fault
% upper residuals
nvecwcf_ul = xlsread('Wanlick_Creek_Fault_ul.xls','nvecwcf_3km','A2:C6000');
I = find(out1.fault.disp{1,26}(:,4)<-2700&out1.fault.disp{1,26}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,26}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecwcf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwcf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwcf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwcf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispwcf_ul(i,1) = (out1.fault.disp{1,26}(I(i),5)^2 + out1.fault.disp{1,26}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwcf_ul = STwcf_ul(I,1);
DTwcf_ul = DTwcf_ul(I,1);
Dispwcf_ul = Dispwcf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwcf_ul(i)/100;
    else
        dg(i,1) = abs(Dispwcf_ul(i)-Dispwcf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwcf_ul(i)/100;
for i=1:length(I)
    DGwcf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwcf_ul(:,1) = unique(J(:,1));
for i=1:length(Lwcf_ul)
    I = find(J(:,1)==Lwcf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwcf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwcf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwcf_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecwcf_ll = xlsread('Wanlick_Creek_Fault.xls','nvecwcf_3km','A2:C6000');
I = find(out2.fault.disp{1,26}(:,4)<-2700&out2.fault.disp{1,26}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,26}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecwcf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwcf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwcf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwcf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispwcf_ll(i,1) = (out2.fault.disp{1,26}(I(i),5)^2 + out2.fault.disp{1,26}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwcf_ll = STwcf_ll(I,1);
DTwcf_ll = DTwcf_ll(I,1);
Dispwcf_ll = Dispwcf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispwcf_ll(i)/100;
    else
        dg(i,1) = abs(Dispwcf_ll(i)-Dispwcf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispwcf_ll(i)/100;
for i=1:length(I)
    DGwcf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwcf_ll(:,1) = unique(J(:,1));
for i=1:length(Lwcf_ll)
    I = find(J(:,1)==Lwcf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lwcf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lwcf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwcf_ll(i,2) = J(I(K),2);
end


% Chilliwack River Fault
% upper residuals
nveccrf_ul = xlsread('Chilliwack_River_Fault_ul.xls','nveccrf_3km','A2:C6000');
I = find(out1.fault.disp{1,27}(:,4)<-2700&out1.fault.disp{1,27}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,27}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nveccrf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveccrf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STcrf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTcrf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispcrf_ul(i,1) = (out1.fault.disp{1,27}(I(i),5)^2 + out1.fault.disp{1,27}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STcrf_ul = STcrf_ul(I,1);
DTcrf_ul = DTcrf_ul(I,1);
Dispcrf_ul = Dispcrf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispcrf_ul(i)/100;
    else
        dg(i,1) = abs(Dispcrf_ul(i)-Dispcrf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispcrf_ul(i)/100;
for i=1:length(I)
    DGcrf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lcrf_ul(:,1) = unique(J(:,1));
for i=1:length(Lcrf_ul)
    I = find(J(:,1)==Lcrf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lcrf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lcrf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lcrf_ul(i,2) = J(I(K),2);
end
% lower residuals
nveccrf_ll = xlsread('Chilliwack_River_Fault.xls','nveccrf_3km','A2:C6000');
I = find(out2.fault.disp{1,27}(:,4)<-2700&out2.fault.disp{1,27}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,27}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nveccrf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveccrf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STcrf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTcrf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispcrf_ll(i,1) = (out2.fault.disp{1,27}(I(i),5)^2 + out2.fault.disp{1,27}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STcrf_ll = STcrf_ll(I,1);
DTcrf_ll = DTcrf_ll(I,1);
Dispcrf_ll = Dispcrf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispcrf_ll(i)/100;
    else
        dg(i,1) = abs(Dispcrf_ll(i)-Dispcrf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispcrf_ll(i)/100;
for i=1:length(I)
    DGcrf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lcrf_ll(:,1) = unique(J(:,1));
for i=1:length(Lcrf_ll)
    I = find(J(:,1)==Lcrf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lcrf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lcrf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lcrf_ll(i,2) = J(I(K),2);
end


% Ruth Creek Fault 1
% upper residuals
nvecrcf1_ul = xlsread('Ruth_Creek_Fault_ul.xls','nvecrcf1_3km','A2:C6000');
I = find(out1.fault.disp{1,28}(:,4)<-2700&out1.fault.disp{1,28}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,28}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecrcf1_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecrcf1_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STrcf1_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTrcf1_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disprcf1_ul(i,1) = (out1.fault.disp{1,28}(I(i),5)^2 + out1.fault.disp{1,28}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STrcf1_ul = STrcf1_ul(I,1);
DTrcf1_ul = DTrcf1_ul(I,1);
Disprcf1_ul = Disprcf1_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disprcf1_ul(i)/100;
    else
        dg(i,1) = abs(Disprcf1_ul(i)-Disprcf1_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disprcf1_ul(i)/100;
for i=1:length(I)
    DGrcf1_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf1_ul(:,1) = unique(J(:,1));
for i=1:length(Lrcf1_ul)
    I = find(J(:,1)==Lrcf1_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lrcf1_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lrcf1_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf1_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecrcf1_ll = xlsread('Ruth_Creek_Fault.xls','nvecrcf1_3km','A2:C6000');
I = find(out2.fault.disp{1,28}(:,4)<-2700&out2.fault.disp{1,28}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,28}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecrcf1_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecrcf1_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STrcf1_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTrcf1_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disprcf1_ll(i,1) = (out2.fault.disp{1,28}(I(i),5)^2 + out2.fault.disp{1,28}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STrcf1_ll = STrcf1_ll(I,1);
DTrcf1_ll = DTrcf1_ll(I,1);
Disprcf1_ll = Disprcf1_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disprcf1_ll(i)/100;
    else
        dg(i,1) = abs(Disprcf1_ll(i)-Disprcf1_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disprcf1_ll(i)/100;
for i=1:length(I)
    DGrcf1_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf1_ll(:,1) = unique(J(:,1));
for i=1:length(Lrcf1_ll)
    I = find(J(:,1)==Lrcf1_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lrcf1_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lrcf1_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf1_ll(i,2) = J(I(K),2);
end


% Ruth Creek Fault 2
% upper residuals
nvecrcf2_ul = xlsread('Ruth_Creek_Fault_ul.xls','nvecrcf2_3km','A2:C6000');
I = find(out1.fault.disp{1,29}(:,4)<-2700&out1.fault.disp{1,29}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,29}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecrcf2_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecrcf2_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STrcf2_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTrcf2_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disprcf2_ul(i,1) = (out1.fault.disp{1,29}(I(i),5)^2 + out1.fault.disp{1,29}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STrcf2_ul = STrcf2_ul(I,1);
DTrcf2_ul = DTrcf2_ul(I,1);
Disprcf2_ul = Disprcf2_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disprcf2_ul(i)/100;
    else
        dg(i,1) = abs(Disprcf2_ul(i)-Disprcf2_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disprcf2_ul(i)/100;
for i=1:length(I)
    DGrcf2_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf2_ul(:,1) = unique(J(:,1));
for i=1:length(Lrcf2_ul)
    I = find(J(:,1)==Lrcf2_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lrcf2_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lrcf2_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf2_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecrcf2_ll = xlsread('Ruth_Creek_Fault.xls','nvecrcf2_3km','A2:C6000');
I = find(out2.fault.disp{1,29}(:,4)<-2700&out2.fault.disp{1,29}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,29}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecrcf2_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecrcf2_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STrcf2_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTrcf2_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Disprcf2_ll(i,1) = (out2.fault.disp{1,29}(I(i),5)^2 + out2.fault.disp{1,29}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STrcf2_ll = STrcf2_ll(I,1);
DTrcf2_ll = DTrcf2_ll(I,1);
Disprcf2_ll = Disprcf2_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Disprcf2_ll(i)/100;
    else
        dg(i,1) = abs(Disprcf2_ll(i)-Disprcf2_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Disprcf2_ll(i)/100;
for i=1:length(I)
    DGrcf2_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lrcf2_ll(:,1) = unique(J(:,1));
for i=1:length(Lrcf2_ll)
    I = find(J(:,1)==Lrcf2_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lrcf2_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lrcf2_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lrcf2_ll(i,2) = J(I(K),2);
end


% % Glacier Extensional Fault 1
% % upper residuals
% nvecgex1_ul = xlsread('Glacier_Extensional_Fault_ul.xls','nvecgex1_200m','A2:C6000');
% I = find(out1.fault.disp{1,30}(:,4)<-2700&out1.fault.disp{1,30}(:,4)>-3000);
% % Tractions
% clear XYZ
% clear T
% clear Tn
% clear Tmag
% clear DC
% clear theta
% clear Ts
% for i=1:length(I)
%     XYZ(i,:) = out1.fault.disp{1,30}(I(i),2:4);% XYZ points
%     T(i,:) = Sigma200*nvecgex1_ul(I(i),:)';% Tractions
%     Tn(i,1) = -T(i,:)*nvecgex1_ul(I(i),:)';% Normal Tractions
%     Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
%     DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
%     theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
%     Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
%     STgex1_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
%     DTgex1_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
%     Dispgex1_ul(i,1) = (out1.fault.disp{1,30}(I(i),5)^2 + out1.fault.disp{1,30}(I(i),8)^2)^.5;% Displacements
% end
% % Sort elements from south to north
% [ys,I] = sort(XYZ(:,2));
% XYZ = XYZ(I,:);
% STgex1_ul = STgex1_ul(I,1);
% DTgex1_ul = DTgex1_ul(I,1);
% Dispgex1_ul = Dispgex1_ul(I,1);
% % Displacement Gradientws
% for i=1:length(I)
%     if i==1
%         dg(i,1) = Dispgex1_ul(i)/100;
%     else
%         dg(i,1) = abs(Dispgex1_ul(i)-Dispgex1_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
%     end
% end
% dg(i+1) = Dispgex1_ul(i)/100;
% for i=1:length(I)
%     DGgex1_ul(i,1) = mean([dg(i) dg(i+1)]);
% end
% % Find observation points closest to fault
% clear Dobs;clear J
% for i=1:length(I)
%     for j=1:length(out1.obs.xyz)
%         Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
%     end
%     J(i,1) = find(Dobs==min(Dobs));
%     J(i,2) = i;
% end
% % Find unique observation points and closest element center
% Lgex1_ul(:,1) = unique(J(:,1));
% for i=1:length(Lgex1_ul)
%     I = find(J(:,1)==Lgex1_ul(i));
%     clear Dobs
%     for j=1:length(I)
%         Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lgex1_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lgex1_ul(i),2))^2)^.5;
%     end
%     K = find(Dobs==min(Dobs));
%     Lgex1_ul(i,2) = J(I(K),2);
% end
% % lower residuals
% nvecgex1_ll = xlsread('Glacier_Extensional_Fault.xls','nvecgex1_200m','A2:C6000');
% I = find(out2.fault.disp{1,30}(:,4)<-2700&out2.fault.disp{1,30}(:,4)>-3000);
% % Tractions
% clear XYZ
% clear T
% clear Tn
% clear Tmag
% clear DC
% clear theta
% clear Ts
% for i=1:length(I)
%     XYZ(i,:) = out2.fault.disp{1,30}(I(i),2:4);% XYZ points
%     T(i,:) = Sigma200*nvecgex1_ll(I(i),:)';% Tractions
%     Tn(i,1) = -T(i,:)*nvecgex1_ll(I(i),:)';% Normal Tractions
%     Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
%     DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
%     theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
%     Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
%     STgex1_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
%     DTgex1_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
%     Dispgex1_ll(i,1) = (out2.fault.disp{1,30}(I(i),5)^2 + out2.fault.disp{1,30}(I(i),8)^2)^.5;% Displacements
% end
% % Sort elements from south to north
% [ys,I] = sort(XYZ(:,2));
% XYZ = XYZ(I,:);
% STgex1_ll = STgex1_ll(I,1);
% DTgex1_ll = DTgex1_ll(I,1);
% Dispgex1_ll = Dispgex1_ll(I,1);
% % Displacement Gradientws
% for i=1:length(I)
%     if i==1
%         dg(i,1) = Dispgex1_ll(i)/100;
%     else
%         dg(i,1) = abs(Dispgex1_ll(i)-Dispgex1_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
%     end
% end
% dg(i+1) = Dispgex1_ll(i)/100;
% for i=1:length(I)
%     DGgex1_ll(i,1) = mean([dg(i) dg(i+1)]);
% end
% % Find observation points closest to fault
% clear Dobs;clear J
% for i=1:length(I)
%     for j=1:length(out2.obs.xyz)
%         Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
%     end
%     J(i,1) = find(Dobs==min(Dobs));
%     J(i,2) = i;
% end
% % Find unique observation points and closest element center
% Lgex1_ll(:,1) = unique(J(:,1));
% for i=1:length(Lgex1_ll)
%     I = find(J(:,1)==Lgex1_ll(i));
%     clear Dobs
%     for j=1:length(I)
%         Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lgex1_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lgex1_ll(i),2))^2)^.5;
%     end
%     K = find(Dobs==min(Dobs));
%     Lgex1_ll(i,2) = J(I(K),2);
% end
% 
% 
% % Glacier Extensional Fault 2
% % upper residuals
% nvecgex2_ul = xlsread('Glacier_Extensional_Fault_ul.xls','nvecgex2_200m','A2:C6000');
% I = find(out1.fault.disp{1,31}(:,4)<-90&out1.fault.disp{1,31}(:,4)>-210);
% % Tractions
% clear XYZ
% clear T
% clear Tn
% clear Tmag
% clear DC
% clear theta
% clear Ts
% for i=1:length(I)
%     XYZ(i,:) = out1.fault.disp{1,31}(I(i),2:4);% XYZ points
%     T(i,:) = Sigma200*nvecgex2_ul(I(i),:)';% Tractions
%     Tn(i,1) = -T(i,:)*nvecgex2_ul(I(i),:)';% Normal Tractions
%     Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
%     DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
%     theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
%     Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
%     STgex2_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
%     DTgex2_ul(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
%     Dispgex2_ul(i,1) = (out1.fault.disp{1,31}(I(i),5)^2 + out1.fault.disp{1,31}(I(i),8)^2)^.5;% Displacements
% end
% % Sort elements from south to north
% [ys,I] = sort(XYZ(:,2));
% XYZ = XYZ(I,:);
% STgex2_ul = STgex2_ul(I,1);
% DTgex2_ul = DTgex2_ul(I,1);
% Dispgex2_ul = Dispgex2_ul(I,1);
% % Displacement Gradientws
% for i=1:length(I)
%     if i==1
%         dg(i,1) = Dispgex2_ul(i)/100;
%     else
%         dg(i,1) = abs(Dispgex2_ul(i)-Dispgex2_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
%     end
% end
% dg(i+1) = Dispgex2_ul(i)/100;
% for i=1:length(I)
%     DGgex2_ul(i,1) = mean([dg(i) dg(i+1)]);
% end
% % Find observation points closest to fault
% clear Dobs;clear J
% for i=1:length(I)
%     for j=1:length(out1.obs.xyz)
%         Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
%     end
%     J(i,1) = find(Dobs==min(Dobs));
%     J(i,2) = i;
% end
% % Find unique observation points and closest element center
% Lgex2_ul(:,1) = unique(J(:,1));
% for i=1:length(Lgex2_ul)
%     I = find(J(:,1)==Lgex2_ul(i));
%     clear Dobs
%     for j=1:length(I)
%         Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lgex2_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lgex2_ul(i),2))^2)^.5;
%     end
%     K = find(Dobs==min(Dobs));
%     Lgex2_ul(i,2) = J(I(K),2);
% end
% % upper residuals
% nvecgex2_ll = xlsread('Glacier_Extensional_Fault.xls','nvecgex2_200m','A2:C6000');
% I = find(out2.fault.disp{1,31}(:,4)<-90&out2.fault.disp{1,31}(:,4)>-210);
% % Tractions
% clear XYZ
% clear T
% clear Tn
% clear Tmag
% clear DC
% clear theta
% clear Ts
% for i=1:length(I)
%     XYZ(i,:) = out2.fault.disp{1,31}(I(i),2:4);% XYZ points
%     T(i,:) = Sigma200*nvecgex2_ll(I(i),:)';% Tractions
%     Tn(i,1) = -T(i,:)*nvecgex2_ll(I(i),:)';% Normal Tractions
%     Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
%     DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
%     theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
%     Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
%     STgex2_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
%     DTgex2_ll(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
%     Dispgex2_ll(i,1) = (out2.fault.disp{1,31}(I(i),5)^2 + out2.fault.disp{1,31}(I(i),8)^2)^.5;% Displacements
% end
% % Sort elements from south to north
% [ys,I] = sort(XYZ(:,2));
% XYZ = XYZ(I,:);
% STgex2_ll = STgex2_ll(I,1);
% DTgex2_ll = DTgex2_ll(I,1);
% Dispgex2_ll = Dispgex2_ll(I,1);
% % Displacement Gradientws
% for i=1:length(I)
%     if i==1
%         dg(i,1) = Dispgex2_ll(i)/100;
%     else
%         dg(i,1) = abs(Dispgex2_ll(i)-Dispgex2_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
%     end
% end
% dg(i+1) = Dispgex2_ll(i)/100;
% for i=1:length(I)
%     DGgex2_ll(i,1) = mean([dg(i) dg(i+1)]);
% end
% % Find observation points closest to fault
% clear Dobs;clear J
% for i=1:length(I)
%     for j=1:length(out2.obs.xyz)
%         Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
%     end
%     J(i,1) = find(Dobs==min(Dobs));
%     J(i,2) = i;
% end
% % Find unique observation points and closest element center
% Lgex2_ll(:,1) = unique(J(:,1));
% for i=1:length(Lgex2_ll)
%     I = find(J(:,1)==Lgex2_ll(i));
%     clear Dobs
%     for j=1:length(I)
%         Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lgex2_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lgex2_ll(i),2))^2)^.5;
%     end
%     K = find(Dobs==min(Dobs));
%     Lgex2_ll(i,2) = J(I(K),2);
% end


% Thunder Creek Fault
% upper residuals
nvecthcf_ul = xlsread('Thunder_Creek_Fault_ul.xls','nvecthcf_3km','A2:C6000');
I = find(out1.fault.disp{1,32}(:,4)<-2700&out1.fault.disp{1,32}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,32}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecthcf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecthcf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STthcf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTthcf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispthcf_ul(i,1) = (out1.fault.disp{1,32}(I(i),5)^2 + out1.fault.disp{1,32}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STthcf_ul = STthcf_ul(I,1);
DTthcf_ul = DTthcf_ul(I,1);
Dispthcf_ul = Dispthcf_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispthcf_ul(i)/100;
    else
        dg(i,1) = abs(Dispthcf_ul(i)-Dispthcf_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispthcf_ul(i)/100;
for i=1:length(I)
    DGthcf_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lthcf_ul(:,1) = unique(J(:,1));
for i=1:length(Lthcf_ul)
    I = find(J(:,1)==Lthcf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lthcf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lthcf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lthcf_ul(i,2) = J(I(K),2);
end
% upper residuals
nvecthcf_ll = xlsread('Thunder_Creek_Fault.xls','nvecthcf_3km','A2:C6000');
I = find(out2.fault.disp{1,32}(:,4)<-2700&out2.fault.disp{1,32}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,32}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecthcf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecthcf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STthcf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTthcf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispthcf_ll(i,1) = (out1.fault.disp{1,32}(I(i),5)^2 + out1.fault.disp{1,32}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STthcf_ll = STthcf_ll(I,1);
DTthcf_ll = DTthcf_ll(I,1);
Dispthcf_ll = Dispthcf_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispthcf_ll(i)/100;
    else
        dg(i,1) = abs(Dispthcf_ll(i)-Dispthcf_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispthcf_ll(i)/100;
for i=1:length(I)
    DGthcf_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lthcf_ll(:,1) = unique(J(:,1));
for i=1:length(Lthcf_ll)
    I = find(J(:,1)==Lthcf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lthcf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lthcf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lthcf_ll(i,2) = J(I(K),2);
end


% South Fork Fault
% upper residuals
nvecsff_ul = xlsread('South_Fork_Fault_ul.xls','nvecsff_3km','A2:C6000');
I = find(out1.fault.disp{1,33}(:,4)<-2700&out1.fault.disp{1,33}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,33}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecsff_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsff_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsff_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsff_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispsff_ul(i,1) = (out1.fault.disp{1,33}(I(i),5)^2 + out1.fault.disp{1,33}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsff_ul = STsff_ul(I,1);
DTsff_ul = DTsff_ul(I,1);
Dispsff_ul = Dispsff_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispsff_ul(i)/100;
    else
        dg(i,1) = abs(Dispsff_ul(i)-Dispsff_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispsff_ul(i)/100;
for i=1:length(I)
    DGsff_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lsff_ul(:,1) = unique(J(:,1));
for i=1:length(Lsff_ul)
    I = find(J(:,1)==Lsff_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lsff_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lsff_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsff_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecsff_ll = xlsread('South_Fork_Fault.xls','nvecsff_3km','A2:C6000');
I = find(out2.fault.disp{1,33}(:,4)<-2700&out2.fault.disp{1,33}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,33}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecsff_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsff_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsff_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsff_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispsff_ll(i,1) = (out2.fault.disp{1,33}(I(i),5)^2 + out2.fault.disp{1,33}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsff_ll = STsff_ll(I,1);
DTsff_ll = DTsff_ll(I,1);
Dispsff_ll = Dispsff_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispsff_ll(i)/100;
    else
        dg(i,1) = abs(Dispsff_ll(i)-Dispsff_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispsff_ll(i)/100;
for i=1:length(I)
    DGsff_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lsff_ll(:,1) = unique(J(:,1));
for i=1:length(Lsff_ll)
    I = find(J(:,1)==Lsff_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lsff_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lsff_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsff_ll(i,2) = J(I(K),2);
end


% North Fork Fault
% upper residuals
nvecnff_ul = xlsread('North_Fork_Fault_ul.xls','nvecnff_3km','A2:C6000');
I = find(out1.fault.disp{1,34}(:,4)<-2700&out1.fault.disp{1,34}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out1.fault.disp{1,34}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnff_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnff_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnff_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnff_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnff_ul(i,1) = (out1.fault.disp{1,34}(I(i),5)^2 + out1.fault.disp{1,34}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnff_ul = STnff_ul(I,1);
DTnff_ul = DTnff_ul(I,1);
Dispnff_ul = Dispnff_ul(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnff_ul(i)/100;
    else
        dg(i,1) = abs(Dispnff_ul(i)-Dispnff_ul(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnff_ul(i)/100;
for i=1:length(I)
    DGnff_ul(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnff_ul(:,1) = unique(J(:,1));
for i=1:length(Lnff_ul)
    I = find(J(:,1)==Lnff_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lnff_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lnff_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnff_ul(i,2) = J(I(K),2);
end
% lower residuals
nvecnff_ll = xlsread('North_Fork_Fault.xls','nvecnff_3km','A2:C6000');
I = find(out2.fault.disp{1,34}(:,4)<-2700&out2.fault.disp{1,34}(:,4)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out2.fault.disp{1,34}(I(i),2:4);% XYZ points
    T(i,:) = Sigma3km*nvecnff_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecnff_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STnff_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTnff_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
    Dispnff_ll(i,1) = (out2.fault.disp{1,34}(I(i),5)^2 + out2.fault.disp{1,34}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STnff_ll = STnff_ll(I,1);
DTnff_ll = DTnff_ll(I,1);
Dispnff_ll = Dispnff_ll(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispnff_ll(i)/100;
    else
        dg(i,1) = abs(Dispnff_ll(i)-Dispnff_ll(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispnff_ll(i)/100;
for i=1:length(I)
    DGnff_ll(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lnff_ll(:,1) = unique(J(:,1));
for i=1:length(Lnff_ll)
    I = find(J(:,1)==Lnff_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lnff_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lnff_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lnff_ll(i,2) = J(I(K),2);
end


% Shuskan Thrust Fault
% upper residuals
XYZsktf_ul = xlsread('Shuskan_Thrust_Fault_ul.xls','XYZsktf','A2:C6000');
tnsktf_ul = xlsread('Shuskan_Thrust_Fault_ul.xls','tnsktf','A1:C6000');
clear C
for i=1:length(tnsktf_ul)
    C(i,1) = mean([XYZsktf_ul(tnsktf_ul(i,1),1) XYZsktf_ul(tnsktf_ul(i,2),1) XYZsktf_ul(tnsktf_ul(i,3),1)]);
    C(i,2) = mean([XYZsktf_ul(tnsktf_ul(i,1),2) XYZsktf_ul(tnsktf_ul(i,2),2) XYZsktf_ul(tnsktf_ul(i,3),2)]);
    C(i,3) = mean([XYZsktf_ul(tnsktf_ul(i,1),3) XYZsktf_ul(tnsktf_ul(i,2),3) XYZsktf_ul(tnsktf_ul(i,3),3)]);
end
nvecsktf_ul = xlsread('Shuskan_Thrust_Fault_ul.xls','nvecsktf','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nvecsktf_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsktf_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsktf_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsktf_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispsktf_ul = zeros(length(XYZ),1);
DGsktf_ul = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lsktf_ul(:,1) = unique(J(:,1));
for i=1:length(Lsktf_ul)
    I = find(J(:,1)==Lsktf_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lsktf_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lsktf_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsktf_ul(i,2) = J(I(K),2);
end
% lower residuals
XYZsktf_ll = xlsread('Shuskan_Thrust_Fault.xls','XYZsktf','A2:C6000');
tnsktf_ll = xlsread('Shuskan_Thrust_Fault.xls','tnsktf','A1:C6000');
clear C
for i=1:length(tnsktf_ll)
    C(i,1) = mean([XYZsktf_ll(tnsktf_ll(i,1),1) XYZsktf_ll(tnsktf_ll(i,2),1) XYZsktf_ll(tnsktf_ll(i,3),1)]);
    C(i,2) = mean([XYZsktf_ll(tnsktf_ll(i,1),2) XYZsktf_ll(tnsktf_ll(i,2),2) XYZsktf_ll(tnsktf_ll(i,3),2)]);
    C(i,3) = mean([XYZsktf_ll(tnsktf_ll(i,1),3) XYZsktf_ll(tnsktf_ll(i,2),3) XYZsktf_ll(tnsktf_ll(i,3),3)]);
end
nvecsktf_ll = xlsread('Shuskan_Thrust_Fault.xls','nvecsktf','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nvecsktf_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsktf_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsktf_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsktf_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispsktf_ll = zeros(length(XYZ),1);
DGsktf_ll = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lsktf_ll(:,1) = unique(J(:,1));
for i=1:length(Lsktf_ll)
    I = find(J(:,1)==Lsktf_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lsktf_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lsktf_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsktf_ll(i,2) = J(I(K),2);
end


% Welker Peak Thrust Fault east 1
% upper residuals
XYZwptfe1_ul = xlsread('Welker_Peak_Thrust_Fault_ul.xls','XYZwptfe1','A2:C6000');
tnwptfe1_ul = xlsread('Welker_Peak_Thrust_Fault_ul.xls','tnwptfe1','A1:C6000');
clear C
for i=1:length(tnwptfe1_ul)
    C(i,1) = mean([XYZwptfe1_ul(tnwptfe1_ul(i,1),1) XYZwptfe1_ul(tnwptfe1_ul(i,2),1) XYZwptfe1_ul(tnwptfe1_ul(i,3),1)]);
    C(i,2) = mean([XYZwptfe1_ul(tnwptfe1_ul(i,1),2) XYZwptfe1_ul(tnwptfe1_ul(i,2),2) XYZwptfe1_ul(tnwptfe1_ul(i,3),2)]);
    C(i,3) = mean([XYZwptfe1_ul(tnwptfe1_ul(i,1),3) XYZwptfe1_ul(tnwptfe1_ul(i,2),3) XYZwptfe1_ul(tnwptfe1_ul(i,3),3)]);
end
nvecwptfe1_ul = xlsread('Welker_Peak_Thrust_Fault_ul.xls','nvecwptfe1','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nvecwptfe1_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwptfe1_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwptfe1_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwptfe1_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispwptfe1_ul = zeros(length(XYZ),1);
DGwptfe1_ul = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwptfe1_ul(:,1) = unique(J(:,1));
for i=1:length(Lwptfe1_ul)
    I = find(J(:,1)==Lwptfe1_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwptfe1_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwptfe1_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwptfe1_ul(i,2) = J(I(K),2);
end
% lower residuals
XYZwptfe1_ll = xlsread('Welker_Peak_Thrust_Fault.xls','XYZwptfe1','A2:C6000');
tnwptfe1_ll = xlsread('Welker_Peak_Thrust_Fault.xls','tnwptfe1','A1:C6000');
clear C
for i=1:length(tnwptfe1_ll)
    C(i,1) = mean([XYZwptfe1_ll(tnwptfe1_ll(i,1),1) XYZwptfe1_ll(tnwptfe1_ll(i,2),1) XYZwptfe1_ll(tnwptfe1_ll(i,3),1)]);
    C(i,2) = mean([XYZwptfe1_ll(tnwptfe1_ll(i,1),2) XYZwptfe1_ll(tnwptfe1_ll(i,2),2) XYZwptfe1_ll(tnwptfe1_ll(i,3),2)]);
    C(i,3) = mean([XYZwptfe1_ll(tnwptfe1_ll(i,1),3) XYZwptfe1_ll(tnwptfe1_ll(i,2),3) XYZwptfe1_ll(tnwptfe1_ll(i,3),3)]);
end
nvecwptfe1_ll = xlsread('Welker_Peak_Thrust_Fault.xls','nvecwptfe1','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nvecwptfe1_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwptfe1_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwptfe1_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwptfe1_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispwptfe1_ll = zeros(length(XYZ),1);
DGwptfe1_ll = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwptfe1_ll(:,1) = unique(J(:,1));
for i=1:length(Lwptfe1_ll)
    I = find(J(:,1)==Lwptfe1_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lwptfe1_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lwptfe1_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwptfe1_ll(i,2) = J(I(K),2);
end


% Welker Peak Thrust Fault east 2
% upper residuals
XYZwptfe2_ul = xlsread('Welker_Peak_Thrust_Fault_ul.xls','XYZwptfe2','A2:C6000');
tnwptfe2_ul = xlsread('Welker_Peak_Thrust_Fault_ul.xls','tnwptfe2','A1:C6000');
clear C
for i=1:length(tnwptfe2_ul)
    C(i,1) = mean([XYZwptfe2_ul(tnwptfe2_ul(i,1),1) XYZwptfe2_ul(tnwptfe2_ul(i,2),1) XYZwptfe2_ul(tnwptfe2_ul(i,3),1)]);
    C(i,2) = mean([XYZwptfe2_ul(tnwptfe2_ul(i,1),2) XYZwptfe2_ul(tnwptfe2_ul(i,2),2) XYZwptfe2_ul(tnwptfe2_ul(i,3),2)]);
    C(i,3) = mean([XYZwptfe2_ul(tnwptfe2_ul(i,1),3) XYZwptfe2_ul(tnwptfe2_ul(i,2),3) XYZwptfe2_ul(tnwptfe2_ul(i,3),3)]);
end
nvecwptfe2_ul = xlsread('Welker_Peak_Thrust_Fault_ul.xls','nvecwptfe2','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nvecwptfe2_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwptfe2_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwptfe2_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwptfe2_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispwptfe2_ul = zeros(length(XYZ),1);
DGwptfe2_ul = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwptfe2_ul(:,1) = unique(J(:,1));
for i=1:length(Lwptfe2_ul)
    I = find(J(:,1)==Lwptfe2_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwptfe2_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwptfe2_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwptfe2_ul(i,2) = J(I(K),2);
end
% lower residuals
XYZwptfe2_ll = xlsread('Welker_Peak_Thrust_Fault.xls','XYZwptfe2','A2:C6000');
tnwptfe2_ll = xlsread('Welker_Peak_Thrust_Fault.xls','tnwptfe2','A1:C6000');
clear C
for i=1:length(tnwptfe2_ll)
    C(i,1) = mean([XYZwptfe2_ll(tnwptfe2_ll(i,1),1) XYZwptfe2_ll(tnwptfe2_ll(i,2),1) XYZwptfe2_ll(tnwptfe2_ll(i,3),1)]);
    C(i,2) = mean([XYZwptfe2_ll(tnwptfe2_ll(i,1),2) XYZwptfe2_ll(tnwptfe2_ll(i,2),2) XYZwptfe2_ll(tnwptfe2_ll(i,3),2)]);
    C(i,3) = mean([XYZwptfe2_ll(tnwptfe2_ll(i,1),3) XYZwptfe2_ll(tnwptfe2_ll(i,2),3) XYZwptfe2_ll(tnwptfe2_ll(i,3),3)]);
end
nvecwptfe2_ll = xlsread('Welker_Peak_Thrust_Fault.xls','nvecwptfe2','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nvecwptfe2_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwptfe2_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwptfe2_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwptfe2_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispwptfe2_ll = zeros(length(XYZ),1);
DGwptfe2_ll = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwptfe2_ll(:,1) = unique(J(:,1));
for i=1:length(Lwptfe2_ll)
    I = find(J(:,1)==Lwptfe2_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lwptfe2_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lwptfe2_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwptfe2_ll(i,2) = J(I(K),2);
end


% Welker Peak Thrust Fault west
% upper residuals
XYZwptfw_ul = xlsread('Welker_Peak_Thrust_Fault_ul.xls','XYZwptfw','A2:C6000');
tnwptfw_ul = xlsread('Welker_Peak_Thrust_Fault_ul.xls','tnwptfw','A1:C6000');
clear C
for i=1:length(tnwptfw_ul)
    C(i,1) = mean([XYZwptfw_ul(tnwptfw_ul(i,1),1) XYZwptfw_ul(tnwptfw_ul(i,2),1) XYZwptfw_ul(tnwptfw_ul(i,3),1)]);
    C(i,2) = mean([XYZwptfw_ul(tnwptfw_ul(i,1),2) XYZwptfw_ul(tnwptfw_ul(i,2),2) XYZwptfw_ul(tnwptfw_ul(i,3),2)]);
    C(i,3) = mean([XYZwptfw_ul(tnwptfw_ul(i,1),3) XYZwptfw_ul(tnwptfw_ul(i,2),3) XYZwptfw_ul(tnwptfw_ul(i,3),3)]);
end
nvecwptfw_ul = xlsread('Welker_Peak_Thrust_Fault_ul.xls','nvecwptfw','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nvecwptfw_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwptfw_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwptfw_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwptfw_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispwptfw_ul = zeros(length(XYZ),1);
DGwptfw_ul = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwptfw_ul(:,1) = unique(J(:,1));
for i=1:length(Lwptfw_ul)
    I = find(J(:,1)==Lwptfw_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwptfw_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwptfw_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwptfw_ul(i,2) = J(I(K),2);
end
% lower residuals
XYZwptfw_ll = xlsread('Welker_Peak_Thrust_Fault.xls','XYZwptfw','A2:C6000');
tnwptfw_ll = xlsread('Welker_Peak_Thrust_Fault.xls','tnwptfw','A1:C6000');
clear C
for i=1:length(tnwptfw_ll)
    C(i,1) = mean([XYZwptfw_ll(tnwptfw_ll(i,1),1) XYZwptfw_ll(tnwptfw_ll(i,2),1) XYZwptfw_ll(tnwptfw_ll(i,3),1)]);
    C(i,2) = mean([XYZwptfw_ll(tnwptfw_ll(i,1),2) XYZwptfw_ll(tnwptfw_ll(i,2),2) XYZwptfw_ll(tnwptfw_ll(i,3),2)]);
    C(i,3) = mean([XYZwptfw_ll(tnwptfw_ll(i,1),3) XYZwptfw_ll(tnwptfw_ll(i,2),3) XYZwptfw_ll(tnwptfw_ll(i,3),3)]);
end
nvecwptfw_ll = xlsread('Welker_Peak_Thrust_Fault.xls','nvecwptfw','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nvecwptfw_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwptfw_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwptfw_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwptfw_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispwptfw_ll = zeros(length(XYZ),1);
DGwptfw_ll = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lwptfw_ll(:,1) = unique(J(:,1));
for i=1:length(Lwptfw_ll)
    I = find(J(:,1)==Lwptfw_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lwptfw_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lwptfw_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwptfw_ll(i,2) = J(I(K),2);
end


% Shuksan Thrust Fault 1
% upper residuals
XYZkstf1_ul = xlsread('Shuksan_Thrust_Fault_ul.xls','XYZkstf1','A2:C6000');
tnkstf1_ul = xlsread('Shuksan_Thrust_Fault_ul.xls','tnkstf1','A1:C6000');
clear C
for i=1:length(tnkstf1_ul)
    C(i,1) = mean([XYZkstf1_ul(tnkstf1_ul(i,1),1) XYZkstf1_ul(tnkstf1_ul(i,2),1) XYZkstf1_ul(tnkstf1_ul(i,3),1)]);
    C(i,2) = mean([XYZkstf1_ul(tnkstf1_ul(i,1),2) XYZkstf1_ul(tnkstf1_ul(i,2),2) XYZkstf1_ul(tnkstf1_ul(i,3),2)]);
    C(i,3) = mean([XYZkstf1_ul(tnkstf1_ul(i,1),3) XYZkstf1_ul(tnkstf1_ul(i,2),3) XYZkstf1_ul(tnkstf1_ul(i,3),3)]);
end
nveckstf1_ul = xlsread('Shuksan_Thrust_Fault_ul.xls','nveckstf1','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nveckstf1_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveckstf1_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STkstf1_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTkstf1_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispkstf1_ul = zeros(length(XYZ),1);
DGkstf1_ul = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lkstf1_ul(:,1) = unique(J(:,1));
for i=1:length(Lkstf1_ul)
    I = find(J(:,1)==Lkstf1_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lkstf1_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lkstf1_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lkstf1_ul(i,2) = J(I(K),2);
end
% lower residuals
XYZkstf1_ll = xlsread('Shuksan_Thrust_Fault.xls','XYZkstf1','A2:C6000');
tnkstf1_ll = xlsread('Shuksan_Thrust_Fault.xls','tnkstf1','A1:C6000');
clear C
for i=1:length(tnkstf1_ll)
    C(i,1) = mean([XYZkstf1_ll(tnkstf1_ll(i,1),1) XYZkstf1_ll(tnkstf1_ll(i,2),1) XYZkstf1_ll(tnkstf1_ll(i,3),1)]);
    C(i,2) = mean([XYZkstf1_ll(tnkstf1_ll(i,1),2) XYZkstf1_ll(tnkstf1_ll(i,2),2) XYZkstf1_ll(tnkstf1_ll(i,3),2)]);
    C(i,3) = mean([XYZkstf1_ll(tnkstf1_ll(i,1),3) XYZkstf1_ll(tnkstf1_ll(i,2),3) XYZkstf1_ll(tnkstf1_ll(i,3),3)]);
end
nveckstf1_ll = xlsread('Shuksan_Thrust_Fault.xls','nveckstf1','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nveckstf1_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveckstf1_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STkstf1_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTkstf1_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispkstf1_ll = zeros(length(XYZ),1);
DGkstf1_ll = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out2.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out2.obs.xyz(j,1))^2 + (XYZ(i,2)-out2.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lkstf1_ll(:,1) = unique(J(:,1));
for i=1:length(Lkstf1_ll)
    I = find(J(:,1)==Lkstf1_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out2.obs.xyz(Lkstf1_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out2.obs.xyz(Lkstf1_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lkstf1_ll(i,2) = J(I(K),2);
end


% Shuksan Thrust Fault 2
% upper residuals
XYZkstf2_ul = xlsread('Shuksan_Thrust_Fault_ul.xls','XYZkstf2','A2:C6000');
tnkstf2_ul = xlsread('Shuksan_Thrust_Fault_ul.xls','tnkstf2','A1:C6000');
clear C
for i=1:length(tnkstf2_ul)
    C(i,1) = mean([XYZkstf2_ul(tnkstf2_ul(i,1),1) XYZkstf2_ul(tnkstf2_ul(i,2),1) XYZkstf2_ul(tnkstf2_ul(i,3),1)]);
    C(i,2) = mean([XYZkstf2_ul(tnkstf2_ul(i,1),2) XYZkstf2_ul(tnkstf2_ul(i,2),2) XYZkstf2_ul(tnkstf2_ul(i,3),2)]);
    C(i,3) = mean([XYZkstf2_ul(tnkstf2_ul(i,1),3) XYZkstf2_ul(tnkstf2_ul(i,2),3) XYZkstf2_ul(tnkstf2_ul(i,3),3)]);
end
nveckstf2_ul = xlsread('Shuksan_Thrust_Fault_ul.xls','nveckstf2','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nveckstf2_ul(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveckstf2_ul(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STkstf2_ul(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTkstf2_ul(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispkstf2_ul = zeros(length(XYZ),1);
DGkstf2_ul = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lkstf2_ul(:,1) = unique(J(:,1));
for i=1:length(Lkstf2_ul)
    I = find(J(:,1)==Lkstf2_ul(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lkstf2_ul(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lkstf2_ul(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lkstf2_ul(i,2) = J(I(K),2);
end
% lower residuals
XYZkstf2_ll = xlsread('Shuksan_Thrust_Fault.xls','XYZkstf2','A2:C6000');
tnkstf2_ll = xlsread('Shuksan_Thrust_Fault.xls','tnkstf2','A1:C6000');
clear C
for i=1:length(tnkstf2_ll)
    C(i,1) = mean([XYZkstf2_ll(tnkstf2_ll(i,1),1) XYZkstf2_ll(tnkstf2_ll(i,2),1) XYZkstf2_ll(tnkstf2_ll(i,3),1)]);
    C(i,2) = mean([XYZkstf2_ll(tnkstf2_ll(i,1),2) XYZkstf2_ll(tnkstf2_ll(i,2),2) XYZkstf2_ll(tnkstf2_ll(i,3),2)]);
    C(i,3) = mean([XYZkstf2_ll(tnkstf2_ll(i,1),3) XYZkstf2_ll(tnkstf2_ll(i,2),3) XYZkstf2_ll(tnkstf2_ll(i,3),3)]);
end
nveckstf2_ll = xlsread('Shuksan_Thrust_Fault.xls','nveckstf2','A2:C6000');
I = find(C(:,3)<-2700&C(:,3)>-3000);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = C(I(i),1:3);% XYZ points
    T(i,:) = Sigma3km*nveckstf2_ll(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nveckstf2_ll(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STkstf2_ll(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTkstf2_ll(i,1) = ((-PS3km(1,1))-(Tn(i,1)))/((-PS3km(1,1))-(-PS3km(3,3)));% Dilation Tendencies
end
% Displacement and Displacement Gradient (zero)
Dispkstf2_ll = zeros(length(XYZ),1);
DGkstf2_ll = zeros(length(XYZ),1);
% Find observation points closest to fault
clear Dobs;clear J
for i=1:length(I)
    for j=1:length(out1.obs.xyz)
        Dobs(j) = ((XYZ(i,1)-out1.obs.xyz(j,1))^2 + (XYZ(i,2)-out1.obs.xyz(j,2))^2)^.5;
    end
    J(i,1) = find(Dobs==min(Dobs));
    J(i,2) = i;
end
% Find unique observation points and closest element center
Lkstf2_ll(:,1) = unique(J(:,1));
for i=1:length(Lkstf2_ll)
    I = find(J(:,1)==Lkstf2_ll(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out1.obs.xyz(Lkstf2_ll(i),1))^2 + (XYZ(J(I(j),2),2)-out1.obs.xyz(Lkstf2_ll(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lkstf2_ll(i,2) = J(I(K),2);
end

%% combine fault layers

L_ul = [Ltacf_ul;Ltsmf_ul;Lrcf_ul;Lblf_ul;Lmwf_ul;Lracf_ul;Lscf1_ul;Lscf2_ul;Lscf3_ul;Ldf_ul;Lsmf_ul;Lbmf_ul;Ltmf_ul;Lwf_ul;Lnrf1_ul;Lnrf2_ul;Lnrf3a_ul;Lnrf3b_ul;Ltcf_ul;Lgcf_ul;Lwcf1_ul;Lwcf2_ul;Llmf_ul;Lwcf_ul;Lcrf_ul;Lrcf1_ul;Lrcf2_ul;Lthcf_ul;Lsff_ul;Lnff_ul;Lsktf_ul;Lwptfe1_ul;Lwptfe2_ul;Lwptfw_ul;Lkstf1_ul;Lkstf2_ul];
STall_ul = [STacf_ul(Ltacf_ul(:,2));STtsmf_ul(Ltsmf_ul(:,2));STrcf_ul(Lrcf_ul(:,2));STblf_ul(Lblf_ul(:,2));STmwf_ul(Lmwf_ul(:,2));STracf_ul(Lracf_ul(:,2));STscf1_ul(Lscf1_ul(:,2));STscf2_ul(Lscf2_ul(:,2));STscf3_ul(Lscf3_ul(:,2));STdf_ul(Ldf_ul(:,2));STsmf_ul(Lsmf_ul(:,2));STbmf_ul(Lbmf_ul(:,2));STtmf_ul(Ltmf_ul(:,2));STwf_ul(Lwf_ul(:,2));STnrf1_ul(Lnrf1_ul(:,2));STnrf2_ul(Lnrf2_ul(:,2));STnrf3a_ul(Lnrf3a_ul(:,2));STnrf3b_ul(Lnrf3b_ul(:,2));STtcf_ul(Ltcf_ul(:,2));STgcf_ul(Lgcf_ul(:,2));STwcf1_ul(Lwcf1_ul(:,2));STwcf2_ul(Lwcf2_ul(:,2));STlmf_ul(Llmf_ul(:,2));STwcf_ul(Lwcf_ul(:,2));STcrf_ul(Lcrf_ul(:,2));STrcf1_ul(Lrcf1_ul(:,2));STrcf2_ul(Lrcf2_ul(:,2));STthcf_ul(Lthcf_ul(:,2));STsff_ul(Lsff_ul(:,2));STnff_ul(Lnff_ul(:,2));STsktf_ul(Lsktf_ul(:,2));STwptfe1_ul(Lwptfe1_ul(:,2));STwptfe2_ul(Lwptfe2_ul(:,2));STwptfw_ul(Lwptfw_ul(:,2));STkstf1_ul(Lkstf1_ul(:,2));STkstf2_ul(Lkstf2_ul(:,2))];
DTall_ul = [DTacf_ul(Ltacf_ul(:,2));DTtsmf_ul(Ltsmf_ul(:,2));DTrcf_ul(Lrcf_ul(:,2));DTblf_ul(Lblf_ul(:,2));DTmwf_ul(Lmwf_ul(:,2));DTracf_ul(Lracf_ul(:,2));DTscf1_ul(Lscf1_ul(:,2));DTscf2_ul(Lscf2_ul(:,2));DTscf3_ul(Lscf3_ul(:,2));DTdf_ul(Ldf_ul(:,2));DTsmf_ul(Lsmf_ul(:,2));DTbmf_ul(Lbmf_ul(:,2));DTtmf_ul(Ltmf_ul(:,2));DTwf_ul(Lwf_ul(:,2));DTnrf1_ul(Lnrf1_ul(:,2));DTnrf2_ul(Lnrf2_ul(:,2));DTnrf3a_ul(Lnrf3a_ul(:,2));DTnrf3b_ul(Lnrf3b_ul(:,2));DTtcf_ul(Ltcf_ul(:,2));DTgcf_ul(Lgcf_ul(:,2));DTwcf1_ul(Lwcf1_ul(:,2));DTwcf2_ul(Lwcf2_ul(:,2));DTlmf_ul(Llmf_ul(:,2));DTwcf_ul(Lwcf_ul(:,2));DTcrf_ul(Lcrf_ul(:,2));DTrcf1_ul(Lrcf1_ul(:,2));DTrcf2_ul(Lrcf2_ul(:,2));DTthcf_ul(Lthcf_ul(:,2));DTsff_ul(Lsff_ul(:,2));DTnff_ul(Lnff_ul(:,2));DTsktf_ul(Lsktf_ul(:,2));DTwptfe1_ul(Lwptfe1_ul(:,2));DTwptfe2_ul(Lwptfe2_ul(:,2));DTwptfw_ul(Lwptfw_ul(:,2));DTkstf1_ul(Lkstf1_ul(:,2));DTkstf2_ul(Lkstf2_ul(:,2))];
Dispall_ul = [Dispacf_ul(Ltacf_ul(:,2));Disptsmf_ul(Ltsmf_ul(:,2));Disprcf_ul(Lrcf_ul(:,2));Dispblf_ul(Lblf_ul(:,2));Dispmwf_ul(Lmwf_ul(:,2));Dispracf_ul(Lracf_ul(:,2));Dispscf1_ul(Lscf1_ul(:,2));Dispscf2_ul(Lscf2_ul(:,2));Dispscf3_ul(Lscf3_ul(:,2));Dispdf_ul(Ldf_ul(:,2));Dispsmf_ul(Lsmf_ul(:,2));Dispbmf_ul(Lbmf_ul(:,2));Disptmf_ul(Ltmf_ul(:,2));Dispwf_ul(Lwf_ul(:,2));Dispnrf1_ul(Lnrf1_ul(:,2));Dispnrf2_ul(Lnrf2_ul(:,2));Dispnrf3a_ul(Lnrf3a_ul(:,2));Dispnrf3b_ul(Lnrf3b_ul(:,2));Disptcf_ul(Ltcf_ul(:,2));Dispgcf_ul(Lgcf_ul(:,2));Dispwcf1_ul(Lwcf1_ul(:,2));Dispwcf2_ul(Lwcf2_ul(:,2));Displmf_ul(Llmf_ul(:,2));Dispwcf_ul(Lwcf_ul(:,2));Dispcrf_ul(Lcrf_ul(:,2));Disprcf1_ul(Lrcf1_ul(:,2));Disprcf2_ul(Lrcf2_ul(:,2));Dispthcf_ul(Lthcf_ul(:,2));Dispsff_ul(Lsff_ul(:,2));Dispnff_ul(Lnff_ul(:,2));Dispsktf_ul(Lsktf_ul(:,2));Dispwptfe1_ul(Lwptfe1_ul(:,2));Dispwptfe2_ul(Lwptfe2_ul(:,2));Dispwptfw_ul(Lwptfw_ul(:,2));Dispkstf1_ul(Lkstf1_ul(:,2));Dispkstf2_ul(Lkstf2_ul(:,2))];
DGall_ul = [DGacf_ul(Ltacf_ul(:,2));DGtsmf_ul(Ltsmf_ul(:,2));DGrcf_ul(Lrcf_ul(:,2));DGblf_ul(Lblf_ul(:,2));DGmwf_ul(Lmwf_ul(:,2));DGracf_ul(Lracf_ul(:,2));DGscf1_ul(Lscf1_ul(:,2));DGscf2_ul(Lscf2_ul(:,2));DGscf3_ul(Lscf3_ul(:,2));DGdf_ul(Ldf_ul(:,2));DGsmf_ul(Lsmf_ul(:,2));DGbmf_ul(Lbmf_ul(:,2));DGtmf_ul(Ltmf_ul(:,2));DGwf_ul(Lwf_ul(:,2));DGnrf1_ul(Lnrf1_ul(:,2));DGnrf2_ul(Lnrf2_ul(:,2));DGnrf3a_ul(Lnrf3a_ul(:,2));DGnrf3b_ul(Lnrf3b_ul(:,2));DGtcf_ul(Ltcf_ul(:,2));DGgcf_ul(Lgcf_ul(:,2));DGwcf1_ul(Lwcf1_ul(:,2));DGwcf2_ul(Lwcf2_ul(:,2));DGlmf_ul(Llmf_ul(:,2));DGwcf_ul(Lwcf_ul(:,2));DGcrf_ul(Lcrf_ul(:,2));DGrcf1_ul(Lrcf1_ul(:,2));DGrcf2_ul(Lrcf2_ul(:,2));DGthcf_ul(Lthcf_ul(:,2));DGsff_ul(Lsff_ul(:,2));DGnff_ul(Lnff_ul(:,2));DGsktf_ul(Lsktf_ul(:,2));DGwptfe1_ul(Lwptfe1_ul(:,2));DGwptfe2_ul(Lwptfe2_ul(:,2));DGwptfw_ul(Lwptfw_ul(:,2));DGkstf1_ul(Lkstf1_ul(:,2));DGkstf2_ul(Lkstf2_ul(:,2))];


L_ll = [Ltacf_ll;Ltsmf_ll;Lrcf_ll;Lblf_ll;Lmwf_ll;Lracf_ll;Lscf1_ll;Lscf2_ll;Lscf3_ll;Ldf_ll;Lsmf_ll;Lbmf_ll;Ltmf_ll;Lwf_ll;Lnrf1_ll;Lnrf2_ll;Lnrf3a_ll;Lnrf3b_ll;Ltcf_ll;Lgcf_ll;Lwcf1_ll;Lwcf2_ll;Llmf_ll;Lwcf_ll;Lcrf_ll;Lrcf1_ll;Lrcf2_ll;Lthcf_ll;Lsff_ll;Lnff_ll;Lsktf_ll;Lwptfe1_ll;Lwptfe2_ll;Lwptfw_ll;Lkstf1_ll;Lkstf2_ll];
STall_ll = [STacf_ll(Ltacf_ll(:,2));STtsmf_ll(Ltsmf_ll(:,2));STrcf_ll(Lrcf_ll(:,2));STblf_ll(Lblf_ll(:,2));STmwf_ll(Lmwf_ll(:,2));STracf_ll(Lracf_ll(:,2));STscf1_ll(Lscf1_ll(:,2));STscf2_ll(Lscf2_ll(:,2));STscf3_ll(Lscf3_ll(:,2));STdf_ll(Ldf_ll(:,2));STsmf_ll(Lsmf_ll(:,2));STbmf_ll(Lbmf_ll(:,2));STtmf_ll(Ltmf_ll(:,2));STwf_ll(Lwf_ll(:,2));STnrf1_ll(Lnrf1_ll(:,2));STnrf2_ll(Lnrf2_ll(:,2));STnrf3a_ll(Lnrf3a_ll(:,2));STnrf3b_ll(Lnrf3b_ll(:,2));STtcf_ll(Ltcf_ll(:,2));STgcf_ll(Lgcf_ll(:,2));STwcf1_ll(Lwcf1_ll(:,2));STwcf2_ll(Lwcf2_ll(:,2));STlmf_ll(Llmf_ll(:,2));STwcf_ll(Lwcf_ll(:,2));STcrf_ll(Lcrf_ll(:,2));STrcf1_ll(Lrcf1_ll(:,2));STrcf2_ll(Lrcf2_ll(:,2));STthcf_ll(Lthcf_ll(:,2));STsff_ll(Lsff_ll(:,2));STnff_ll(Lnff_ll(:,2));STsktf_ll(Lsktf_ll(:,2));STwptfe1_ll(Lwptfe1_ll(:,2));STwptfe2_ll(Lwptfe2_ll(:,2));STwptfw_ll(Lwptfw_ll(:,2));STkstf1_ll(Lkstf1_ll(:,2));STkstf2_ll(Lkstf2_ll(:,2))];
DTall_ll = [DTacf_ll(Ltacf_ll(:,2));DTtsmf_ll(Ltsmf_ll(:,2));DTrcf_ll(Lrcf_ll(:,2));DTblf_ll(Lblf_ll(:,2));DTmwf_ll(Lmwf_ll(:,2));DTracf_ll(Lracf_ll(:,2));DTscf1_ll(Lscf1_ll(:,2));DTscf2_ll(Lscf2_ll(:,2));DTscf3_ll(Lscf3_ll(:,2));DTdf_ll(Ldf_ll(:,2));DTsmf_ll(Lsmf_ll(:,2));DTbmf_ll(Lbmf_ll(:,2));DTtmf_ll(Ltmf_ll(:,2));DTwf_ll(Lwf_ll(:,2));DTnrf1_ll(Lnrf1_ll(:,2));DTnrf2_ll(Lnrf2_ll(:,2));DTnrf3a_ll(Lnrf3a_ll(:,2));DTnrf3b_ll(Lnrf3b_ll(:,2));DTtcf_ll(Ltcf_ll(:,2));DTgcf_ll(Lgcf_ll(:,2));DTwcf1_ll(Lwcf1_ll(:,2));DTwcf2_ll(Lwcf2_ll(:,2));DTlmf_ll(Llmf_ll(:,2));DTwcf_ll(Lwcf_ll(:,2));DTcrf_ll(Lcrf_ll(:,2));DTrcf1_ll(Lrcf1_ll(:,2));DTrcf2_ll(Lrcf2_ll(:,2));DTthcf_ll(Lthcf_ll(:,2));DTsff_ll(Lsff_ll(:,2));DTnff_ll(Lnff_ll(:,2));DTsktf_ll(Lsktf_ll(:,2));DTwptfe1_ll(Lwptfe1_ll(:,2));DTwptfe2_ll(Lwptfe2_ll(:,2));DTwptfw_ll(Lwptfw_ll(:,2));DTkstf1_ll(Lkstf1_ll(:,2));DTkstf2_ll(Lkstf2_ll(:,2))];
Dispall_ll = [Dispacf_ll(Ltacf_ll(:,2));Disptsmf_ll(Ltsmf_ll(:,2));Disprcf_ll(Lrcf_ll(:,2));Dispblf_ll(Lblf_ll(:,2));Dispmwf_ll(Lmwf_ll(:,2));Dispracf_ll(Lracf_ll(:,2));Dispscf1_ll(Lscf1_ll(:,2));Dispscf2_ll(Lscf2_ll(:,2));Dispscf3_ll(Lscf3_ll(:,2));Dispdf_ll(Ldf_ll(:,2));Dispsmf_ll(Lsmf_ll(:,2));Dispbmf_ll(Lbmf_ll(:,2));Disptmf_ll(Ltmf_ll(:,2));Dispwf_ll(Lwf_ll(:,2));Dispnrf1_ll(Lnrf1_ll(:,2));Dispnrf2_ll(Lnrf2_ll(:,2));Dispnrf3a_ll(Lnrf3a_ll(:,2));Dispnrf3b_ll(Lnrf3b_ll(:,2));Disptcf_ll(Ltcf_ll(:,2));Dispgcf_ll(Lgcf_ll(:,2));Dispwcf1_ll(Lwcf1_ll(:,2));Dispwcf2_ll(Lwcf2_ll(:,2));Displmf_ll(Llmf_ll(:,2));Dispwcf_ll(Lwcf_ll(:,2));Dispcrf_ll(Lcrf_ll(:,2));Disprcf1_ll(Lrcf1_ll(:,2));Disprcf2_ll(Lrcf2_ll(:,2));Dispthcf_ll(Lthcf_ll(:,2));Dispsff_ll(Lsff_ll(:,2));Dispnff_ll(Lnff_ll(:,2));Dispsktf_ll(Lsktf_ll(:,2));Dispwptfe1_ll(Lwptfe1_ll(:,2));Dispwptfe2_ll(Lwptfe2_ll(:,2));Dispwptfw_ll(Lwptfw_ll(:,2));Dispkstf1_ll(Lkstf1_ll(:,2));Dispkstf2_ll(Lkstf2_ll(:,2))];
DGall_ll = [DGacf_ll(Ltacf_ll(:,2));DGtsmf_ll(Ltsmf_ll(:,2));DGrcf_ll(Lrcf_ll(:,2));DGblf_ll(Lblf_ll(:,2));DGmwf_ll(Lmwf_ll(:,2));DGracf_ll(Lracf_ll(:,2));DGscf1_ll(Lscf1_ll(:,2));DGscf2_ll(Lscf2_ll(:,2));DGscf3_ll(Lscf3_ll(:,2));DGdf_ll(Ldf_ll(:,2));DGsmf_ll(Lsmf_ll(:,2));DGbmf_ll(Lbmf_ll(:,2));DGtmf_ll(Ltmf_ll(:,2));DGwf_ll(Lwf_ll(:,2));DGnrf1_ll(Lnrf1_ll(:,2));DGnrf2_ll(Lnrf2_ll(:,2));DGnrf3a_ll(Lnrf3a_ll(:,2));DGnrf3b_ll(Lnrf3b_ll(:,2));DGtcf_ll(Ltcf_ll(:,2));DGgcf_ll(Lgcf_ll(:,2));DGwcf1_ll(Lwcf1_ll(:,2));DGwcf2_ll(Lwcf2_ll(:,2));DGlmf_ll(Llmf_ll(:,2));DGwcf_ll(Lwcf_ll(:,2));DGcrf_ll(Lcrf_ll(:,2));DGrcf1_ll(Lrcf1_ll(:,2));DGrcf2_ll(Lrcf2_ll(:,2));DGthcf_ll(Lthcf_ll(:,2));DGsff_ll(Lsff_ll(:,2));DGnff_ll(Lnff_ll(:,2));DGsktf_ll(Lsktf_ll(:,2));DGwptfe1_ll(Lwptfe1_ll(:,2));DGwptfe2_ll(Lwptfe2_ll(:,2));DGwptfw_ll(Lwptfw_ll(:,2));DGkstf1_ll(Lkstf1_ll(:,2));DGkstf2_ll(Lkstf2_ll(:,2))];


k=1;
for i=1:length(out1.obs.pstress)
    if find(L_ul(:,1)==i)
        if STall_ul(k)>1
            ST_ul(i,1) = 1;
        elseif STall_ul(k)<0
            ST_ul(i,1) = 0;
        else
            ST_ul(i,1) = STall_ul(k);
        end
        DT_ul(i,1) = DTall_ul(k);
        Disp_ul(i,1) = Dispall_ul(k);
        DG_ul(i,1) = DGall_ul(k);
        k=k+1;
    else
        ST_ul(i,1) = 0;
        DT_ul(i,1) = 0;
        Disp_ul(i,1) = 0;
        DG_ul(i,1) = 0;
    end
end
k=1;
for i=1:length(out2.obs.pstress)
    if find(L_ll(:,1)==i)
        if STall_ll(k)>1
            ST_ll(i,1) = 1;
        elseif STall_ll(k)<0
            ST_ll(i,1) = 0;
        else
            ST_ll(i,1) = STall_ll(k);
        end
        DT_ll(i,1) = DTall_ll(k);
        Disp_ll(i,1) = Dispall_ll(k);
        DG_ll(i,1) = DGall_ll(k);
        k=k+1;
    else
        ST_ll(i,1) = 0;
        DT_ll(i,1) = 0;
        Disp_ll(i,1) = 0;
        DG_ll(i,1) = 0;
    end
end

% FAULT_GRID --> X,Y,Z,slip tendency,dilation tendency,displacement gradient
for i=1:length(out1.obs.pstress)
    FAULT_GRID(i,1:3) = out1.obs.pstress(i,1:3);
end
FAULT_GRID(:,4) = abs(ST_ul-ST_ll);
FAULT_GRID(:,5) = abs(DT_ul-DT_ll);
FAULT_GRID(:,6) = abs(Disp_ul-Disp_ll);
FAULT_GRID(:,7) = abs(DG_ul-DG_ll);

%% Combine Stress layers

% 2D smoothing
for j=0:114
for i=0:107
    X(1+i,1+j) = out1.obs.xyz((1+i)+108*j,1);
    Y(1+i,1+j) = out1.obs.xyz((1+i)+108*j,2);
    ScXY_ul(1+i,1+j) = ((((-out1.obs.pstress((1+i)+108*j,15))-(-out1.obs.pstress((1+i)+108*j,7)))/2)*(1+.6^2)^.5 - .6*(((-out1.obs.pstress((1+i)+108*j,15))+(-out1.obs.pstress((1+i)+108*j,7)))/2));%/1000000;
    ShminXY_ul(1+i,1+j) = (-out1.obs.pstress((1+i)+108*j,7));%/1000000;
    if find(L_ul(:,1)==((1+i)+108*j))
        ScXY_ul(1+i,1+j) = NaN;
        ShminXY_ul(1+i,1+j) = NaN;
    end
end
end
Nrc = 2;
ScXY_ul = smooth2a(ScXY_ul,Nrc);
ShminXY_ul = smooth2a(ShminXY_ul,Nrc);
for i=1:numel(ScXY_ul(1,:))
    Sc_ul(1+(i-1)*numel(ScXY_ul(:,1)):i*numel(ScXY_ul(:,1)),1) = ScXY_ul(:,i);
    Shmin_ul(1+(i-1)*numel(ScXY_ul(:,1)):i*numel(ScXY_ul(:,1)),1) = ShminXY_ul(:,i);
end
for j=0:114
for i=0:107
    X(1+i,1+j) = out2.obs.xyz((1+i)+108*j,1);
    Y(1+i,1+j) = out2.obs.xyz((1+i)+108*j,2);
    ScXY_ll(1+i,1+j) = ((((-out2.obs.pstress((1+i)+108*j,15))-(-out2.obs.pstress((1+i)+108*j,7)))/2)*(1+.6^2)^.5 - .6*(((-out2.obs.pstress((1+i)+108*j,15))+(-out2.obs.pstress((1+i)+108*j,7)))/2));%/1000000;
    ShminXY_ll(1+i,1+j) = (-out2.obs.pstress((1+i)+108*j,7));%/1000000;
    if find(L_ul(:,1)==((1+i)+108*j))
        ScXY_ll(1+i,1+j) = NaN;
        ShminXY_ll(1+i,1+j) = NaN;
    end
end
end
ScXY_ll = smooth2a(ScXY_ll,Nrc);
ShminXY_ll = smooth2a(ShminXY_ll,Nrc);
for i=1:numel(ScXY_ll(1,:))
    Sc_ll(1+(i-1)*numel(ScXY_ll(:,1)):i*numel(ScXY_ll(:,1)),1) = ScXY_ll(:,i);
    Shmin_ll(1+(i-1)*numel(ScXY_ll(:,1)):i*numel(ScXY_ll(:,1)),1) = ShminXY_ll(:,i);
end

% extract stress values to compute means and standard deviations
k=1;
for i=1:length(Sc_ul)
    if isnan(Sc_ul(i)-Sc_ll(i))
        Sc(i,1) = 0;
        Shmin(i,1) = 0;
    else
        Sc(i,1) = abs(Sc_ul(i)-Sc_ll(i));
        Shmin(i,1) = abs(Shmin_ul(i)-Shmin_ll(i));
        ScReal(k,1) = abs(Sc_ul(i)-Sc_ll(i));
        ShminReal(k,1) = abs(Shmin_ul(i)-Shmin_ll(i));
        k=k+1;
    end
end

% Mean and Standard Deviation
% Sc
Scmean = mean(ScReal);%/1000000;
SigSc = std(ScReal);
% Shmin
Shminmean = mean(ShminReal);%/1000000;
SigShmin = std(ShminReal);

% STRESS_GRID --> X,Y,Z,maximum Coulomb shear stress,Shmin
STRESS_GRID(:,1:3) = out1.obs.xyz(:,1:3);
STRESS_GRID(:,4) = Sc;
STRESS_GRID(:,5) = Shmin;

%% Permeability Model Layer Normalization

% Fault Layers
Fault.sliptendency(:,1:3) = FAULT_GRID(:,1:3);
Fault.sliptendency(:,4) = FAULT_GRID(:,4)/max(FAULT_GRID(:,4));
Fault.dilationtendency(:,1:3) = FAULT_GRID(:,1:3);
Fault.dilationtendency(:,4) = FAULT_GRID(:,5)/max(FAULT_GRID(:,5));
% displacement
Fault.displacement(:,1:3) = FAULT_GRID(:,1:3);
Fault.displacement(:,4) = FAULT_GRID(:,6)/max(FAULT_GRID(:,6));
% displacement gradient
Fault.displacementgradient(:,1:3) = FAULT_GRID(:,1:3);
Fault.displacementgradient(:,4) = FAULT_GRID(:,7)/max(FAULT_GRID(:,7));

% Stress Layers
% normalization between +/- X standard deviations
nsd = 5;% # of standard deviations
Stress.MaximumCoulombShearStress(:,1:3) = STRESS_GRID(:,1:3);
% Stress.MaximumCoulombShearStress(:,4) = (STRESS_GRID(:,4)-(Scmean-sdc*SigSc))/(2*sdc*SigSc);
Stress.MaximumCoulombShearStress(:,4) = STRESS_GRID(:,4)/(2*nsd*SigSc);
I = find(Stress.MaximumCoulombShearStress(:,4)<0);
Stress.MaximumCoulombShearStress(I,4) = 0;
I = find(Stress.MaximumCoulombShearStress(:,4)>1);
Stress.MaximumCoulombShearStress(I,4) = 1;
for i=1:length(L_ul)
    Stress.MaximumCoulombShearStress(L_ul(i,1),4) = 0;
end
for i=1:length(L_ll)
    Stress.MaximumCoulombShearStress(L_ll(i,1),4) = 0;
end

% Inverse Shmin values by adding 2*mean to negative values
Stress.Sigma3(:,1:3) = STRESS_GRID(:,1:3);
Stress.Sigma3(:,4) = STRESS_GRID(:,5);
Stress.Sigma3(:,4) = Stress.Sigma3(:,4)/(2*nsd*SigShmin);
I = find(Stress.Sigma3(:,4)<0);
Stress.Sigma3(I,4) = 0;
I = find(Stress.Sigma3(:,4)>1);
Stress.Sigma3(I,4) = 1;
for i=1:length(L_ul)
    Stress.Sigma3(L_ul(i,1),4) = 0;
end
for i=1:length(L_ll)
    Stress.Sigma3(L_ll(i,1),4) = 0;
end

%% FIGURES

figure
plot([1:numel(Sc)],Sc,'k-');ylabel('Sc')
hold on
plot([0 9292],[Scmean+2*nsd*SigSc Scmean+2*nsd*SigSc])
plot([0 9292],[0 0])
figure
plot([1:numel(Shmin)],Shmin,'k-');ylabel('Shmin')
hold on
plot([0 9292],[Shminmean+2*nsd*SigShmin Shminmean+2*nsd*SigShmin])
plot([0 9292],[0 0])

figure
plot([1:numel(Stress.MaximumCoulombShearStress(:,4))],Stress.MaximumCoulombShearStress(:,4),'k.');ylabel('Sc favorability')
figure
plot([1:numel(Stress.Sigma3(:,4))],Stress.Sigma3(:,4),'k.');ylabel('Shmin favorability')


% grid data for contour plots
for j=0:114
for i=0:107
    X(1+i,1+j) = out1.obs.pstress((1+i)+108*j,1);
    Y(1+i,1+j) = out1.obs.pstress((1+i)+108*j,2);
    STXY(1+i,1+j) = Fault.sliptendency((1+i)+108*j,4);
    DTXY(1+i,1+j) = Fault.dilationtendency((1+i)+108*j,4);
    DispXY(1+i,1+j) = Fault.displacement((1+i)+108*j,4);
    DGXY(1+i,1+j) = Fault.displacementgradient((1+i)+108*j,4);
    ScXY(1+i,1+j) = Stress.MaximumCoulombShearStress((1+i)+108*j,4);
    ShminXY(1+i,1+j) = Stress.Sigma3((1+i)+108*j,4);
    if find(L_ul(:,1)==((1+i)+108*j))
        ScXY(1+i,1+j) = NaN;
        ShminXY(1+i,1+j) = NaN;
    elseif find(L_ll(:,1)==((1+i)+108*j))
        ScXY(1+i,1+j) = NaN;
        ShminXY(1+i,1+j) = NaN;
    end
end
end

% colormap white-black
for i=1:50
    unccm(i,:) = [(1-i/50) (1-i/50) (1-i/50)];
end
Vm = [0:.01:1];

% Sc
figure
contourf(X,Y,ScXY,Vm)
hold on
contour(X,Y,ScXY,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sc uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% S3
figure
contourf(X,Y,ShminXY,Vm)
hold on
contour(X,Y,ShminXY,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sigma3 uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% ST
figure
contourf(X,Y,STXY)
hold on
contour(X,Y,STXY)
c=colorbar;
set(get(c,'ylabel'),'String','Slip Tendency uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% DT
figure
contourf(X,Y,DTXY)
hold on
contour(X,Y,DTXY)
c=colorbar;
set(get(c,'ylabel'),'String','Dilation Tendency uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% Disp
figure
contourf(X,Y,DispXY)
hold on
contour(X,Y,DispXY)
c=colorbar;
set(get(c,'ylabel'),'String','Displacement uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

% Disp
figure
contourf(X,Y,DGXY)
hold on
contour(X,Y,DGXY)
c=colorbar;
set(get(c,'ylabel'),'String','Displacement Gradient uncertainty','Fontsize',14);
caxis([0 1]);
colormap(unccm);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)